(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    282692,       8609]*)
(*NotebookOutlinePosition[    294602,       8940]*)
(*  CellTagsIndexPosition[    292770,       8879]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[StyleBox["TuGames  v1.1",
  FontSlant->"Italic"]], "Title"],

Cell["", "Author"],

Cell[TextData[{
  StyleBox["by Holger I.  Meinhardt (2005)\nInstitute for Statistics and\n\
Economic Theory\nUniversity of Karlsruhe\nEnglerstr. 11,Bd. 11.40\nD-76128 \
Karlsruhe\n",
    FontSlant->"Italic"],
  "E-mails: hme@vwl3.wiwi.uni-karlsruhe.de",
  StyleBox[", ",
    FontSlant->"Italic"],
  "Holger.Meinhardt@wiwi.uni-karlsruhe.de"
}], "Text"],

Cell[CellGroupData[{

Cell["Contents", "Section"],

Cell[TextData[{
  "1. ",
  ButtonBox["Introduction",
    ButtonData:>"Introduction",
    ButtonStyle->"Hyperlink"],
  "\n2. ",
  ButtonBox["Installation",
    ButtonData:>"Installation",
    ButtonStyle->"Hyperlink"],
  "\n2.1. ",
  ButtonBox["Unix",
    ButtonData:>"Unix",
    ButtonStyle->"Hyperlink"],
  "\n2.2. ",
  ButtonBox["Windows",
    ButtonData:>"Windows",
    ButtonStyle->"Hyperlink"],
  "\n2.3. ",
  ButtonBox["Mac OS",
    ButtonData:>"Mac OS",
    ButtonStyle->"Hyperlink"],
  "\n3. ",
  ButtonBox["Getting Started",
    ButtonData:>"Getting Started",
    ButtonStyle->"Hyperlink"],
  " \n3.1. ",
  ButtonBox["How to define Games?",
    ButtonData:>"How to define Games?",
    ButtonStyle->"Hyperlink"],
  "\n4. ",
  ButtonBox["Some Functions",
    ButtonData:>"Some Functions",
    ButtonStyle->"Hyperlink"],
  "\n4.1. ",
  ButtonBox["Basic Functions",
    ButtonData:>"Basic Functions",
    ButtonStyle->"Hyperlink"],
  "\n4.2. ",
  ButtonBox["k-Convexity",
    ButtonData:>"k-convexity",
    ButtonStyle->"Hyperlink"],
  "\n4.3. ",
  ButtonBox["Kernel",
    ButtonData:>"Kernel",
    ButtonStyle->"Hyperlink"],
  "\n4.4. ",
  ButtonBox["Unanimity Coordinates",
    ButtonData:>"Unanimity Coordinates",
    ButtonStyle->"Hyperlink"],
  "\n5. ",
  ButtonBox["Computing the Vertices of the Core",
    ButtonData:>"5",
    ButtonStyle->"Hyperlink"],
  "\n6. ",
  ButtonBox["Concluding Remarks and Limitations",
    ButtonData:>"Concluding Remarks and Limitations",
    ButtonStyle->"Hyperlink"],
  "\n7. ",
  ButtonBox["References",
    ButtonData:>"References",
    ButtonStyle->"Hyperlink"]
}], "Text",
  CellTags->{
  "1.", "2.", "2.1.", "2.2.", "2.3.", "3.", "4.", "4.1.", "4.2.", "4.3.", 
    "4.4.", "5.", "6.", "7.", "3.1.", "Vertices"}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["1.Introduction",
  ButtonData:>"1.",
  ButtonStyle->"Hyperlink"]], "Section",
  CellTags->"Introduction"],

Cell[TextData[{
  StyleBox["TuGames",
    FontSlant->"Italic"],
  " is a ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " package to determine and to check some game properties of transferable \
utility games. It provides about 70 different functions and it can calculate, \
for instance, kernel elements, excess payoffs, marginal values, the \
tau-value, and the vertices of a core. Moreover, it verifies if the game is \
convex, average-convex  or superadditive just to mention some interesting \
functions. This package is an extension of the package ",
  StyleBox["CooperativeGames",
    FontSlant->"Italic"],
  " that has been developed by ",
  ButtonBox["M. Carter",
    ButtonData:>"M. Carter",
    ButtonStyle->"Hyperlink"],
  ". It must be mentioned in this place that some commands of ",
  StyleBox["TuGames",
    FontSlant->"Italic"],
  " require routines that have been provided by the package ",
  StyleBox["CooperativeGames",
    FontSlant->"Italic"],
  ".  Therefore, you have also to install the package ",
  StyleBox["CooperativeGames",
    FontSlant->"Italic"],
  " to use the new functions properly. A description of the package ",
  StyleBox["CooperativeGames",
    FontSlant->"Italic"],
  " can be found in Economic and Financial Modeling with ",
  StyleBox["Mathematica,",
    FontSlant->"Italic"],
  " ed. ",
  ButtonBox["Hal. R. Varian",
    ButtonData:>"Hal R. Varian",
    ButtonStyle->"Hyperlink"],
  ", Telos  Springer Publisher,1993, Chapter 8. Furthermore, if one is \
interested in computing the vertices of a core the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " package ",
  StyleBox["VertexEnum",
    FontSlant->"Italic"],
  " written by ",
  ButtonBox["K. Fukuda",
    ButtonData:>"http://www.ifor.math.ethz.ch/staff/fukuda/fukuda.html",
    ButtonStyle->"Hyperlink"],
  " and I. Mizukoshi must also be installed on the computer.  But note that \
this function is very slow in computing all vertices of a core on old \
computers like Pentium II systems.  You can overcome these shortcomings of \
VertexEnum by installing the C-library cddmathlink written by the same \
authors to perform the same computational task more efficiently. It can be \
found under http://www.cs.mcgill.ca/ fukuda/ for various UNIX and forWindow \
systems. The library is linked via MathLink with the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Kernel. For Windows Operating Systems pre-build binaries are available \
and are included in the subdirectory cddml. Note that the functions that \
based on this library are not activated. To use these functions on your \
operating systems you must comment them out in the package TuGames. Moreover, \
you have to adjust the $Path variable where the library can be found. The \
default value is set to \"/usr/local/bin\" for UNIX systems. For changing \
this value edit the file ",
  StyleBox["TUGames",
    FontSlant->"Italic"],
  " with an editor of your choice and search for ",
  StyleBox["SetDirectory[]",
    FontWeight->"Bold"],
  ". The package ",
  StyleBox["TuGames",
    FontSlant->"Italic"],
  " can be used under Windows XP/2000/NT, MacOS and UNIX platforms running ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Version 3.0 or later. The author has tested the functions extensively \
under LINUX x86/64, HP-UX  and AIX. Furthermore, the package was also be \
installed and tested successfully under Windows XP. For Windows 2000/NT and \
Mac OS the author has no experience. But the programming language of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " is system independent, thus, there should no problems occur on these \
operating systems. "
}], "Text",
  CellFrame->{{0, 0}, {0, 0.5}},
  TextAlignment->Left,
  TextJustification->1,
  CellTags->{
  "http://www.ifor.math.ethz.ch/staff/fukuda/fukuda.html", "1993", "1993C"}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["2. Installation",
  ButtonData:>"2.",
  ButtonStyle->"Hyperlink"]], "Section",
  CellTags->"Installation"],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["2.1. Unix",
  ButtonData:>"2.1.",
  ButtonStyle->"Hyperlink"]], "Subsubsection",
  CellTags->"Unix"],

Cell[TextData[{
  "1. Create  a directory \"",
  StyleBox["TuGames",
    FontWeight->"Bold",
    FontVariations->{"CompatibilityType"->0}],
  "\" in your",
  StyleBox["  $HOME/.",
    FontWeight->"Bold"],
  StyleBox["Mathematica",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox["/3.0/AddOns/Applications",
    FontWeight->"Bold"],
  " directory. Copy now all files in the directory \"",
  StyleBox["TuGames",
    FontWeight->"Bold",
    FontVariations->{"CompatibilityType"->0}],
  "\", but for the file ",
  StyleBox["CooperativeGames.m",
    FontSlant->"Italic"],
  " create a subdirectory \"",
  StyleBox["coop",
    FontWeight->"Bold",
    FontVariations->{"CompatibilityType"->0}],
  "\" in ",
  StyleBox["TuGames",
    FontSlant->"Italic"],
  " and move the file in this subdirectory.\n2. Create the variable ",
  StyleBox["$TuGamesPath",
    FontWeight->"Bold"],
  " in the ",
  StyleBox["init.m",
    FontSlant->"Italic"],
  " file in your ",
  StyleBox["$HOME/.",
    FontWeight->"Bold"],
  StyleBox["Mathematica",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox["/3.0/Kernel",
    FontWeight->"Bold"],
  " directory. If no ",
  StyleBox["init.m",
    FontSlant->"Italic"],
  " file exists, create the file. Set this variable to\n",
  StyleBox["$TuGamesPath = \
$HomeDirectory<>\".Mathematica/3.0/AddOns/Applications/TuGames\"",
    FontWeight->"Bold"],
  "\n3. Add to the global variable ",
  StyleBox["$Path",
    FontWeight->"Bold"],
  " in the",
  StyleBox[" ",
    FontWeight->"Bold"],
  StyleBox["init.m",
    FontSlant->"Italic",
    FontVariations->{"CompatibilityType"->0}],
  " file the location of ",
  StyleBox["TuGames ",
    FontSlant->"Italic"],
  StyleBox["by",
    FontVariations->{"CompatibilityType"->0}],
  "\n",
  StyleBox["AppendTo[$Path, $TuGamesPath]",
    FontWeight->"Bold"],
  "\nNow you can start ",
  StyleBox["TuGames.",
    FontSlant->"Italic"]
}], "Text"],

Cell["\<\
Note that for UNIX/LINUX systems is also a graphical extension \
available. See also the remark at the end of the README file.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["2.2. Windows",
  ButtonData:>"2.2.",
  ButtonStyle->"Hyperlink"]], "Subsubsection",
  CellTags->"Windows"],

Cell[TextData[{
  "1. Create the directory \"",
  StyleBox["AddOns\\Applications\\TuGames",
    FontWeight->"Bold",
    FontVariations->{"CompatibilityType"->0}],
  "\" at the location where your ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " files are located.  This can be find out by typing\n",
  StyleBox["$TopDirectory",
    FontWeight->"Bold",
    FontVariations->{"CompatibilityType"->0}],
  "\nin your ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Notebook. \n2. Copy now all files in this directory. \n2.1 Create for the \
file ",
  StyleBox["CooperativeGames.m",
    FontSlant->"Italic"],
  " the subdirectory \"",
  StyleBox["coop",
    FontWeight->"Bold",
    FontVariations->{"CompatibilityType"->0}],
  "\" and move the file in this directory.\n2.2 Create for the file \
VertexEnum.m the subdirectory \"vertex\" and move the file in this directory. \
\n2.3 Create for the library cddml_w32new the subdirectory \"cddml\" and move \
the file in this directory.\n3. Create in your ",
  StyleBox["init.m",
    FontSlant->"Italic"],
  " file the variable ",
  StyleBox["$TuGamesPath",
    FontWeight->"Bold",
    FontVariations->{"CompatibilityType"->0}],
  " to locate the various packages. Set this variable to \n",
  StyleBox["$TuGamesPath = \
$TopDirectory<>\"\\\\AddOns\\\\Applications\\\\TuGames\"",
    FontWeight->"Bold",
    FontVariations->{"CompatibilityType"->0}],
  "\n4. Add to the variable ",
  StyleBox["$Path",
    FontWeight->"Bold"],
  " in the ",
  StyleBox["init.m",
    FontSlant->"Italic",
    FontVariations->{"CompatibilityType"->0}],
  " file the location of ",
  StyleBox["TuGames",
    FontSlant->"Italic"],
  "\n",
  StyleBox["AppendTo[$Path, $TuGamesPath]",
    FontWeight->"Bold"],
  "\nNote that the dopple backslash (\\\\) is important. A simple backslash \
is not suffient to set the directory path correctly.\nNow you can start ",
  StyleBox["TuGames. \n",
    FontSlant->"Italic"],
  "In cases that you have problems with the init.m file consult the README \
file."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["2.3. Mac OS ",
  ButtonData:>"2.3.",
  ButtonStyle->"Hyperlink"]], "Subsubsection",
  CellTags->"Mac OS"],

Cell["\<\
Sorry, but at the moment no installation instruction for Mac OS is \
available. \
\>", "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["3. Getting Started",
  ButtonData:>"3.",
  ButtonStyle->"Hyperlink"]], "Section",
  CellTags->"Getting Started"],

Cell["\<\
In the next step we assume that you have installed properly the \
files mentioned above on your computer. To start with the calculation, we \
have first to load some packages. This can be done by the following commands. \
\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Needs["\<coop`CooperativeGames`\>"]\), "\[IndentingNewLine]", 
    \(Needs["\<TuGames`\>"]\), "\[IndentingNewLine]", 
    \(Needs["\<VertexEnum`\>"]\)}], "Input"],

Cell[BoxData[
    \("==================================================="\)], "Print"],

Cell[BoxData[
    InterpretationBox[\("Loading Package 'TuGames' for \
"\[InvisibleSpace]"Unix"\),
      SequenceForm[ "Loading Package 'TuGames' for ", "Unix"],
      Editable->False]], "Print"],

Cell[BoxData[
    \("==================================================="\)], "Print"],

Cell[BoxData[
    \("TuGames V1.1 by Holger Meinhardt"\)], "Print"],

Cell[BoxData[
    \("Release Date: 25.07.2005"\)], "Print"],

Cell[BoxData[
    \("Program runs under Mathematica Version 3.0 or later"\)], "Print"],

Cell[BoxData[
    \("==================================================="\)], "Print"],

Cell[BoxData[
    \("==================================================="\)], "Print"],

Cell[BoxData[
    \("Package 'TuGames' loaded"\)], "Print"],

Cell[BoxData[
    \("==================================================="\)], "Print"]
}, Open  ]],

Cell["To get an overview of all available functions call just", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(funcname = Names["\<TuGames`*\>"]\)], "Input"],

Cell[BoxData[
    \({"AdjustedEffUpperVectors", "AdjustedEffVector", 
      "AdjustedWorthVectors", "AllConstraints", "AllMaxSurpluses", "Assign", 
      "AvConvexQ", "AvSumCheck", "BelongToCoreQ", "CallMaximize", 
      "CallMinimize", "CddGmpPlotCore", "CddGmpPlotImputationSet", 
      "CddGmpPlotLowerSet", "CddGmpPlotReasonableSet", "CddGmpVerticesCore", 
      "CddVerticesCore", "CddVerticesImputationSet", "CddVerticesLowerSet", 
      "CddVerticesReasonableSet", "ChangeInternalEps", "coal", "Concession", 
      "ContributionSum", "ConvCheck", "ConvexQ", "ConvexStrQ", 
      "ConvexUnanConditionQ", "ConvStrQ", "CoordS", "CoreElementsQ", 
      "DefineGame", "DeltaLP", "DigitPrecision", "DisagreeConvex", 
      "Disagreement", "DisplayAllResults", "DisplayMatrixForm", "DualGame", 
      "EpsCore", "EpsilonValue", "EpsValue", "EvalSumMinCoord", 
      "ExcessPayoff", "FifthCriticalVal", "FilledCore", "FindKernelSolution", 
      "FindPreKernelSolution", "FirstCriticalVal", "FourthCriticalVal", 
      "GameMonotoneQ", "Gap", "GrandCoalitionLargestValueQ", "ImputationQ", 
      "IncreasingMargContributions", "IntersectionOfMaxExcessSets", 
      "IntersectionUpperLowerSetQ", "kCover", "Kernel", "KernelCalculation", 
      "KernelImputationListQ", "KernelImputationQ", "KernelPoints", 
      "KernelRange", "KernelSubCall", "KernelSubCallEmpty", 
      "KernelSubCallZero", "KernelVertices", "LargestAmount", "LexiCenter", 
      "LowerSetIncImputationQ", "LowerSetQ", "MargValue", 
      "MaxExcessBalanced", "MaxExcessSets", "MaxSurplus", 
      "MinUnanimityCoordinates", "ModifiedKernel", "ModifiedNucleolus", 
      "MonotoneQ", "NewShapley", "Nuc1convex", "OneNormalization", 
      "PreKernelEqualsKernelQ", "PreKernelQ", "PreNucleolus", "ProperAmount", 
      "ProperContribution", "Quota", "RationalApproximate", "RationalExact", 
      "RationalTol", "ReasonableOutcome", "ReasonableSet", "Scrb", 
      "ScrbSolution", "SecondCriticalVal", "SecondStarCriticalVal", 
      "SelectSuperSets", "SetGameToNonZeroMonotonic", "SetRecursionLimit", 
      "Silent", "SmallestContribution", "SmallestContributionVector", 
      "StarCriticalVal", "StrictlyConvexUnanConditionQ", 
      "StrIncreasMargContrib", "SuperAdditiveQ", "TauValue", 
      "ThirdCriticalVal", "ThirdStarCriticalVal", "TIJsets", "Transfer", 
      "TransferConstraints", "UnanimityCoordinates", 
      "UpperSetIncImputationQ", "UpperSetQ", "UtopiaPayoff", "UtopiaSum", 
      "UtopiaVector", "Vec3DToSimplex", "VerticesCore", 
      "WeaklySuperAdditiveQ", "WeightedMajority", "WithIncidences", 
      "ZeroMonotoneQ", "ZeroNormalization", 
      "ZeroOneNormalization"}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "For getting a short listing of all available functions in the package ",
  StyleBox["TUGames",
    FontSlant->"Italic"],
  " type"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?TuGames`*\ \)\)], "Input"],

Cell[BoxData[GridBox[{
        {
          StyleBox["TuGames`",
            FontFamily->"Helvetica",
            FontSize->12,
            FontWeight->"Bold"]},
        {GridBox[{
              {
                ButtonBox[
                  StyleBox["AdjustedEffUpperVectors",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3331391289-8138305", 
                    "TuGames`AdjustedEffUpperVectors"},
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"], 
                ButtonBox[
                  StyleBox["Concession",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3331391289-8138305", 
                    "TuGames`Concession"},
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"], 
                ButtonBox[
                  StyleBox["FifthCriticalVal",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3331391289-8138305", 
                    "TuGames`FifthCriticalVal"},
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"], 
                ButtonBox[
                  StyleBox["KernelSubCallZero",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3331391289-8138305", 
                    "TuGames`KernelSubCallZero"},
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"], 
                ButtonBox[
                  StyleBox["Quota",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  ButtonData:>{"Info3331391289-8138305", "TuGames`Quota"},
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"], 
                ButtonBox[
                  StyleBox["ThirdStarCriticalVal",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3331391289-8138305", 
                    "TuGames`ThirdStarCriticalVal"},
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"]},
              {
                ButtonBox[
                  StyleBox["AdjustedEffVector",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3331391289-8138305", 
                    "TuGames`AdjustedEffVector"},
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"], 
                ButtonBox[
                  StyleBox["ContributionSum",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3331391289-8138305", 
                    "TuGames`ContributionSum"},
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"], 
                ButtonBox[
                  StyleBox["FilledCore",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3331391289-8138305", 
                    "TuGames`FilledCore"},
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"], 
                ButtonBox[
                  StyleBox["KernelVertices",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3331391289-8138305", 
                    "TuGames`KernelVertices"},
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"], 
                ButtonBox[
                  StyleBox["RationalApproximate",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3331391289-8138305", 
                    "TuGames`RationalApproximate"},
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"], 
                ButtonBox[
                  StyleBox["TIJsets",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  ButtonData:>{"Info3331391289-8138305", "TuGames`TIJsets"},
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"]},
              {
                ButtonBox[
                  StyleBox["AdjustedWorthVectors",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3331391289-8138305", 
                    "TuGames`AdjustedWorthVectors"},
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"], 
                ButtonBox[
                  StyleBox["ConvCheck",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  ButtonData:>{"Info3331391289-8138305", "TuGames`ConvCheck"},
                  
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"], 
                ButtonBox[
                  StyleBox["FindKernelSolution",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3331391289-8138305", 
                    "TuGames`FindKernelSolution"},
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"], 
                ButtonBox[
                  StyleBox["LargestAmount",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3331391289-8138305", 
                    "TuGames`LargestAmount"},
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"], 
                ButtonBox[
                  StyleBox["RationalExact",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3331391289-8138305", 
                    "TuGames`RationalExact"},
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"], 
                ButtonBox[
                  StyleBox["Transfer",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  ButtonData:>{"Info3331391289-8138305", "TuGames`Transfer"},
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"]},
              {
                ButtonBox[
                  StyleBox["AllConstraints",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3331391289-8138305", 
                    "TuGames`AllConstraints"},
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"], 
                ButtonBox[
                  StyleBox["ConvexQ",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  ButtonData:>{"Info3331391289-8138305", "TuGames`ConvexQ"},
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"], 
                ButtonBox[
                  StyleBox["FindPreKernelSolution",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3331391289-8138305", 
                    "TuGames`FindPreKernelSolution"},
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"], 
                ButtonBox[
                  StyleBox["LexiCenter",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3331391289-8138305", 
                    "TuGames`LexiCenter"},
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"], 
                ButtonBox[
                  StyleBox["RationalTol",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3331391289-8138305", 
                    "TuGames`RationalTol"},
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"], 
                ButtonBox[
                  StyleBox["TransferConstraints",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3331391289-8138305", 
                    "TuGames`TransferConstraints"},
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"]},
              {
                ButtonBox[
                  StyleBox["AllMaxSurpluses",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3331391289-8138305", 
                    "TuGames`AllMaxSurpluses"},
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"], 
                ButtonBox[
                  StyleBox["ConvexStrQ",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3331391289-8138305", 
                    "TuGames`ConvexStrQ"},
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"], 
                ButtonBox[
                  StyleBox["FirstCriticalVal",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3331391289-8138305", 
                    "TuGames`FirstCriticalVal"},
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"], 
                ButtonBox[
                  StyleBox["LowerSetIncImputationQ",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3331391289-8138305", 
                    "TuGames`LowerSetIncImputationQ"},
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"], 
                ButtonBox[
                  StyleBox["ReasonableOutcome",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3331391289-8138305", 
                    "TuGames`ReasonableOutcome"},
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"], 
                ButtonBox[
                  StyleBox["UnanimityCoordinates",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3331391289-8138305", 
                    "TuGames`UnanimityCoordinates"},
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"]},
              {
                ButtonBox[
                  StyleBox["Assign",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  ButtonData:>{"Info3331391289-8138305", "TuGames`Assign"},
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"], 
                ButtonBox[
                  StyleBox["ConvexUnanConditionQ",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3331391289-8138305", 
                    "TuGames`ConvexUnanConditionQ"},
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"], 
                ButtonBox[
                  StyleBox["FourthCriticalVal",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3331391289-8138305", 
                    "TuGames`FourthCriticalVal"},
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"], 
                ButtonBox[
                  StyleBox["LowerSetQ",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  ButtonData:>{"Info3331391289-8138305", "TuGames`LowerSetQ"},
                  
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"], 
                ButtonBox[
                  StyleBox["ReasonableSet",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3331391289-8138305", 
                    "TuGames`ReasonableSet"},
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"], 
                ButtonBox[
                  StyleBox["UpperSetIncImputationQ",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3331391289-8138305", 
                    "TuGames`UpperSetIncImputationQ"},
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"]},
              {
                ButtonBox[
                  StyleBox["AvConvexQ",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  ButtonData:>{"Info3331391289-8138305", "TuGames`AvConvexQ"},
                  
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"], 
                ButtonBox[
                  StyleBox["ConvStrQ",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  ButtonData:>{"Info3331391289-8138305", "TuGames`ConvStrQ"},
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"], 
                ButtonBox[
                  StyleBox["GameMonotoneQ",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  ButtonData:>{"Info3331391289-8138305", 
                    "TuGames`GameMonotoneQ"},
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"], 
                ButtonBox[
                  StyleBox["MargValue",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  ButtonData:>{"Info3331391289-8138305", "TuGames`MargValue"},
                  
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"], 
                ButtonBox[
                  StyleBox["Scrb",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  ButtonData:>{"Info3331391289-8138305", "TuGames`Scrb"},
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"], 
                ButtonBox[
                  StyleBox["UpperSetQ",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  ButtonData:>{"Info3331391289-8138305", "TuGames`UpperSetQ"},
                  
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"]},
              {
                ButtonBox[
                  StyleBox["AvSumCheck",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  ButtonData:>{"Info3331391289-8138305", 
                    "TuGames`AvSumCheck"},
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"], 
                ButtonBox[
                  StyleBox["CoordS",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  ButtonData:>{"Info3331391289-8138305", "TuGames`CoordS"},
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"], 
                ButtonBox[
                  StyleBox["Gap",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  ButtonData:>{"Info3331391289-8138305", "TuGames`Gap"},
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"], 
                ButtonBox[
                  StyleBox["MaxExcessBalanced",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3331391289-8138305", 
                    "TuGames`MaxExcessBalanced"},
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"], 
                ButtonBox[
                  StyleBox["ScrbSolution",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  ButtonData:>{"Info3331391289-8138305", 
                    "TuGames`ScrbSolution"},
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"], 
                ButtonBox[
                  StyleBox["UtopiaPayoff",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3331391289-8138305", 
                    "TuGames`UtopiaPayoff"},
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"]},
              {
                ButtonBox[
                  StyleBox["BelongToCoreQ",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3331391289-8138305", 
                    "TuGames`BelongToCoreQ"},
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"], 
                ButtonBox[
                  StyleBox["CoreElementsQ",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3331391289-8138305", 
                    "TuGames`CoreElementsQ"},
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"], 
                ButtonBox[
                  StyleBox["GrandCoalitionLargestValueQ",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3331391289-8138305", 
                    "TuGames`GrandCoalitionLargestValueQ"},
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"], 
                ButtonBox[
                  StyleBox["MaxExcessSets",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3331391289-8138305", 
                    "TuGames`MaxExcessSets"},
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"], 
                ButtonBox[
                  StyleBox["SecondCriticalVal",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3331391289-8138305", 
                    "TuGames`SecondCriticalVal"},
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"], 
                ButtonBox[
                  StyleBox["UtopiaSum",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  ButtonData:>{"Info3331391289-8138305", "TuGames`UtopiaSum"},
                  
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"]},
              {
                ButtonBox[
                  StyleBox["CallMaximize",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3331391289-8138305", 
                    "TuGames`CallMaximize"},
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"], 
                ButtonBox[
                  StyleBox["DefineGame",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3331391289-8138305", 
                    "TuGames`DefineGame"},
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"], 
                ButtonBox[
                  StyleBox["ImputationQ",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3331391289-8138305", 
                    "TuGames`ImputationQ"},
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"], 
                ButtonBox[
                  StyleBox["MaxSurplus",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3331391289-8138305", 
                    "TuGames`MaxSurplus"},
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"], 
                ButtonBox[
                  StyleBox["SecondStarCriticalVal",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3331391289-8138305", 
                    "TuGames`SecondStarCriticalVal"},
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"], 
                ButtonBox[
                  StyleBox["UtopiaVector",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3331391289-8138305", 
                    "TuGames`UtopiaVector"},
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"]},
              {
                ButtonBox[
                  StyleBox["CallMinimize",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3331391289-8138305", 
                    "TuGames`CallMinimize"},
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"], 
                ButtonBox[
                  StyleBox["DeltaLP",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  ButtonData:>{"Info3331391289-8138305", "TuGames`DeltaLP"},
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"], 
                ButtonBox[
                  StyleBox["IncreasingMargContributions",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3331391289-8138305", 
                    "TuGames`IncreasingMargContributions"},
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"], 
                ButtonBox[
                  StyleBox["MinUnanimityCoordinates",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3331391289-8138305", 
                    "TuGames`MinUnanimityCoordinates"},
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"], 
                ButtonBox[
                  StyleBox["SelectSuperSets",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3331391289-8138305", 
                    "TuGames`SelectSuperSets"},
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"], 
                ButtonBox[
                  StyleBox["Vec3DToSimplex",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3331391289-8138305", 
                    "TuGames`Vec3DToSimplex"},
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"]},
              {
                ButtonBox[
                  StyleBox["CddGmpPlotCore",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3331391289-8138305", 
                    "TuGames`CddGmpPlotCore"},
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"], 
                ButtonBox[
                  StyleBox["DigitPrecision",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3331391289-8138305", 
                    "TuGames`DigitPrecision"},
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"], 
                ButtonBox[
                  StyleBox["IntersectionOfMaxExcessSets",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3331391289-8138305", 
                    "TuGames`IntersectionOfMaxExcessSets"},
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"], 
                ButtonBox[
                  StyleBox["ModifiedKernel",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3331391289-8138305", 
                    "TuGames`ModifiedKernel"},
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"], 
                ButtonBox[
                  StyleBox["SetGameToNonZeroMonotonic",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3331391289-8138305", 
                    "TuGames`SetGameToNonZeroMonotonic"},
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"], 
                ButtonBox[
                  StyleBox["VerticesCore",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3331391289-8138305", 
                    "TuGames`VerticesCore"},
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"]},
              {
                ButtonBox[
                  StyleBox["CddGmpPlotImputationSet",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3331391289-8138305", 
                    "TuGames`CddGmpPlotImputationSet"},
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"], 
                ButtonBox[
                  StyleBox["DisagreeConvex",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3331391289-8138305", 
                    "TuGames`DisagreeConvex"},
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"], 
                ButtonBox[
                  StyleBox["IntersectionUpperLowerSetQ",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3331391289-8138305", 
                    "TuGames`IntersectionUpperLowerSetQ"},
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"], 
                ButtonBox[
                  StyleBox["ModifiedNucleolus",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3331391289-8138305", 
                    "TuGames`ModifiedNucleolus"},
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"], 
                ButtonBox[
                  StyleBox["SetRecursionLimit",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3331391289-8138305", 
                    "TuGames`SetRecursionLimit"},
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"], 
                ButtonBox[
                  StyleBox["WeaklySuperAdditiveQ",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3331391289-8138305", 
                    "TuGames`WeaklySuperAdditiveQ"},
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"]},
              {
                ButtonBox[
                  StyleBox["CddGmpPlotLowerSet",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3331391289-8138305", 
                    "TuGames`CddGmpPlotLowerSet"},
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"], 
                ButtonBox[
                  StyleBox["Disagreement",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3331391289-8138305", 
                    "TuGames`Disagreement"},
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"], 
                ButtonBox[
                  StyleBox["kCover",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  ButtonData:>{"Info3331391289-8138305", "TuGames`kCover"},
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"], 
                ButtonBox[
                  StyleBox["MonotoneQ",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  ButtonData:>{"Info3331391289-8138305", "TuGames`MonotoneQ"},
                  
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"], 
                ButtonBox[
                  StyleBox["Silent",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  ButtonData:>{"Info3331391289-8138305", "TuGames`Silent"},
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"], 
                ButtonBox[
                  StyleBox["WeightedMajority",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3331391289-8138305", 
                    "TuGames`WeightedMajority"},
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"]},
              {
                ButtonBox[
                  StyleBox["CddGmpPlotReasonableSet",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3331391289-8138305", 
                    "TuGames`CddGmpPlotReasonableSet"},
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"], 
                ButtonBox[
                  StyleBox["DisplayAllResults",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3331391289-8138305", 
                    "TuGames`DisplayAllResults"},
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"], 
                ButtonBox[
                  StyleBox["Kernel",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  ButtonData:>{"Info3331391289-8138305", "TuGames`Kernel"},
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"], 
                ButtonBox[
                  StyleBox["NewShapley",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3331391289-8138305", 
                    "TuGames`NewShapley"},
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"], 
                ButtonBox[
                  StyleBox["SmallestContribution",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3331391289-8138305", 
                    "TuGames`SmallestContribution"},
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"], 
                ButtonBox[
                  StyleBox["WithIncidences",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3331391289-8138305", 
                    "TuGames`WithIncidences"},
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"]},
              {
                ButtonBox[
                  StyleBox["CddGmpVerticesCore",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3331391289-8138305", 
                    "TuGames`CddGmpVerticesCore"},
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"], 
                ButtonBox[
                  StyleBox["DisplayMatrixForm",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3331391289-8138305", 
                    "TuGames`DisplayMatrixForm"},
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"], 
                ButtonBox[
                  StyleBox["KernelCalculation",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3331391289-8138305", 
                    "TuGames`KernelCalculation"},
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"], 
                ButtonBox[
                  StyleBox["Nuc1convex",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3331391289-8138305", 
                    "TuGames`Nuc1convex"},
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"], 
                ButtonBox[
                  StyleBox["SmallestContributionVector",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3331391289-8138305", 
                    "TuGames`SmallestContributionVector"},
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"], 
                ButtonBox[
                  StyleBox["ZeroMonotoneQ",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3331391289-8138305", 
                    "TuGames`ZeroMonotoneQ"},
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"]},
              {
                ButtonBox[
                  StyleBox["CddVerticesCore",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3331391289-8138305", 
                    "TuGames`CddVerticesCore"},
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"], 
                ButtonBox[
                  StyleBox["DualGame",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  ButtonData:>{"Info3331391289-8138305", "TuGames`DualGame"},
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"], 
                ButtonBox[
                  StyleBox["KernelImputationListQ",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3331391289-8138305", 
                    "TuGames`KernelImputationListQ"},
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"], 
                ButtonBox[
                  StyleBox["OneNormalization",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3331391289-8138305", 
                    "TuGames`OneNormalization"},
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"], 
                ButtonBox[
                  StyleBox["StarCriticalVal",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3331391289-8138305", 
                    "TuGames`StarCriticalVal"},
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"], 
                ButtonBox[
                  StyleBox["ZeroNormalization",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3331391289-8138305", 
                    "TuGames`ZeroNormalization"},
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"]},
              {
                ButtonBox[
                  StyleBox["CddVerticesImputationSet",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3331391289-8138305", 
                    "TuGames`CddVerticesImputationSet"},
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"], 
                ButtonBox[
                  StyleBox["EpsCore",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  ButtonData:>{"Info3331391289-8138305", "TuGames`EpsCore"},
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"], 
                ButtonBox[
                  StyleBox["KernelImputationQ",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3331391289-8138305", 
                    "TuGames`KernelImputationQ"},
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"], 
                ButtonBox[
                  StyleBox["PreKernelEqualsKernelQ",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3331391289-8138305", 
                    "TuGames`PreKernelEqualsKernelQ"},
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"], 
                ButtonBox[
                  StyleBox["StrictlyConvexUnanConditionQ",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3331391289-8138305", 
                    "TuGames`StrictlyConvexUnanConditionQ"},
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"], 
                ButtonBox[
                  StyleBox["ZeroOneNormalization",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3331391289-8138305", 
                    "TuGames`ZeroOneNormalization"},
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"]},
              {
                ButtonBox[
                  StyleBox["CddVerticesLowerSet",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3331391289-8138305", 
                    "TuGames`CddVerticesLowerSet"},
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"], 
                ButtonBox[
                  StyleBox["EpsilonValue",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3331391289-8138305", 
                    "TuGames`EpsilonValue"},
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"], 
                ButtonBox[
                  StyleBox["KernelPoints",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3331391289-8138305", 
                    "TuGames`KernelPoints"},
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"], 
                ButtonBox[
                  StyleBox["PreKernelQ",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3331391289-8138305", 
                    "TuGames`PreKernelQ"},
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"], 
                ButtonBox[
                  StyleBox["StrIncreasMargContrib",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3331391289-8138305", 
                    "TuGames`StrIncreasMargContrib"},
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"], ""},
              {
                ButtonBox[
                  StyleBox["CddVerticesReasonableSet",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3331391289-8138305", 
                    "TuGames`CddVerticesReasonableSet"},
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"], 
                ButtonBox[
                  StyleBox["EpsValue",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  ButtonData:>{"Info3331391289-8138305", "TuGames`EpsValue"},
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"], 
                ButtonBox[
                  StyleBox["KernelRange",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3331391289-8138305", 
                    "TuGames`KernelRange"},
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"], 
                ButtonBox[
                  StyleBox["PreNucleolus",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3331391289-8138305", 
                    "TuGames`PreNucleolus"},
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"], 
                ButtonBox[
                  StyleBox["SuperAdditiveQ",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3331391289-8138305", 
                    "TuGames`SuperAdditiveQ"},
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"], ""},
              {
                ButtonBox[
                  StyleBox["ChangeInternalEps",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3331391289-8138305", 
                    "TuGames`ChangeInternalEps"},
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"], 
                ButtonBox[
                  StyleBox["EvalSumMinCoord",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3331391289-8138305", 
                    "TuGames`EvalSumMinCoord"},
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"], 
                ButtonBox[
                  StyleBox["KernelSubCall",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3331391289-8138305", 
                    "TuGames`KernelSubCall"},
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"], 
                ButtonBox[
                  StyleBox["ProperAmount",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3331391289-8138305", 
                    "TuGames`ProperAmount"},
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"], 
                ButtonBox[
                  StyleBox["TauValue",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  ButtonData:>{"Info3331391289-8138305", "TuGames`TauValue"},
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"], ""},
              {
                ButtonBox[
                  StyleBox["coal",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  ButtonData:>{"Info3331391289-8138305", "TuGames`coal"},
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"], 
                ButtonBox[
                  StyleBox["ExcessPayoff",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3331391289-8138305", 
                    "TuGames`ExcessPayoff"},
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"], 
                ButtonBox[
                  StyleBox["KernelSubCallEmpty",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3331391289-8138305", 
                    "TuGames`KernelSubCallEmpty"},
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"], 
                ButtonBox[
                  StyleBox["ProperContribution",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3331391289-8138305", 
                    "TuGames`ProperContribution"},
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"], 
                ButtonBox[
                  StyleBox["ThirdCriticalVal",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3331391289-8138305", 
                    "TuGames`ThirdCriticalVal"},
                  ButtonFrame->"None",
                  ButtonNote->"TuGames`"], ""}
              },
            
            RowMinHeight->{
              1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 
                1.05}]}
        },
      RowSpacings->{2, 3},
      ColumnsEqual->True]], "Print",
  CellMargins->{{20, Inherited}, {Inherited, Inherited}},
  ShowCellLabel->False,
  CellFrameMargins->{{Inherited, Inherited}, {14, 14}},
  Background->RGBColor[0.964706, 0.929412, 0.839216],
  ButtonBoxOptions->{Active->True},
  GridBoxOptions->{ColumnAlignments->{Left}}]
}, Open  ]],

Cell["\<\
Just click with your mouse pointer on the functions name to get a \
short description how to use it.  \
\>", "Text"],

Cell[BoxData[
    \("ConvexQ[game] checks if the Tu-game is convex.\n  It returns the value \
'True' or 'False'."\)], "Print",
  CellTags->"Info3264939207-8254035"],

Cell["\<\
To obtain a brief documentation about individual functions type \
\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?TuGames`ConvexQ\)\)], "Input"],

Cell[BoxData[
    \("ConvexQ[game] checks if the Tu-game is convex. It returns the value \
'True' or 'False'."\)], "Print",
  CellTags->"Info3331391299-1787670"]
}, Open  ]],

Cell[TextData[{
  "if you are interested in a specific function name like",
  StyleBox[" ConvexQ[]",
    FontWeight->"Bold"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["3.1. How to define Games?",
  ButtonData:>"3.1.",
  ButtonStyle->"Hyperlink"]], "Subsubsection",
  CellTags->"How to define Games?"],

Cell[TextData[{
  "Note first that in the sequel we indicate the whole player set in the \
commands with the symbol  ",
  StyleBox["T",
    FontSlant->"Italic"],
  " instead of ",
  StyleBox["N. ",
    FontSlant->"Italic"],
  "We must deviate from the general game theoretical convention, since under \
",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " the symbol ",
  StyleBox["N",
    FontSlant->"Italic"],
  " is already occupied by the built-in function ",
  StyleBox["N[] ",
    FontWeight->"Bold"],
  "to evaluate an expression numerically. Whereas in the definitions and \
results we use the symbol ",
  StyleBox["N",
    FontSlant->"Italic"],
  " in the usual convention. \nWe can define a game in two different ways. \
The first one is the way as it was implemented by ",
  ButtonBox["Carter",
    ButtonData:>"M. Carter",
    ButtonStyle->"Hyperlink"],
  " in his ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " package ",
  StyleBox["CooperativeGames",
    FontSlant->"Italic"],
  ". This procedure becomes very inconvenient for large games. The package ",
  StyleBox["TuGames",
    FontSlant->"Italic"],
  " provides, in addition, the function ",
  StyleBox["DefineGame[]",
    FontWeight->"Bold"],
  " to assign the values of the characteristic function for large games. Let \
us now present the representation of a TU-game used by ",
  ButtonBox["Carter",
    ButtonData:>"M. Carter",
    ButtonStyle->"Hyperlink"],
  ". The values of the characteristic function are assigned by"
}], "Text",
  TextJustification->1,
  CellTags->"DefineGame"],

Cell[BoxData[
    \(ExpGame1 := \((T = {1, 2, 3, 4}; 
        Clear[v]; \[IndentingNewLine]v[{}] = 0; \[IndentingNewLine]v[{1}] = 
          0; \[IndentingNewLine]v[{2}] = 0; \[IndentingNewLine]v[{3}] = 
          0; \[IndentingNewLine]v[{4}] = 0; \[IndentingNewLine]v[{1, 2}] = 
          0; \[IndentingNewLine]v[{1, 3}] = 0; \[IndentingNewLine]v[{1, 4}] = 
          0; \[IndentingNewLine]v[{2, 3}] = 0; \[IndentingNewLine]v[{2, 4}] = 
          0; \[IndentingNewLine]v[{3, 4}] = 
          0; \[IndentingNewLine]v[{1, 2, 3}] = 
          40; \[IndentingNewLine]v[{1, 2, 4}] = 
          0; \[IndentingNewLine]v[{1, 3, 4}] = 
          40; \[IndentingNewLine]v[{2, 3, 4}] = 0; v[T] = 90;)\)\)], "Input"],

Cell[TextData[{
  "To call the function ",
  StyleBox["DefineGame[]",
    FontWeight->"Bold"],
  " we define in a first step the player set and create a vector with zeros \
of length ",
  Cell[BoxData[
      \(TraditionalForm\`2\^n\)]],
  ". "
}], "Text"],

Cell[BoxData[{
    \(\(T2 = {1, 2, 3, 4};\)\), "\[IndentingNewLine]", 
    \(\(vec2 = Table[0, {i, 16}];\)\)}], "Input"],

Cell[TextData[{
  "Then we can assign positive values to some or all coalitions. It is also \
possible to assign coalition values directly to the vector, but in this case \
you have to know the exact order how the components of the vector are \
assigned to the coalitions. Note that you should not assign negative or \
floating point values to the coalitions. The commands in the package ",
  StyleBox["TuGames",
    FontSlant->"Italic"],
  " require nonnegative  or rational numbers for the coalitional values to \
perform the computational task correctly.  For instance, if you use floating \
point numbers some functions can run into an infinite loop and never \
terminate. In this case choose from the menu ",
  StyleBox["Kernel",
    FontWeight->"Bold"],
  " ",
  StyleBox["->",
    FontWeight->"Bold"],
  "  ",
  StyleBox["Abort Evaluation",
    FontWeight->"Bold"],
  "."
}], "Text",
  TextJustification->1],

Cell[BoxData[
    \(\(ExpGame2 := \((DefineGame[T2, vec2]; v[{1, 2, 3}] = 40; 
          v[{1, 3, 4}] = 40; v[T] = 90;)\);\)\)], "Input"],

Cell[TextData[{
  "Here is an example with five players. The example is borrowed from ",
  ButtonBox["Maschler, Peleg and Shapley",
    ButtonData:>"M. Maschler",
    ButtonStyle->"Hyperlink"],
  " (1979) (cf. p. 317)."
}], "Text",
  CellTags->"(1979)"],

Cell[BoxData[{
    \(\(T3 = {1, 2, 3, 4, 5};\)\), "\[IndentingNewLine]", 
    \(\(vec3 = Table[0, {i, 32}];\)\)}], "Input"],

Cell[BoxData[
    \(\(ExpGame3 := \((DefineGame[T3, vec3]; v[{1, 2, 4}] = 4; 
          v[{1, 2, 5}] = 4; v[{1, 3, 4}] = 4; v[{1, 3, 5}] = 4; 
          v[{2, 3, 4}] = 4; v[{2, 3, 5}] = 4; v[{4, 5}] = 4; 
          v[T] = 7;)\);\)\)], "Input"],

Cell["Next an average-convex  game:", "Text"],

Cell[BoxData[
    \(\(ExpGame4 := \((DefineGame[T2, vec2]; v[{1, 2}] = 1\/4; 
          v[{1, 4}] = 1\/4; v[{2, 3}] = 1\/4; v[{3, 4}] = 3\/8; 
          v[{1, 2, 3}] = 1\/2; v[{1, 2, 4}] = 1\/2; v[{1, 3, 4}] = 1\/2; 
          v[{2, 3, 4}] = 1\/2; v[T] = 1;)\);\)\)], "Input"],

Cell[TextData[{
  "Note that we have just assigned the values to the characteristic \
functions, but these values are at the moment not evaluated. Since under the \
operator \":=\" the right hand side, that means, in our case the game, is \
maintained in an unevaluated form. The game is at that moment evaluated when \
a function is invoked that requires as an input the pattern ",
  StyleBox["game_name, ",
    FontSlant->"Italic"],
  " that is, in the case that the left hand expression ",
  StyleBox["game_name",
    FontSlant->"Italic"],
  " appears, it is replaced by the right hand expression, the game.",
  StyleBox[" ",
    FontSlant->"Italic"],
  " To see that at the moment no game is really evaluated type "
}], "Text",
  TextJustification->1],

Cell[CellGroupData[{

Cell[BoxData[
    \(?? v\)], "Input"],

Cell[BoxData[
    \("v[S] describes the worth of coalition S"\)], "Print",
  CellTags->"Info3331391315-5722292"]
}, Open  ]],

Cell[TextData[{
  "Due to the fact that nothing is evaluated at the moment you get a short \
function description back. Problems encountered with the operator \":=\" in \
the context of our package is briefly discussed in ",
  ButtonBox["Section 6",
    ButtonData:>"Concluding Remarks and Limitations",
    ButtonStyle->"Hyperlink"],
  ". "
}], "Text",
  TextJustification->1]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["4. Some Functions",
  ButtonData:>"4.",
  ButtonStyle->"Hyperlink"]], "Section",
  CellTags->"Some Functions"],

Cell[TextData[{
  "In this section we will discuss some basic functions provided by ",
  StyleBox["TuGames",
    FontSlant->"Italic"],
  " to examine some game properties like convexity, average-convexity, \
superadditvity, monotonicity and zero-monotonicity. Furthermore, ",
  StyleBox["TuGames",
    FontSlant->"Italic"],
  " will also enable us to evaluated solutions of a game like the Shapley \
value, tau-value  or the kernel.  In the sequel of the section we will \
discuss as well functions related to the notion of ",
  StyleBox["k",
    FontSlant->"Italic"],
  "-convexity and unanimity coordinates. At this place some remarks are \
required concerning the presentation of the material in this notebook. The \
purpose of this notebook is to give the potential user a short description at \
hand how to use the new commands related to transferable utility games \
correctly. We will not embed the descriptions of the commands in a thorough \
game theoretical presentation of definitions and results on which the \
commands are based on. We just introduce definitions and results in cases \
where it is according to our opinion useful to do so. This is done to mention \
differences between functions that do ostensible the same or where we have \
used special results in our functions that are not quite common. In addition, \
we will also dispense from any code presentation and discussion. Users \
interested in this material should examine and try out for themselves the \
code presented in the package ",
  StyleBox["TuGames",
    FontSlant->"Italic"],
  ". Moreover, we assume that users bring along good knowledge in cooperative \
game theory to asses the results correctly in a game theoretical context. \
Nevertheless, we hope that the package might be useful for research as well \
as for teaching purpose in constructing examples in both of these fields. \
Certainly, it is assumed that users have some experience with ",
  StyleBox["Mathematica, ",
    FontSlant->"Italic"],
  "but it is not a prerequisite for the use of the package."
}], "Text",
  TextJustification->1],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["4.1. Basic Functions",
  ButtonData:>"4.1.",
  ButtonStyle->"Hyperlink"]], "Subsubsection",
  FontSize->16,
  CellTags->"Basic Functions"],

Cell[TextData[{
  "In general, functions are invoked by the function name and its arguments, \
in most cases a function needs as an input argument the ",
  StyleBox["game_name",
    FontSlant->"Italic"],
  ", a list of imputations (payoffs), a set of coalitions or a player from \
the player set. To make the point more precise let us first start with some \
functions that need just one argument to examine some well known game \
properties. The function that examines the convexity condition of the game is \
called ",
  StyleBox["ConvexQ[]",
    FontWeight->"Bold"],
  " and it needs just one ",
  "argument",
  ", namely the ",
  StyleBox["game_name",
    FontSlant->"Italic"],
  " to perform the necessary calculations to check on this game property. We \
can verify convexity by invoking"
}], "Text",
  TextJustification->1],

Cell[CellGroupData[{

Cell[BoxData[
    \(ConvexQ[ExpGame1]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ConvexQ[ExpGame2]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ConvexQ[ExpGame3]\)], "Input"],

Cell[BoxData[
    \(False\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ConvexQ[ExpGame4]\)], "Input"],

Cell[BoxData[
    \(False\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Additionally to the possibility to check whether a game is convex, we are \
also able to examine with the command ",
  StyleBox["AvConvexQ[]",
    FontWeight->"Bold"],
  " a generalized convexity property, the so-called  average convexity. \
Since, average-convexity generalize convexity it should be clear that \
convexity implies average-convexity, but the converse is not true. The \
property of average-convexity has been introduced by ",
  ButtonBox["Inarra and Usategui ",
    ButtonData:>"E. Inarra",
    ButtonStyle->"Hyperlink"],
  "(1993) in the literature. Before we will discuss this command note first \
that average-convexity  is defined as follows"
}], "Text",
  TextJustification->1,
  CellTags->"(1993)"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Sum]\_\(\(i\)\(\ \)\(\[Element]\)\(S\)\(\ \)\)\([v(
                S)\  - v(
                S\\i)]\)\ \ \  \[LessEqual] \ \(\(\[Sum]\_\(\(i\)\(\ \)\(\
\[Element]\)\(S\)\(\ \)\)\)\([v(R) - v(R\\i)]\)\(\ \ \ \ \)\)\)]],
  "for all ",
  Cell[BoxData[
      \(TraditionalForm\`S\  \[SubsetEqual] \ R\  \[SubsetEqual] \ N, \ 
      S\  \[NotEqual] \(\(\[Phi]\)\(.\)\(\ \ \)\)\)]]
}], "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "Similar to the function",
  StyleBox[" ConvexQ[]",
    FontWeight->"Bold"],
  " the function ",
  StyleBox["AvConvexQ[]",
    FontWeight->"Bold"],
  " that test the average-convexity  condition of the game is called with one \
",
  "argument",
  ", the ",
  StyleBox["game_name",
    FontSlant->"Italic"],
  ".  Hence, we need just to type"
}], "Text",
  TextJustification->1],

Cell[CellGroupData[{

Cell[BoxData[
    \(AvConvexQ[ExpGame1]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(AvConvexQ[ExpGame2]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(AvConvexQ[ExpGame3]\)], "Input"],

Cell[BoxData[
    \(False\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(AvConvexQ[ExpGame4]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell["Superadditivity can be checked by ", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(SuperAdditiveQ[ExpGame1]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(SuperAdditiveQ[ExpGame2]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(SuperAdditiveQ[ExpGame3]\)], "Input"],

Cell[BoxData[
    \(False\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(SuperAdditiveQ[ExpGame4]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Let the coalitions ",
  Cell[BoxData[
      \(TraditionalForm\`S\_1,  ... , S\_k\)]],
  "  partition the grand coalition ",
  StyleBox["T",
    FontSlant->"Italic"],
  ".  A necessary condition for the core ",
  StyleBox["C(v)",
    FontSlant->"Italic"],
  " of a game ",
  StyleBox["v",
    FontSlant->"Italic"],
  " to be nonempty is that the condition"
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\[Sum]\+\(i = 1\)\%k v(S\_i)\  \[LessEqual] \ 
      v(N)\)]]], "Text",
  TextAlignment->Center],

Cell[TextData[{
  "is satisfied. This property is captured by the function ",
  StyleBox["WeaklySuperAdditiveQ[].",
    FontWeight->"Bold"]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(WeaklySuperAdditiveQ[ExpGame1]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(WeaklySuperAdditiveQ[ExpGame2]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(WeaklySuperAdditiveQ[ExpGame3]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(WeaklySuperAdditiveQ[ExpGame4]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Certainly, we can also verify on monotonicity and zero-monotonicity  of \
the game. The commands are ",
  StyleBox["GameMonotoneQ[],",
    FontWeight->"Bold"],
  " ",
  StyleBox["MonotoneQ[]",
    FontWeight->"Bold"],
  " and ",
  StyleBox["ZeroMonotoneQ[]",
    FontWeight->"Bold"],
  "."
}], "Text",
  TextJustification->1],

Cell[CellGroupData[{

Cell[BoxData[
    \(GameMonotoneQ[ExpGame1]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(MonotoneQ[ExpGame1]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ZeroMonotoneQ[ExpGame1]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(GameMonotoneQ[ExpGame2]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(MonotoneQ[ExpGame2]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ZeroMonotoneQ[ExpGame2]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(GameMonotoneQ[ExpGame3]\)], "Input"],

Cell[BoxData[
    \(False\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(MonotoneQ[ExpGame3]\)], "Input"],

Cell[BoxData[
    \(False\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ZeroMonotoneQ[ExpGame3]\)], "Input"],

Cell[BoxData[
    \(False\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(GameMonotoneQ[ExpGame4]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(MonotoneQ[ExpGame4]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "To demonstrate that the package ",
  StyleBox["TuGames",
    FontSlant->"Italic"],
  " works properly together with ",
  StyleBox["CooperativeGames",
    FontSlant->"Italic"],
  " let us now call the command ",
  StyleBox["CoreQ[]",
    FontWeight->"Bold"],
  " written by ",
  ButtonBox["Carter",
    ButtonData:>"M. Carter",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(CoreQ[ExpGame1]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(CoreQ[ExpGame2]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(CoreQ[ExpGame3]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(CoreQ[ExpGame4]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell["Now determine the quotas of the games", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Quota[ExpGame1]\)], "Input"],

Cell[BoxData[
    \({80\/3, \(-\(40\/3\)\), 80\/3, \(-\(40\/3\)\)}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Quota[ExpGame2]\)], "Input"],

Cell[BoxData[
    \({80\/3, \(-\(40\/3\)\), 80\/3, \(-\(40\/3\)\)}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Quota[ExpGame3]\)], "Input"],

Cell[BoxData[
    \({0, 0, 0, 0, 0}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Quota[ExpGame4]\)], "Input"],

Cell[BoxData[
    \({1\/6, 1\/6, 1\/6, 1\/6}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["4.2 k-convexity",
  ButtonData:>"4.2.",
  ButtonStyle->"Hyperlink"]], "Subsubsection",
  FontSize->16,
  CellTags->"k-convexity"],

Cell[TextData[{
  StyleBox["In this section we present some basic functions related to the \
notion of ",
    FontVariations->{"CompatibilityType"->0}],
  StyleBox["k",
    FontSlant->"Italic",
    FontVariations->{"CompatibilityType"->0}],
  StyleBox["-convexity  that has been introduced by ",
    FontVariations->{"CompatibilityType"->0}],
  ButtonBox["Driessen",
    ButtonData:>"Theo Driessen",
    ButtonStyle->"Hyperlink"],
  StyleBox[". The usefulness of this notion stems from the fact that TU-games \
 with this property having similar properties like convex games, although \
convexity does not imply ",
    FontVariations->{"CompatibilityType"->0}],
  StyleBox["k",
    FontSlant->"Italic",
    FontVariations->{"CompatibilityType"->0}],
  StyleBox["-convexity, and the converse is also not true in general. There \
is just a small subclass of games that satisfy both properties, for instance, \
bankruptcy games are convex as well as ",
    FontVariations->{"CompatibilityType"->0}],
  StyleBox["k",
    FontSlant->"Italic",
    FontVariations->{"CompatibilityType"->0}],
  StyleBox["-convex. The package ",
    FontVariations->{"CompatibilityType"->0}],
  StyleBox["TuGames ",
    FontSlant->"Italic"],
  "provides some useful functions to determine properties of ",
  StyleBox["k",
    FontSlant->"Italic"],
  "-convex  games. To demonstrate some of these functions, let us define to \
this end four new games. The first three games have been borrowed from ",
  ButtonBox["Driessen",
    ButtonData:>"Theo Driessen",
    ButtonStyle->"Hyperlink"],
  " (1988), whereas two of them are 2-convex ( Exp. 4.5 on page 198 and Exp \
5.3 on page 202) and one of them is 1-convex \"",
  StyleBox["ExpGame7",
    FontSlant->"Italic"],
  "\" (cf. Exp. 5.6 on page 75). The last game presented in the series below \
is discussed in ",
  ButtonBox["Meinhardt",
    ButtonData:>"H. Meinhardt",
    ButtonStyle->"Hyperlink"],
  " (2002) and satisfies also the property of 2-convexity."
}], "Text",
  TextJustification->1,
  CellTags->{"(1988)", "(2002a)"}],

Cell[BoxData[
    \(\(ExpGame5 := \((DefineGame[T2, Table[0, {i, 2^Length[T2]}]]; 
          v[{1, 2}] = \(v[{1, 3}] = 1\); v[{2, 3}] = 4; \ v[{2, 4}] = \ 6; 
          v[{1, 4}] = 3; v[{3, 4}] = \ 7; \ v[{1, 2, 3}] = 9; 
          v[{1, 2, 4}] = 12; v[{\ 1, 3, 4}] = \ 13; v[{2, 3, 4}] = 15; 
          v[T] = 20;)\);\)\)], "Input"],

Cell[BoxData[
    \(\(ExpGame6 := \((DefineGame[T2, Table[0, {i, 2^Length[T2]}]]; 
          v[{1, 2, 
                3}] = \(v[{1, 2, 4}] = \(v[{1, 3, 4}] = \(v[{2, 3, 4}] = 
                  3\)\)\); v[T] = 5;)\);\)\)], "Input"],

Cell[BoxData[{
    \(\(T4 = {1, 2, 3};\)\), "\[IndentingNewLine]", 
    \(\(vec4 = Table[0, {i, 2^Length[T4]}];\)\)}], "Input"],

Cell[BoxData[
    \(\(ExpGame7 := \((DefineGame[T4, Table[0, {i, 2^Length[T4]}]]; 
          v[{2}] = \(v[{3}] = 6\); v[{1, 2}] = \(v[{1, 3}] = 9\); 
          v[{2, 3}] = 15; v[T] = 18;)\);\)\)], "Input"],

Cell[TextData[{
  "As mentioned above you could assign the values of the characteristic \
function directly by constructing a vector of length ",
  Cell[BoxData[
      \(TraditionalForm\`2\^n\)]],
  "simply by"
}], "Text"],

Cell[BoxData[
    \(\(coalval = {0, 26.7, 26.7, 26.7, 26.7, 800\/3, 800\/3, 800\/3, 800\/3, 
          800\/3, 800\/3, 1600\/3, 1600\/3, 1600\/3, 1600\/3, 
          800};\)\)], "Input"],

Cell["The order of the coalitions is obtained by the functions", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Subsets[T2]\)], "Input"],

Cell[BoxData[
    \({{}, {1}, {2}, {3}, {4}, {1, 2}, {1, 3}, {1, 4}, {2, 3}, {2, 4}, {3, 
        4}, {1, 2, 3}, {1, 2, 4}, {1, 3, 4}, {2, 3, 4}, {1, 2, 3, 
        4}}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "To define a game you need no more than the player set ",
  StyleBox["T2",
    FontSlant->"Italic"],
  " and the vector of the values of the game, that is, ",
  StyleBox["coalval",
    FontSlant->"Italic"],
  ". "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Options[DefineGame]\)], "Input"],

Cell[BoxData[
    \({RationalApproximate \[Rule] True}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(ExpGame8 := \((DefineGame[T2, coalval])\);\)\)], "Input"],

Cell["\<\
Let us first check whether some of them have an empty or non-empty  \
core.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(CoreQ[ExpGame5]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(CoreQ[ExpGame6]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Let ",
  StyleBox["k \[Epsilon] ",
    FontSlant->"Italic"],
  StyleBox["\[DoubleStruckCapitalN]",
    FontVariations->{"CompatibilityType"->0}],
  ". Note that an  ",
  StyleBox["n",
    FontSlant->"Italic"],
  "-person  game ",
  Cell[BoxData[
      \(TraditionalForm\`v\_k\)]],
  " is called the ",
  StyleBox["k",
    FontSlant->"Italic"],
  "-cover  of the game ",
  StyleBox["v",
    FontSlant->"Italic"],
  " if the original game ",
  StyleBox["v",
    FontSlant->"Italic"],
  StyleBox[" satisfies the condition",
    FontVariations->{"CompatibilityType"->0}]
}], "Text",
  CellTags->"1988"],

Cell[TextData[{
  StyleBox["(1)   ",
    FontVariations->{"CompatibilityType"->0}],
  Cell[BoxData[
      \(TraditionalForm\`\(\(\(g\^v\)(
              S)\  \[GreaterEqual] \ \(\(g\^v\)(
                N)\)\ \ \ \ \ for\ all\ S\  \[Subset] \ N\ with\  | 
        S | \ \ \(\(\[GreaterEqual]\)\(\ \)\(k\)\)\)\(,\)\)\)]],
  " (cf. ",
  ButtonBox["Driessen",
    ButtonData:>"Theo Driessen",
    ButtonStyle->"Hyperlink"],
  " 1988, pp. 173)"
}], "Text",
  TextAlignment->Center,
  CellTags->"1988"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\(g\^v\)(
          S)\  := \ \[Sum]\_\(j\ \[Epsilon]\ S\)\ b\_j\%v\  - \ v(S)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`b\_j\%v\  = \ v(N)\  - \ \(\(v(N\\i)\)\(.\)\)\)]],
  "  ",
  StyleBox["A TU-game  ",
    FontVariations->{"CompatibilityType"->0}],
  Cell[BoxData[
      \(TraditionalForm\`v\_k\)]],
  " ",
  StyleBox["is defined as follows",
    FontVariations->{"CompatibilityType"->0}]
}], "Text",
  TextAlignment->Left,
  CellTags->"1988"],

Cell[TextData[{
  StyleBox["(2)  ",
    FontVariations->{"CompatibilityType"->0}],
  Cell[BoxData[
      \(TraditionalForm\`\(v\_k\)(S)\  := \ v(S)\)]],
  " if ",
  StyleBox[" ",
    FontVariations->{"CompatibilityType"->0}],
  "|S|  <",
  StyleBox[" k",
    FontSlant->"Italic"],
  StyleBox[" and ",
    FontVariations->{"CompatibilityType"->0}],
  Cell[BoxData[
      \(TraditionalForm\`\(v\_k\)(\ 
          S) := \ \[Sum]\_\(j\ \[Epsilon]\ S\)\ b\_j\%v\  - \ \(g\^v\)(
            N)\)]],
  " if |S|  \[GreaterEqual] ",
  StyleBox["k",
    FontSlant->"Italic"],
  ".  "
}], "Text",
  TextAlignment->Center,
  CellTags->"1988"],

Cell[TextData[{
  "A TU-game  ",
  StyleBox["v",
    FontSlant->"Italic"],
  " is called ",
  StyleBox["k",
    FontSlant->"Italic"],
  "-convex if the ",
  StyleBox["k",
    FontSlant->"Italic"],
  "-cover  of the game is convex, that is, the condition (1) is fulfilled and \
the TU-game ",
  Cell[BoxData[
      \(TraditionalForm\`v\_k\)]],
  " is convex. The ",
  StyleBox["k-",
    FontSlant->"Italic"],
  StyleBox["cover of the game ",
    FontVariations->{"CompatibilityType"->0}],
  StyleBox["v",
    FontSlant->"Italic",
    FontVariations->{"CompatibilityType"->0}],
  StyleBox[" can be verified by calling the function ",
    FontVariations->{"CompatibilityType"->0}],
  StyleBox["Gap[]",
    FontWeight->"Bold",
    FontVariations->{"CompatibilityType"->0}],
  StyleBox[". The output of the function ",
    FontVariations->{"CompatibilityType"->0}],
  StyleBox["Gap[]",
    FontWeight->"Bold",
    FontVariations->{"CompatibilityType"->0}],
  StyleBox[" is the value of ",
    FontVariations->{"CompatibilityType"->0}],
  Cell[BoxData[
      \(TraditionalForm\`\(g\^v\)(S)\)]],
  " for each coalition in the order set by the command ",
  StyleBox["Subsets[]",
    FontWeight->"Bold"],
  ". In the example given below the coalition size two starts at position 6 \
whereas coalition size 3 starts at position 12. "
}], "Text",
  TextJustification->1,
  CellTags->"1988"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Gap[ExpGame5]\)], "Input"],

Cell[BoxData[
    \({0, 5, 7, 8, 11, 11, 12, 13, 11, 12, 12, 11, 11, 11, 11, 
      11}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Gap[ExpGame6]\)], "Input"],

Cell[BoxData[
    \({0, 2, 2, 2, 2, 4, 4, 4, 4, 4, 4, 3, 3, 3, 3, 3}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Gap[ExpGame7]\)], "Input"],

Cell[BoxData[
    \({0, 3, 3, 3, 3, 3, 3, 3}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Gap[ExpGame8]\)], "Input"],

Cell[BoxData[
    \({0, 7199\/30, 7199\/30, 7199\/30, 7199\/30, 800\/3, 800\/3, 800\/3, 
      800\/3, 800\/3, 800\/3, 800\/3, 800\/3, 800\/3, 800\/3, 
      800\/3}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Gap[ExpGame8] // N\)], "Input"],

Cell[BoxData[
    \({0.`, 239.96666666666667`, 239.96666666666667`, 239.96666666666667`, 
      239.96666666666667`, 266.6666666666667`, 266.6666666666667`, 
      266.6666666666667`, 266.6666666666667`, 266.6666666666667`, 
      266.6666666666667`, 266.6666666666667`, 266.6666666666667`, 
      266.6666666666667`, 266.6666666666667`, 266.6666666666667`}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Game \"",
  StyleBox["ExpGame7",
    FontSlant->"Italic"],
  "\" satisfies the condition of a 1-cover, whereas for the other games the \
condition of a 2-cover  is satisfied. In the next step, we have to verify \
that the associated ",
  Cell[BoxData[
      \(TraditionalForm\`v\_k\)]],
  " game is convex. By doing so, we can derive the associated ",
  Cell[BoxData[
      \(TraditionalForm\`v\_k\)]],
  " game by using the function ",
  StyleBox["kCover[]",
    FontWeight->"Bold",
    FontVariations->{"CompatibilityType"->0}],
  StyleBox[" and by setting ",
    FontVariations->{"CompatibilityType"->0}],
  StyleBox["k=2",
    FontSlant->"Italic",
    FontVariations->{"CompatibilityType"->0}],
  StyleBox[". ",
    FontVariations->{"CompatibilityType"->0}],
  "First, we have to generate the coalitional values of the ",
  Cell[BoxData[
      \(TraditionalForm\`v\_2\)]],
  " games, this is done by calling"
}], "Text",
  TextJustification->1],

Cell[CellGroupData[{

Cell[BoxData[
    \(kval1 = kCover[ExpGame5, 2]\)], "Input"],

Cell[BoxData[
    \({0, 0, 0, 0, 0, 1, 2, 5, 4, 7, 8, 9, 12, 13, 15, 20}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(kval2 = kCover[ExpGame6, 2]\)], "Input"],

Cell[BoxData[
    \({0, 0, 0, 0, 0, 1, 1, 1, 1, 1, 1, 3, 3, 3, 3, 5}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(kval3 = kCover[ExpGame7, 1]\)], "Input"],

Cell[BoxData[
    \({0, 0, 6, 6, 9, 9, 15, 18}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(kval4 = kCover[ExpGame8, 2]\)], "Input"],

Cell[BoxData[
    \({0, 267\/10, 267\/10, 267\/10, 267\/10, 800\/3, 800\/3, 800\/3, 800\/3, 
      800\/3, 800\/3, 1600\/3, 1600\/3, 1600\/3, 1600\/3, 800}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "In the second step we define new TU-games  ",
  Cell[BoxData[
      \(TraditionalForm\`v\_2\)]],
  " for \"",
  StyleBox["ExpGame5",
    FontSlant->"Italic"],
  ", ",
  StyleBox["ExpGame6, ExpGame7",
    FontSlant->"Italic"],
  "\" and \"",
  StyleBox["ExpGame8",
    FontSlant->"Italic"],
  "\" respectively, by the function ",
  StyleBox["DefineGame[] ",
    FontWeight->"Bold"],
  "and by using the associated vectors of coalitional values which we have \
determined in the previous step. These games are defined simply by typing"
}], "Text",
  TextJustification->1],

Cell[BoxData[
    \(\(Gamevk1 := \((DefineGame[T2, kval1])\);\)\)], "Input"],

Cell[BoxData[
    \(\(Gamevk2 := \((DefineGame[T2, kval2])\);\)\)], "Input"],

Cell[BoxData[
    \(\(Gamevk3 := \((DefineGame[T4, kval3])\);\)\)], "Input"],

Cell[BoxData[
    \(\(Gamevk4 := \((DefineGame[T2, kval4])\);\)\)], "Input"],

Cell[TextData[{
  "We have already found out that the original games satisfy condition (1), \
hence, it remains to check whether the corresponding games ",
  Cell[BoxData[
      \(TraditionalForm\`v\_k\)]],
  " are convex to conclude that the games under considerations are 2-convex. \
To this end, we call the function ",
  StyleBox["ConvexQ[].",
    FontWeight->"Bold"]
}], "Text",
  TextJustification->1],

Cell[CellGroupData[{

Cell[BoxData[
    \(ConvexQ[Gamevk1]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ConvexQ[ExpGame5]\)], "Input"],

Cell[BoxData[
    \(False\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ConvexQ[Gamevk2]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ConvexQ[ExpGame6]\)], "Input"],

Cell[BoxData[
    \(False\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ConvexQ[Gamevk3]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ConvexQ[ExpGame7]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ConvexQ[Gamevk4]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ConvexQ[ExpGame8]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Since the condition (1) and the convexity condition are fulfilled, all \
games under consideration are ",
  StyleBox["k",
    FontSlant->"Italic"],
  "-convex.  Exemplary, we demonstrate that the game \"",
  StyleBox["ExpGame5",
    FontSlant->"Italic"],
  "\" is not 1-convex. "
}], "Text",
  TextJustification->1],

Cell[CellGroupData[{

Cell[BoxData[
    \(kval5 = kCover[ExpGame5, 1]\)], "Input"],

Cell[BoxData[
    \({0, \(-6\), \(-4\), \(-3\), 0, 1, 2, 5, 4, 7, 8, 9, 12, 13, 15, 
      20}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(Gamevk5 := \((DefineGame[T2, kval5])\);\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ConvexQ[ExpGame5]\)], "Input"],

Cell[BoxData[
    \(False\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ConvexQ[Gamevk3]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "The convexity condition holds, but recall that the ",
  StyleBox["k",
    FontSlant->"Italic"],
  "-cover  of the game \"",
  StyleBox["ExpGame5",
    FontSlant->"Italic"],
  "\" is not an 1-cover,  it is just a 2-cover."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Gap[ExpGame5]\)], "Input"],

Cell[BoxData[
    \({0, 5, 7, 8, 11, 11, 12, 13, 11, 12, 12, 11, 11, 11, 11, 
      11}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "In this case condition (1) does not hold and therefore the game \"",
  StyleBox["ExpGame5",
    FontSlant->"Italic"],
  "\" is not 1-convex."
}], "Text"],

Cell["\<\
Furthermore, we can calculate the upper or utopia payoff that \
represents an upper bound of the core by \
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(UtopiaVector[ExpGame5]\)], "Input"],

Cell[BoxData[
    \({5, 7, 8, 11}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(UtopiaVector[ExpGame6]\)], "Input"],

Cell[BoxData[
    \({2, 2, 2, 2}\)], "Output"]
}, Open  ]],

Cell["\<\
A lower bound of the core is the so-called  disagreement vector and \
it can be computed by calling \
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Disagreement[ExpGame5]\)], "Input"],

Cell[BoxData[
    \({0, 0, 0, 0}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Disagreement[ExpGame6]\)], "Input"],

Cell[BoxData[
    \({0, 0, 0, 0}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Since the tau-value  can be regarded as some fair compromise between the \
utopia and the disagreement vector,",
  StyleBox[" we are now in the position to compute the tau-value  of the \
previous games. ",
    FontVariations->{"CompatibilityType"->0}]
}], "Text",
  TextJustification->1],

Cell[CellGroupData[{

Cell[BoxData[
    \(tau1 = TauValue[ExpGame5]\)], "Input"],

Cell[BoxData[
    \({100\/31, 140\/31, 160\/31, 220\/31}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(tau2 = TauValue[ExpGame6]\)], "Input"],

Cell[BoxData[
    \({5\/4, 5\/4, 5\/4, 5\/4}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "In the next step, we want to verify if the computed tau-values  are \
contained in the corresponding cores of the game \"",
  StyleBox["ExpGame5",
    FontSlant->"Italic"],
  "\" and \"",
  StyleBox["ExpGame6",
    FontSlant->"Italic"],
  "\", respectively.  For this purpose we us call the command ",
  StyleBox["InCoreQ[]",
    FontWeight->"Bold"],
  " provided by the package ",
  StyleBox["CooperativeGames. ",
    FontSlant->"Italic"],
  "The command requires as an input one imputation and the ",
  StyleBox["game_name.",
    FontSlant->"Italic"]
}], "Text",
  TextJustification->1],

Cell[CellGroupData[{

Cell[BoxData[
    \(InCoreQ[tau1, ExpGame5]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(InCoreQ[tau2, ExpGame6]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "It is well known that for convexity of an ",
  StyleBox["n",
    FontSlant->"Italic"],
  "-person  Tu-game  it is necessary and sufficient that the core of the game \
contains all ",
  StyleBox["n",
    FontSlant->"Italic"],
  "! marginal worth vectors. A similar result holds for ",
  StyleBox["k",
    FontSlant->"Italic"],
  "-convex  games. For ",
  StyleBox["k",
    FontSlant->"Italic"],
  "-convexity it is necessary and sufficient that all ",
  Cell[BoxData[
      \(TraditionalForm\`\((\(\((n - k)\)!\))\)\^\(-1\)\ \(n!\)\)]],
  " adjusted marginal worth vectors are contained in the core of the game \
(cf. ",
  ButtonBox["Driessen",
    ButtonData:>"Theo Driessen",
    ButtonStyle->"Hyperlink"],
  " 1988). The adjusted marginal worth vectors of ",
  StyleBox["k",
    FontSlant->"Italic"],
  "-convex  games can be evaluated with the function ",
  StyleBox["AdjustedWorthVectors[]",
    FontWeight->"Bold"],
  " . There is also a special function available to compute the adjusted \
worth vectors of 1-convex games. The function name in this case is ",
  StyleBox["AdjustedEffUpperVectors[]",
    FontWeight->"Bold"],
  ". Let us now calculate for the above games the adjusted marginal worth \
vectors. "
}], "Text",
  TextJustification->1],

Cell[CellGroupData[{

Cell[BoxData[
    \(v5 = AdjustedWorthVectors[ExpGame5, 2]\)], "Input"],

Cell[BoxData[
    \({{0, 1, 8, 11}, {0, 1, 8, 11}, {0, 7, 2, 11}, {0, 7, 8, 5}, {0, 7, 2, 
        11}, {0, 7, 8, 5}, {1, 0, 8, 11}, {1, 0, 8, 11}, {2, 7, 0, 11}, {5, 
        7, 8, 0}, {2, 7, 0, 11}, {5, 7, 8, 0}, {5, 0, 4, 11}, {5, 0, 8, 
        7}, {5, 4, 0, 11}, {5, 7, 8, 0}, {5, 7, 0, 8}, {5, 7, 8, 0}, {5, 0, 
        4, 11}, {5, 0, 8, 7}, {5, 4, 0, 11}, {5, 7, 8, 0}, {5, 7, 0, 8}, {5, 
        7, 8, 0}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(u5 = v5 // Union\)], "Input"],

Cell[BoxData[
    \({{0, 1, 8, 11}, {0, 7, 2, 11}, {0, 7, 8, 5}, {1, 0, 8, 11}, {2, 7, 0, 
        11}, {5, 0, 4, 11}, {5, 0, 8, 7}, {5, 4, 0, 11}, {5, 7, 0, 8}, {5, 7, 
        8, 0}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Length[u5]\)], "Input"],

Cell[BoxData[
    \(10\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "As expected the number of marginal worth vectors does not exceed the \
threshold value of ",
  Cell[BoxData[
      \(TraditionalForm\`\((\(\((n - k)\)!\))\)\^\(-1\)\ \(n!\)\)]],
  " vertices. For 2-convex  games the maximal number of marginal worth \
vectors is 12. All adjusted marginal worth vectors must be contained in the \
core. We check this by"
}], "Text",
  TextJustification->1],

Cell[CellGroupData[{

Cell[BoxData[
    \(CoreElementsQ[ExpGame5, u5]\)], "Input"],

Cell[BoxData[
    \({True, True, True, True, True, True, True, True, True, 
      True}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "As well as for the class of convex games the class of ",
  StyleBox["k",
    FontSlant->"Italic"],
  "-convex  games can be characterized by the vertices of the core, it is \
necessary and sufficient for the ",
  StyleBox["k",
    FontSlant->"Italic"],
  "-convexity  property that the vertices of the core coincide exactly with \
the adjusted marginal worth vectors. We are able to check on this property by \
using the following steps: first, we compute the vertices of the core. In a \
second step we find out the imputations that are contained in the core and \
examine if the imputations we have selected are really core elements. Then we \
compute the adjusted marginal worth vectors and compare the result with our \
vertex result. To compute core vertices, we can perform this task with the \
command ",
  StyleBox["VerticesCore[]",
    FontWeight->"Bold"],
  ". The command returns two output values, the vertices and a list of \
\"active-variable\" sets, indicating which inequalities are satisfied with \
equalities at each vertex  (cf. ",
  StyleBox["VertexEnum",
    FontSlant->"Italic"],
  ").  In our example below, the symbol ",
  StyleBox["cvert5",
    FontSlant->"Italic"],
  " captures the informations associated with the vertices and the symbol ",
  StyleBox["nonvert5",
    FontSlant->"Italic"],
  " grabs all informations of the \"active -variable\" set. "
}], "Text",
  TextJustification->1],

Cell[CellGroupData[{

Cell[BoxData[
    \({cvert5, nonvert5} = VerticesCore[ExpGame5]\)], "Input"],

Cell[BoxData[
    \({{{5, 7, 8, 0}, {3, 9, 10, 0}, {6, 6, 9, 0}, {6, 8, 7, 0}, {0, 9, 10, 
          3}, {6, 0, 9, 6}, {6, 8, 0, 7}, {5, 7, 0, 8}, {2, 7, 0, 11}, {1, 8, 
          0, 12}, {5, 4, 0, 11}, {0, 7, 8, 5}, {0, 7, 2, 11}, {0, 8, 1, 
          12}, {0, 1, 8, 11}, {5, 0, 8, 7}, {5, 0, 4, 11}, {1, 0, 8, 
          11}}, {{16, 18, 19, 17, 8, 4}, {16, 11, 8, 17, 4}, {16, 18, 8, 13, 
          4}, {14, 18, 8, 17, 4}, {16, 11, 5, 17, 1}, {16, 18, 6, 13, 
          2}, {14, 18, 7, 17, 3}, {7, 18, 19, 17, 3}, {7, 15, 19, 17, 3}, {7, 
          15, 10, 17, 3}, {7, 18, 19, 15, 3, 12}, {16, 5, 19, 17, 1}, {15, 5, 
          19, 17, 1}, {15, 5, 10, 17, 1}, {16, 5, 19, 15, 9, 1}, {16, 18, 19, 
          6, 2}, {15, 18, 19, 6, 2, 12}, {16, 15, 19, 6, 2, 9}}}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "The package provides two different functions to check whether a list of \
imputations is contained in the core. In addition to the function ",
  StyleBox["CoreElementsQ[]",
    FontWeight->"Bold"],
  StyleBox[" which we have already introduced above and that is based on the \
function ",
    FontVariations->{"CompatibilityType"->0}],
  StyleBox["InCoreQ[]",
    FontWeight->"Bold",
    FontVariations->{"CompatibilityType"->0}],
  StyleBox[" by ",
    FontVariations->{"CompatibilityType"->0}],
  ButtonBox["Carter",
    ButtonData:>"M. Carter",
    ButtonStyle->"Hyperlink"],
  ButtonBox[",",
    ButtonData:>"Hal Varian",
    ButtonStyle->"Hyperlink"],
  StyleBox[" we provide a second function that is called ",
    FontVariations->{"CompatibilityType"->0}],
  StyleBox["BelongToCoreQ[]",
    FontWeight->"Bold",
    FontVariations->{"CompatibilityType"->0}],
  StyleBox[" which is based on the property that an imputation ",
    FontVariations->{"CompatibilityType"->0}],
  StyleBox["x",
    FontSlant->"Italic",
    FontVariations->{"CompatibilityType"->0}],
  StyleBox[" belongs to the core ",
    FontVariations->{"CompatibilityType"->0}],
  StyleBox["C(v) ",
    FontSlant->"Italic",
    FontVariations->{"CompatibilityType"->0}],
  StyleBox["iff ",
    FontVariations->{"CompatibilityType"->0}]
}], "Text",
  TextJustification->1],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`x(
          S) = \[Sum]\_\(i\ \[Epsilon]\ S\)\ x\_i\ \  \[LessEqual] \ 
          v(N)\  - \ v(S)\)]],
  " for all",
  StyleBox[" S \[Subset] N",
    FontSlant->"Italic"],
  ".  "
}], "Text",
  TextAlignment->Center,
  TextJustification->1],

Cell[TextData[{
  "We demonstrate how the function ",
  StyleBox["BelongToCoreQ[]",
    FontWeight->"Bold",
    FontVariations->{"CompatibilityType"->0}],
  " works in comparison to the function ",
  StyleBox["CoreElementsQ[]",
    FontWeight->"Bold"],
  " before we proceed on our problem. The difference between the function is \
discussed in more detail in ",
  ButtonBox["Section 5",
    ButtonData:>"Unix Functions",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text",
  TextJustification->1],

Cell[CellGroupData[{

Cell[BoxData[
    \(cor5 = CoreElementsQ[ExpGame5, cvert5]\)], "Input"],

Cell[BoxData[
    \({True, False, False, False, False, False, False, True, True, False, 
      True, True, True, False, True, True, True, True}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(blcor5 = BelongToCoreQ[ExpGame5, cvert5]\)], "Input"],

Cell[BoxData[
    \({True, False, False, False, False, False, False, True, True, False, 
      True, True, True, False, True, True, True, True}\)], "Output"]
}, Open  ]],

Cell["\<\
Since, some of imputations aren't contained in the core, we select \
the core imputations by using the command\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(pos5 = Position[cor5, True]\)], "Input"],

Cell[BoxData[
    \({{1}, {8}, {9}, {11}, {12}, {13}, {15}, {16}, {17}, {18}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(bcs5 = Position[blcor5, True]\)], "Input"],

Cell[BoxData[
    \({{1}, {8}, {9}, {11}, {12}, {13}, {15}, {16}, {17}, {18}}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "We got with the command ",
  StyleBox["Position[]",
    FontWeight->"Bold"],
  " the exact location of the core elements, we can use this information by \
extracting all core imputations typing "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ext5 = Extract[cvert5, pos5]\)], "Input"],

Cell[BoxData[
    \({{5, 7, 8, 0}, {5, 7, 0, 8}, {2, 7, 0, 11}, {5, 4, 0, 11}, {0, 7, 8, 
        5}, {0, 7, 2, 11}, {0, 1, 8, 11}, {5, 0, 8, 7}, {5, 0, 4, 11}, {1, 0, 
        8, 11}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(bcext5 = Extract[cvert5, bcs5]\)], "Input"],

Cell[BoxData[
    \({{5, 7, 8, 0}, {5, 7, 0, 8}, {2, 7, 0, 11}, {5, 4, 0, 11}, {0, 7, 8, 
        5}, {0, 7, 2, 11}, {0, 1, 8, 11}, {5, 0, 8, 7}, {5, 0, 4, 11}, {1, 0, 
        8, 11}}\)], "Output"]
}, Open  ]],

Cell["\<\
Let us verify that all the elements we have selected from our \
initial list are contained in the core.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(CoreElementsQ[ExpGame5, ext5]\)], "Input"],

Cell[BoxData[
    \({True, True, True, True, True, True, True, True, True, 
      True}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BelongToCoreQ[ExpGame5, bcext5]\)], "Input"],

Cell[BoxData[
    \({True, True, True, True, True, True, True, True, True, 
      True}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Length[ext5]\)], "Input"],

Cell[BoxData[
    \(10\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(to5 = Union[ext5, u5]\)], "Input"],

Cell[BoxData[
    \({{0, 1, 8, 11}, {0, 7, 2, 11}, {0, 7, 8, 5}, {1, 0, 8, 11}, {2, 7, 0, 
        11}, {5, 0, 4, 11}, {5, 0, 8, 7}, {5, 4, 0, 11}, {5, 7, 0, 8}, {5, 7, 
        8, 0}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Length[to5]\)], "Input"],

Cell[BoxData[
    \(10\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "To get more evidence that the function ",
  StyleBox["AdjustedWorthVectors[]",
    FontWeight->"Bold"],
  " computes the exact values. Let us consider the game \"",
  StyleBox["ExpGame8",
    FontSlant->"Italic"],
  "\"."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(v8 = AdjustedWorthVectors[ExpGame8, 2]\)], "Input"],

Cell[BoxData[
    \({{267\/10, 7199\/30, 800\/3, 800\/3}, {267\/10, 7199\/30, 800\/3, 
        800\/3}, {267\/10, 800\/3, 7199\/30, 800\/3}, {267\/10, 800\/3, 
        800\/3, 7199\/30}, {267\/10, 800\/3, 7199\/30, 800\/3}, {267\/10, 
        800\/3, 800\/3, 7199\/30}, {7199\/30, 267\/10, 800\/3, 
        800\/3}, {7199\/30, 267\/10, 800\/3, 800\/3}, {7199\/30, 800\/3, 
        267\/10, 800\/3}, {7199\/30, 800\/3, 800\/3, 267\/10}, {7199\/30, 
        800\/3, 267\/10, 800\/3}, {7199\/30, 800\/3, 800\/3, 
        267\/10}, {800\/3, 267\/10, 7199\/30, 800\/3}, {800\/3, 267\/10, 
        800\/3, 7199\/30}, {800\/3, 7199\/30, 267\/10, 800\/3}, {800\/3, 
        7199\/30, 800\/3, 267\/10}, {800\/3, 800\/3, 267\/10, 
        7199\/30}, {800\/3, 800\/3, 7199\/30, 267\/10}, {800\/3, 267\/10, 
        7199\/30, 800\/3}, {800\/3, 267\/10, 800\/3, 7199\/30}, {800\/3, 
        7199\/30, 267\/10, 800\/3}, {800\/3, 7199\/30, 800\/3, 
        267\/10}, {800\/3, 800\/3, 267\/10, 7199\/30}, {800\/3, 800\/3, 
        7199\/30, 267\/10}}\)], "Output"]
}, Open  ]],

Cell["Removing all duplicated results we obtain", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(u8 = v8 // Union\)], "Input"],

Cell[BoxData[
    \({{267\/10, 7199\/30, 800\/3, 800\/3}, {267\/10, 800\/3, 7199\/30, 
        800\/3}, {267\/10, 800\/3, 800\/3, 7199\/30}, {7199\/30, 267\/10, 
        800\/3, 800\/3}, {7199\/30, 800\/3, 267\/10, 800\/3}, {7199\/30, 
        800\/3, 800\/3, 267\/10}, {800\/3, 267\/10, 7199\/30, 
        800\/3}, {800\/3, 267\/10, 800\/3, 7199\/30}, {800\/3, 7199\/30, 
        267\/10, 800\/3}, {800\/3, 7199\/30, 800\/3, 267\/10}, {800\/3, 
        800\/3, 267\/10, 7199\/30}, {800\/3, 800\/3, 7199\/30, 
        267\/10}}\)], "Output"]
}, Open  ]],

Cell["\<\
We obtain the expected number of adjusted marginal worth vectors, \
since\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Length[u8]\)], "Input"],

Cell[BoxData[
    \(12\)], "Output"]
}, Open  ]],

Cell["\<\
For an intermediate step, let us verify that the computed vectors \
are all efficient. This could be done by\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Apply[Plus, #]\  &\)\  /@ \ u8\)], "Input"],

Cell[BoxData[
    \({800, 800, 800, 800, 800, 800, 800, 800, 800, 800, 800, 
      800}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \({cvert8, nonvert8} = VerticesCore[ExpGame8]\)], "Input"],

Cell[BoxData[
    \({{{800\/3, 800\/3, 267\/10, 7199\/30}, {800\/3, 800\/3, 7199\/30, 
          267\/10}, {7199\/30, 800\/3, 800\/3, 267\/10}, {267\/10, 800\/3, 
          800\/3, 7199\/30}, {267\/10, 7199\/30, 800\/3, 800\/3}, {7199\/30, 
          800\/3, 267\/10, 800\/3}, {267\/10, 800\/3, 7199\/30, 
          800\/3}, {7199\/30, 267\/10, 800\/3, 800\/3}, {800\/3, 7199\/30, 
          800\/3, 267\/10}, {800\/3, 267\/10, 800\/3, 7199\/30}, {800\/3, 
          7199\/30, 267\/10, 800\/3}, {800\/3, 267\/10, 7199\/30, 
          800\/3}}, {{19, 18, 7, 17, 14}, {19, 18, 8, 17, 14}, {19, 16, 8, 
          17, 11}, {19, 16, 5, 17, 11}, {19, 15, 5, 16, 9}, {19, 15, 7, 17, 
          10}, {19, 15, 5, 17, 10}, {19, 16, 6, 15, 9}, {19, 18, 8, 16, 
          13}, {19, 18, 6, 16, 13}, {19, 18, 7, 15, 12}, {19, 18, 6, 15, 
          12}}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Length[cvert8]\)], "Input"],

Cell[BoxData[
    \(12\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(CoreElementsQ[ExpGame8, cvert8]\)], "Input"],

Cell[BoxData[
    \({True, True, True, True, True, True, True, True, True, True, True, 
      True}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(CoreElementsQ[ExpGame8, Rationalize[cvert8]]\)], "Input"],

Cell[BoxData[
    \({True, True, True, True, True, True, True, True, True, True, True, 
      True}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BelongToCoreQ[ExpGame8, cvert8]\)], "Input"],

Cell[BoxData[
    \({True, True, True, True, True, True, True, True, True, True, True, 
      True}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(to8 = Union[cvert8, v8]\)], "Input"],

Cell[BoxData[
    \({{267\/10, 7199\/30, 800\/3, 800\/3}, {267\/10, 800\/3, 7199\/30, 
        800\/3}, {267\/10, 800\/3, 800\/3, 7199\/30}, {7199\/30, 267\/10, 
        800\/3, 800\/3}, {7199\/30, 800\/3, 267\/10, 800\/3}, {7199\/30, 
        800\/3, 800\/3, 267\/10}, {800\/3, 267\/10, 7199\/30, 
        800\/3}, {800\/3, 267\/10, 800\/3, 7199\/30}, {800\/3, 7199\/30, 
        267\/10, 800\/3}, {800\/3, 7199\/30, 800\/3, 267\/10}, {800\/3, 
        800\/3, 267\/10, 7199\/30}, {800\/3, 800\/3, 7199\/30, 
        267\/10}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Length[to8]\)], "Input"],

Cell[BoxData[
    \(12\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Do not try to use the function ",
  StyleBox["AdjustedEffUpperVectors[] ",
    FontWeight->"Bold"],
  StyleBox["for ",
    FontVariations->{"CompatibilityType"->0}],
  StyleBox["k",
    FontSlant->"Italic",
    FontVariations->{"CompatibilityType"->0}],
  StyleBox["-convex  games, with ",
    FontVariations->{"CompatibilityType"->0}],
  StyleBox["k",
    FontSlant->"Italic",
    FontVariations->{"CompatibilityType"->0}],
  StyleBox["\[GreaterEqual] 2. In this case you will get wrong results.",
    FontVariations->{"CompatibilityType"->0}]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(AdjustedEffUpperVectors[ExpGame8]\)], "Input"],

Cell[BoxData[
    \({{0, 800\/3, 800\/3, 800\/3}, {800\/3, 0, 800\/3, 800\/3}, {800\/3, 
        800\/3, 0, 800\/3}, {800\/3, 800\/3, 800\/3, 0}}\)], "Output"]
}, Open  ]],

Cell["\<\
You can just us this function simply to compute the adjusted \
marginal worth vectors for 1-convex  games as the next example will \
demonstrate it. \
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(AdjustedEffUpperVectors[ExpGame7]\)], "Input"],

Cell[BoxData[
    \({{0, 9, 9}, {3, 6, 9}, {3, 9, 6}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(AdjustedWorthVectors[ExpGame7, 1] // Union\)], "Input"],

Cell[BoxData[
    \({{0, 9, 9}, {3, 6, 9}, {3, 9, 6}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(VerticesCore[ExpGame7]\)[\([1]\)]\)], "Input"],

Cell[BoxData[
    \({{3, 9, 6}, {0, 9, 9}, {3, 6, 9}}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["4.3 Kernel",
  ButtonData:>"4.3.",
  ButtonStyle->"Hyperlink"]], "Subsubsection",
  FontSize->16,
  CellTags->"Kernel"],

Cell[TextData[{
  "In this subsection we want to present some functions which will enable ",
  StyleBox["us",
    FontVariations->{"CompatibilityType"->0}],
  " to compute at least a kernel solution or in good cases the whole kernel \
of a game. The functions we will present in this subsection relying on the \
linear programming approach to determine outcomes that lie in the core (or \
strong epsilon core) as well as  in the kernel of the game, that is, outcomes \
that satisfy the bisection property.  Note, that for zero-monotonic  games \
the bisection property is necessary and sufficient that an imputation that \
belongs to the core (strong-epsilon core)  is also contained in the kernel of \
the game (cf. Th 3.7 ",
  ButtonBox["Maschler, Peleg and Shapley",
    ButtonData:>"M. Maschler",
    ButtonStyle->"Hyperlink"],
  " (1979)). More informations about the algorithm can be found in ",
  ButtonBox["Meinhardt",
    ButtonData:>"H. Meinhardt",
    ButtonStyle->"Hyperlink"],
  " (2004). To start off, let us first consider the command ",
  StyleBox["Kernel[game,opts]",
    FontWeight->"Bold"],
  " without an options to compute a kernel point of the game.  In the second \
case we make use of an optional ",
  "argument",
  " ",
  StyleBox["eps",
    FontWeight->"Bold"],
  " which is a critical value to generalize the bisection property to the \
strong epsilon-cores. You can omit the critical value ",
  StyleBox["eps",
    FontWeight->"Bold"],
  " in the command without harm, since the default value is set to zero. \
There are different functions available which determine the different types \
of critical values. One critical value can be calculated, for instance, by \
the function ",
  StyleBox["FirstCriticalVal[game]",
    FontWeight->"Bold"],
  ". This function and  all the rest of them will be discussed in the sequel \
of this subsection."
}], "Text",
  TextJustification->1,
  CellTags->"(2002b)"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ker1 = Kernel[ExpGame1]\)], "Input"],

Cell[BoxData[
    \("Game has nonempty core"\)], "Print"],

Cell[BoxData[
    \({45\/2, 45\/2, 45\/2, 45\/2}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ker2 = Kernel[ExpGame2]\)], "Input"],

Cell[BoxData[
    \("Game has nonempty core"\)], "Print"],

Cell[BoxData[
    \({45\/2, 45\/2, 45\/2, 45\/2}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ModifiedKernel[ExpGame2]\)], "Input"],

Cell[BoxData[
    \({45\/2, 45\/2, 45\/2, 45\/2}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ker3 = Kernel[ExpGame3]\)], "Input"],

Cell[BoxData[
    \("Game has nonempty core"\)], "Print"],

Cell[BoxData[
    \({1, 1, 1, 2, 2}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ModifiedKernel[ExpGame3]\)], "Input"],

Cell[BoxData[
    \({1, 1, 1, 2, 2}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ker4 = Kernel[ExpGame4]\)], "Input"],

Cell[BoxData[
    \("Game has nonempty core"\)], "Print"],

Cell[BoxData[
    \({7\/32, 7\/32, 9\/32, 9\/32}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ModifiedKernel[ExpGame4]\)], "Input"],

Cell[BoxData[
    \({7\/32, 7\/32, 9\/32, 9\/32}\)], "Output"]
}, Open  ]],

Cell["\<\
The next function verifies whether the payoff belongs to the kernel \
of the game.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(KernelImputationQ[ExpGame1, ker1]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(KernelImputationQ[ExpGame2, ker2]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(KernelImputationQ[ExpGame3, ker3]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(KernelImputationQ[ExpGame4, ker4]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell["Define some payoffs", "Text"],

Cell[BoxData[
    \(\(pay = {{45, 0, 45, 0}, {10, 20, 30, 30}, ker1, ker2};\)\)], "Input"],

Cell["\<\
If you want to test, if a list of payoffs belong to the kernel then \
use \
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(KernelImputationListQ[ExpGame1, pay]\)], "Input"],

Cell[BoxData[
    \({False, False, True, True}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Specify now the arrangement of all subsets of the grand coalition ",
  StyleBox["N",
    FontSlant->"Italic"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Subsets[{1, 2, 3, 4}]\)], "Input"],

Cell[BoxData[
    \({{}, {1}, {2}, {3}, {4}, {1, 2}, {1, 3}, {1, 4}, {2, 3}, {2, 4}, {3, 
        4}, {1, 2, 3}, {1, 2, 4}, {1, 3, 4}, {2, 3, 4}, {1, 2, 3, 
        4}}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "The surpluses of an excess vector are arranged exactly in accordance with \
the above order of subsets of the grand coalition ",
  StyleBox["N",
    FontSlant->"Italic"],
  ". Here, we present the corresponding excess vectors related to the symbol \
\"",
  StyleBox["pay",
    FontSlant->"Italic"],
  "\"."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ExcessPayoff[ExpGame1, pay, 
      DisplayMatrixForm \[Rule] \ True]\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(Co[{}]\), \(Co[{1}]\), \(Co[{2}]\), \(Co[{3}]\), \(Co[{4}]\), \
\(Co[{1, 2}]\), \(Co[{1, 3}]\), \(Co[{1, 4}]\), \(Co[{2, 3}]\), \(Co[{2, 
                  4}]\), \(Co[{3, 4}]\), \(Co[{1, 2, 3}]\), \(Co[{1, 2, 
                  4}]\), \(Co[{1, 3, 4}]\), \(Co[{2, 3, 4}]\), \(Co[{1, 2, 3, 
                  4}]\)},
            {"0", \(-45\), "0", \(-45\), 
              "0", \(-45\), \(-90\), \(-45\), \(-45\), 
              "0", \(-45\), \(-50\), \(-45\), \(-50\), \(-45\), "0"},
            {
              "0", \(-10\), \(-20\), \(-30\), \(-30\), \(-30\), \(-40\), \
\(-40\), \(-50\), \(-50\), \(-60\), \(-20\), \(-60\), \(-30\), \(-80\), "0"},
            {
              "0", \(-\(45\/2\)\), \(-\(45\/2\)\), \(-\(45\/2\)\), \(-\(45\/2\
\)\), \(-45\), \(-45\), \(-45\), \(-45\), \(-45\), \(-45\), \(-\(55\/2\)\), \
\(-\(135\/2\)\), \(-\(55\/2\)\), \(-\(135\/2\)\), "0"},
            {
              "0", \(-\(45\/2\)\), \(-\(45\/2\)\), \(-\(45\/2\)\), \(-\(45\/2\
\)\), \(-45\), \(-45\), \(-45\), \(-45\), \(-45\), \(-45\), \(-\(55\/2\)\), \
\(-\(135\/2\)\), \(-\(55\/2\)\), \(-\(135\/2\)\), "0"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[TextData[{
  "To check if the kernel element coincides with the nucleolus, we use the \
function ",
  StyleBox["Nucleolus[]",
    FontWeight->"Bold"],
  " provided by ",
  StyleBox["CooperativeGames.",
    FontSlant->"Italic"]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Nucleolus[ExpGame1]\)], "Input"],

Cell[BoxData[
    \({45\/2, 45\/2, 45\/2, 45\/2}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "In the package ",
  StyleBox["TuGames ",
    FontSlant->"Italic"],
  StyleBox["are also some functions available to compute the nucleolus or \
pre-nucleolus of the game.  These are the following functions:",
    FontVariations->{"CompatibilityType"->0}]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ModifiedNucleolus[ExpGame1]\)], "Input"],

Cell[BoxData[
    \({45\/2, 45\/2, 45\/2, 45\/2}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(LexiCenter[ExpGame1]\)], "Input"],

Cell[BoxData[
    \({45\/2, 45\/2, 45\/2, 45\/2}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(PreNucleolus[ExpGame1]\)], "Input"],

Cell[BoxData[
    \({45\/2, 45\/2, 45\/2, 45\/2}\)], "Output"]
}, Open  ]],

Cell["The Options can be called with the following command.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Options[ModifiedNucleolus]\)], "Input"],

Cell[BoxData[
    \({CallMinimize \[Rule] True, SetRecursionLimit \[Rule] 128, 
      Silent \[Rule] True}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Due to our experience these functions are more robust than the function ",
  StyleBox["Nucleolus[] ",
    FontWeight->"Bold"],
  "for essential games. If the game is  inessential then the result\nmight \
not be correct and you have to check the result by ",
  StyleBox["KernelImputationListQ[",
    FontWeight->"Bold"],
  StyleBox["]",
    FontWeight->"Bold"],
  " or ",
  StyleBox["KernelImputationQ[]",
    FontWeight->"Bold"],
  ". Since the result is a remapping of\na zero-one normalized game back to \
original game, one has simply to look on this result to find an appropriate \
remapping to original game."
}], "Text"],

Cell[TextData[{
  "The game \"",
  StyleBox["ExpGame1",
    FontSlant->"Italic"],
  "\" is convex, in this case the kernel is an unique element that coincides \
with the Nucleolus."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ConvexQ[ExpGame1]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Recall the kernel element from \"",
  StyleBox["ExpGame3",
    FontSlant->"Italic"],
  "\""
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ker3\)], "Input"],

Cell[BoxData[
    \({1, 1, 1, 2, 2}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(nuc3 = Nucleolus[ExpGame3]\)], "Input"],

Cell[BoxData[
    \({1, 1, 1, 2, 2}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ModifiedNucleolus[ExpGame3]\)], "Input"],

Cell[BoxData[
    \({1, 1, 1, 2, 2}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ModifiedNucleolus[ExpGame3, CallMinimize \[Rule] \ False]\)], "Input"],

Cell[BoxData[
    \({1, 1, 1, 2, 2}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "If you are interested to find out more kernel elements the package \
provides the command ",
  StyleBox["KernelCalculation[]",
    FontWeight->"Bold"],
  ".  The function ",
  StyleBox["KernelCalculation[]",
    FontWeight->"Bold"],
  " computes a kernel element and candidates from ",
  StyleBox["(n(n-1)/2 + 1)",
    FontSlant->"Italic"],
  " LPs, whereas ",
  StyleBox["Kernel[]",
    FontWeight->"Bold"],
  " computes a kernel element from just one linear maximization problem.  ",
  "But due to the restriction that the built-in function ",
  StyleBox["ConstrainedMax[]",
    FontWeight->"Bold"],
  " find just one solution and not all solutions of a LP we are sometimes not \
able to specify the whole kernel with ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ". That's why we follow the strategy that the above commands return also \
the final LP for further investigation outside of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ". "
}], "Text",
  TextJustification->1],

Cell[CellGroupData[{

Cell[BoxData[
    \({sol3, pay3} = 
      KernelCalculation[ExpGame3, EpsilonValue \[Rule] \ 2]\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("Game is zero-monotone? "\[InvisibleSpace]False\),
      SequenceForm[ "Game is zero-monotone? ", False],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Core is nonempty? "\[InvisibleSpace]True\),
      SequenceForm[ "Core is nonempty? ", True],
      Editable->False]], "Print"],

Cell[BoxData[
    \("Game is either zero-monotonic or has nonempty core"\)], "Print"],

Cell[BoxData[
    InterpretationBox[\("A Kernel solution is: "\[InvisibleSpace]{x[
              1] \[Rule] 1, x[2] \[Rule] 1, x[3] \[Rule] 1, x[4] \[Rule] 2, 
          x[5] \[Rule] 2}\),
      SequenceForm[ 
      "A Kernel solution is: ", {x[ 1] -> 1, x[ 2] -> 1, x[ 3] -> 1, x[ 4] -> 
        2, x[ 5] -> 2}],
      Editable->False]], "Print"],

Cell[BoxData[
    \({{1, 1, 1, 2, 
        2}, {{1\/6, 4\/3, 4\/3, 3\/2, 8\/3}, {1\/6, 4\/3, 4\/3, 8\/3, 
          3\/2}, {1, 1, 1, 2, 2}, {1, 1, 3, 1, 1}, {1, 3, 1, 1, 1}, {4\/3, 
          1\/6, 4\/3, 3\/2, 8\/3}, {4\/3, 1\/6, 4\/3, 8\/3, 3\/2}, {4\/3, 
          4\/3, 1\/6, 3\/2, 8\/3}, {4\/3, 4\/3, 1\/6, 8\/3, 3\/2}, {5\/3, 
          5\/3, 5\/3, 1, 1}, {3, 1, 1, 1, 1}}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(KernelImputationListQ[ExpGame3, pay3]\)], "Input"],

Cell[BoxData[
    \({False, False, True, False, False, False, False, False, False, False, 
      False}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "All internal results can be obtained by invoking the option ",
  StyleBox["DisplayAllResults.",
    FontSlant->"Italic"]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \({sol3, obj3, con3, tra3, \ pay3} = 
      KernelCalculation[ExpGame3, EpsilonValue \[Rule] \ 2, 
        DisplayAllResults \[Rule] \ True]\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("Game is zero-monotone? "\[InvisibleSpace]False\),
      SequenceForm[ "Game is zero-monotone? ", False],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Core is nonempty? "\[InvisibleSpace]True\),
      SequenceForm[ "Core is nonempty? ", True],
      Editable->False]], "Print"],

Cell[BoxData[
    \("Game is either zero-monotonic or has nonempty core"\)], "Print"],

Cell[BoxData[
    InterpretationBox[\("A Kernel solution is: "\[InvisibleSpace]{x[
              1] \[Rule] 1, x[2] \[Rule] 1, x[3] \[Rule] 1, x[4] \[Rule] 2, 
          x[5] \[Rule] 2}\),
      SequenceForm[ 
      "A Kernel solution is: ", {x[ 1] -> 1, x[ 2] -> 1, x[ 3] -> 1, x[ 4] -> 
        2, x[ 5] -> 2}],
      Editable->False]], "Print"],

Cell[BoxData[
    \({{1, 1, 1, 2, 2}, 
      x[1] + x[2] + x[3] + x[4] + x[5], {x[1] \[GreaterEqual] 0, 
        x[1] \[GreaterEqual] 0, x[2] \[GreaterEqual] 0, 
        x[2] \[GreaterEqual] 0, x[3] \[GreaterEqual] 0, 
        x[3] \[GreaterEqual] 0, x[1] + x[2] + x[4] \[GreaterEqual] 4, 
        x[1] + x[2] + x[4] \[GreaterEqual] 4, 
        x[1] + x[2] + x[4] \[GreaterEqual] 4, 
        x[1] + x[3] + x[4] \[GreaterEqual] 4, 
        x[1] + x[3] + x[4] \[GreaterEqual] 4, 
        x[1] + x[3] + x[4] \[GreaterEqual] 4, 
        x[2] + x[3] + x[4] \[GreaterEqual] 4, 
        x[2] + x[3] + x[4] \[GreaterEqual] 4, 
        x[2] + x[3] + x[4] \[GreaterEqual] 4, 
        x[1] + x[2] + x[5] \[GreaterEqual] 4, 
        x[1] + x[2] + x[5] \[GreaterEqual] 4, 
        x[1] + x[2] + x[5] \[GreaterEqual] 4, 
        x[1] + x[3] + x[5] \[GreaterEqual] 4, 
        x[1] + x[3] + x[5] \[GreaterEqual] 4, 
        x[1] + x[3] + x[5] \[GreaterEqual] 4, 
        x[2] + x[3] + x[5] \[GreaterEqual] 4, 
        x[2] + x[3] + x[5] \[GreaterEqual] 4, 
        x[2] + x[3] + x[5] \[GreaterEqual] 4, x[4] + x[5] \[GreaterEqual] 4, 
        x[1] + x[2] + x[3] + x[4] + x[5] \[LessEqual] 7}, {1, 1, 1\/6, 1\/6, 
        1, 1\/6, 1\/6, 1\/6, 1\/6, 
        1\/3}, {{1\/6, 4\/3, 4\/3, 3\/2, 8\/3}, {1\/6, 4\/3, 4\/3, 8\/3, 
          3\/2}, {1, 1, 1, 2, 2}, {1, 1, 3, 1, 1}, {1, 3, 1, 1, 1}, {4\/3, 
          1\/6, 4\/3, 3\/2, 8\/3}, {4\/3, 1\/6, 4\/3, 8\/3, 3\/2}, {4\/3, 
          4\/3, 1\/6, 3\/2, 8\/3}, {4\/3, 4\/3, 1\/6, 8\/3, 3\/2}, {5\/3, 
          5\/3, 5\/3, 1, 1}, {3, 1, 1, 1, 1}}}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "The first return value is the kernel solution, the second the objective \
function, the third the constraint set, the fourth contains  values of the \
largest bi-symmetrical transfer and the last value returns in general a list \
of possible kernel candidates that have been computed from the ",
  StyleBox["n(n-1)/2",
    FontSlant->"Italic"],
  " initial LPs. Note, that according to this procedure the function becomes \
very slow for huge games.  A good strategy is to find out a first kernel \
element by the function ",
  StyleBox["Kernel[]",
    FontWeight->"Bold"],
  ". This function is in average 10 times faster than the function ",
  StyleBox["KernelCalculation[]",
    FontWeight->"Bold"],
  ".  Moreover, we have found out that you can also speed up the calculation \
with the above commands by providing one of the critical value that have been \
introduced by ",
  ButtonBox["Maschler, Peleg and Shapley",
    ButtonData:>"M. Maschler",
    ButtonStyle->"Hyperlink"],
  " (1979) to vary the strong epsilon core instead of using the default value \
zero."
}], "Text",
  TextJustification->1],

Cell["The complete set of options can be seen by", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Options[KernelCalculation]\)], "Input"],

Cell[BoxData[
    \({CallMaximize \[Rule] False, ChangeInternalEps \[Rule] False, 
      DisplayAllResults \[Rule] False, EpsilonValue \[Rule] 0, 
      SetGameToNonZeroMonotonic \[Rule] False}\)], "Output"]
}, Open  ]],

Cell["and for the function Kernel by calling", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Options[Kernel]\)], "Input"],

Cell[BoxData[
    \({CallMaximize \[Rule] False, DisplayAllResults \[Rule] False, 
      EpsilonValue \[Rule] 0}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Now have a look what returns the function ",
  StyleBox["Kernel[]  ",
    FontWeight->"Bold"],
  StyleBox["by invoking the option DisplayAllResults",
    FontVariations->{"CompatibilityType"->0}]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \({sol3, object3, con3, var3, trans3} = 
      Kernel[ExpGame3, DisplayAllResults \[Rule] \ True]\)], "Input"],

Cell[BoxData[
    \("Game has nonempty core"\)], "Print"],

Cell[BoxData[
    \({{1, 1, 1, 2, 
        2}, \[Delta][1, 2] + \[Delta][1, 3] + \[Delta][1, 4] + \[Delta][1, 
          5] + \[Delta][2, 3] + \[Delta][2, 4] + \[Delta][2, 5] + \[Delta][3, 
          4] + \[Delta][3, 5] + \[Delta][4, 
          5], {x[1] + x[2] + x[3] + x[4] + x[5] \[Equal] 7, 
        x[1] \[GreaterEqual] 0, x[2] \[GreaterEqual] 0, 
        x[1] + x[2] \[GreaterEqual] 0, x[3] \[GreaterEqual] 0, 
        x[1] + x[3] \[GreaterEqual] 0, x[2] + x[3] \[GreaterEqual] 0, 
        x[1] + x[2] + x[3] \[GreaterEqual] 0, x[4] \[GreaterEqual] 0, 
        x[1] + x[4] \[GreaterEqual] 0, x[2] + x[4] \[GreaterEqual] 0, 
        x[1] + x[2] + x[4] \[GreaterEqual] 4, x[3] + x[4] \[GreaterEqual] 0, 
        x[1] + x[3] + x[4] \[GreaterEqual] 4, 
        x[2] + x[3] + x[4] \[GreaterEqual] 4, 
        x[1] + x[2] + x[3] + x[4] \[GreaterEqual] 0, x[5] \[GreaterEqual] 0, 
        x[1] + x[5] \[GreaterEqual] 0, x[2] + x[5] \[GreaterEqual] 0, 
        x[1] + x[2] + x[5] \[GreaterEqual] 4, x[3] + x[5] \[GreaterEqual] 0, 
        x[1] + x[3] + x[5] \[GreaterEqual] 4, 
        x[2] + x[3] + x[5] \[GreaterEqual] 4, 
        x[1] + x[2] + x[3] + x[5] \[GreaterEqual] 0, 
        x[4] + x[5] \[GreaterEqual] 4, x[1] + x[4] + x[5] \[GreaterEqual] 0, 
        x[2] + x[4] + x[5] \[GreaterEqual] 0, 
        x[1] + x[2] + x[4] + x[5] \[GreaterEqual] 0, 
        x[3] + x[4] + x[5] \[GreaterEqual] 0, 
        x[1] + x[3] + x[4] + x[5] \[GreaterEqual] 0, 
        x[2] + x[3] + x[4] + x[5] \[GreaterEqual] 0, 
        x[1] - \[Delta][1, 2] \[GreaterEqual] 0, 
        x[2] - \[Delta][1, 2] \[GreaterEqual] 0, 
        x[1] + x[3] - \[Delta][1, 2] \[GreaterEqual] 0, 
        x[2] + x[3] - \[Delta][1, 2] \[GreaterEqual] 0, 
        x[1] + x[4] - \[Delta][1, 2] \[GreaterEqual] 0, 
        x[2] + x[4] - \[Delta][1, 2] \[GreaterEqual] 0, 
        x[1] + x[3] + x[4] - \[Delta][1, 2] \[GreaterEqual] 4, 
        x[2] + x[3] + x[4] - \[Delta][1, 2] \[GreaterEqual] 4, 
        x[1] + x[5] - \[Delta][1, 2] \[GreaterEqual] 0, 
        x[2] + x[5] - \[Delta][1, 2] \[GreaterEqual] 0, 
        x[1] + x[3] + x[5] - \[Delta][1, 2] \[GreaterEqual] 4, 
        x[2] + x[3] + x[5] - \[Delta][1, 2] \[GreaterEqual] 4, 
        x[1] + x[4] + x[5] - \[Delta][1, 2] \[GreaterEqual] 0, 
        x[2] + x[4] + x[5] - \[Delta][1, 2] \[GreaterEqual] 0, 
        x[1] + x[3] + x[4] + x[5] - \[Delta][1, 2] \[GreaterEqual] 0, 
        x[2] + x[3] + x[4] + x[5] - \[Delta][1, 2] \[GreaterEqual] 
          0, \[Delta][1, 2] \[GreaterEqual] 0, 
        x[1] - \[Delta][1, 3] \[GreaterEqual] 0, 
        x[1] + x[2] - \[Delta][1, 3] \[GreaterEqual] 0, 
        x[3] - \[Delta][1, 3] \[GreaterEqual] 0, 
        x[2] + x[3] - \[Delta][1, 3] \[GreaterEqual] 0, 
        x[1] + x[4] - \[Delta][1, 3] \[GreaterEqual] 0, 
        x[1] + x[2] + x[4] - \[Delta][1, 3] \[GreaterEqual] 4, 
        x[3] + x[4] - \[Delta][1, 3] \[GreaterEqual] 0, 
        x[2] + x[3] + x[4] - \[Delta][1, 3] \[GreaterEqual] 4, 
        x[1] + x[5] - \[Delta][1, 3] \[GreaterEqual] 0, 
        x[1] + x[2] + x[5] - \[Delta][1, 3] \[GreaterEqual] 4, 
        x[3] + x[5] - \[Delta][1, 3] \[GreaterEqual] 0, 
        x[2] + x[3] + x[5] - \[Delta][1, 3] \[GreaterEqual] 4, 
        x[1] + x[4] + x[5] - \[Delta][1, 3] \[GreaterEqual] 0, 
        x[1] + x[2] + x[4] + x[5] - \[Delta][1, 3] \[GreaterEqual] 0, 
        x[3] + x[4] + x[5] - \[Delta][1, 3] \[GreaterEqual] 0, 
        x[2] + x[3] + x[4] + x[5] - \[Delta][1, 3] \[GreaterEqual] 
          0, \[Delta][1, 3] \[GreaterEqual] 0, 
        x[1] - \[Delta][1, 4] \[GreaterEqual] 0, 
        x[1] + x[2] - \[Delta][1, 4] \[GreaterEqual] 0, 
        x[1] + x[3] - \[Delta][1, 4] \[GreaterEqual] 0, 
        x[1] + x[2] + x[3] - \[Delta][1, 4] \[GreaterEqual] 0, 
        x[4] - \[Delta][1, 4] \[GreaterEqual] 0, 
        x[2] + x[4] - \[Delta][1, 4] \[GreaterEqual] 0, 
        x[3] + x[4] - \[Delta][1, 4] \[GreaterEqual] 0, 
        x[2] + x[3] + x[4] - \[Delta][1, 4] \[GreaterEqual] 4, 
        x[1] + x[5] - \[Delta][1, 4] \[GreaterEqual] 0, 
        x[1] + x[2] + x[5] - \[Delta][1, 4] \[GreaterEqual] 4, 
        x[1] + x[3] + x[5] - \[Delta][1, 4] \[GreaterEqual] 4, 
        x[1] + x[2] + x[3] + x[5] - \[Delta][1, 4] \[GreaterEqual] 0, 
        x[4] + x[5] - \[Delta][1, 4] \[GreaterEqual] 4, 
        x[2] + x[4] + x[5] - \[Delta][1, 4] \[GreaterEqual] 0, 
        x[3] + x[4] + x[5] - \[Delta][1, 4] \[GreaterEqual] 0, 
        x[2] + x[3] + x[4] + x[5] - \[Delta][1, 4] \[GreaterEqual] 
          0, \[Delta][1, 4] \[GreaterEqual] 0, 
        x[1] - \[Delta][1, 5] \[GreaterEqual] 0, 
        x[1] + x[2] - \[Delta][1, 5] \[GreaterEqual] 0, 
        x[1] + x[3] - \[Delta][1, 5] \[GreaterEqual] 0, 
        x[1] + x[2] + x[3] - \[Delta][1, 5] \[GreaterEqual] 0, 
        x[1] + x[4] - \[Delta][1, 5] \[GreaterEqual] 0, 
        x[1] + x[2] + x[4] - \[Delta][1, 5] \[GreaterEqual] 4, 
        x[1] + x[3] + x[4] - \[Delta][1, 5] \[GreaterEqual] 4, 
        x[1] + x[2] + x[3] + x[4] - \[Delta][1, 5] \[GreaterEqual] 0, 
        x[5] - \[Delta][1, 5] \[GreaterEqual] 0, 
        x[2] + x[5] - \[Delta][1, 5] \[GreaterEqual] 0, 
        x[3] + x[5] - \[Delta][1, 5] \[GreaterEqual] 0, 
        x[2] + x[3] + x[5] - \[Delta][1, 5] \[GreaterEqual] 4, 
        x[4] + x[5] - \[Delta][1, 5] \[GreaterEqual] 4, 
        x[2] + x[4] + x[5] - \[Delta][1, 5] \[GreaterEqual] 0, 
        x[3] + x[4] + x[5] - \[Delta][1, 5] \[GreaterEqual] 0, 
        x[2] + x[3] + x[4] + x[5] - \[Delta][1, 5] \[GreaterEqual] 
          0, \[Delta][1, 5] \[GreaterEqual] 0, 
        x[2] - \[Delta][2, 3] \[GreaterEqual] 0, 
        x[1] + x[2] - \[Delta][2, 3] \[GreaterEqual] 0, 
        x[3] - \[Delta][2, 3] \[GreaterEqual] 0, 
        x[1] + x[3] - \[Delta][2, 3] \[GreaterEqual] 0, 
        x[2] + x[4] - \[Delta][2, 3] \[GreaterEqual] 0, 
        x[1] + x[2] + x[4] - \[Delta][2, 3] \[GreaterEqual] 4, 
        x[3] + x[4] - \[Delta][2, 3] \[GreaterEqual] 0, 
        x[1] + x[3] + x[4] - \[Delta][2, 3] \[GreaterEqual] 4, 
        x[2] + x[5] - \[Delta][2, 3] \[GreaterEqual] 0, 
        x[1] + x[2] + x[5] - \[Delta][2, 3] \[GreaterEqual] 4, 
        x[3] + x[5] - \[Delta][2, 3] \[GreaterEqual] 0, 
        x[1] + x[3] + x[5] - \[Delta][2, 3] \[GreaterEqual] 4, 
        x[2] + x[4] + x[5] - \[Delta][2, 3] \[GreaterEqual] 0, 
        x[1] + x[2] + x[4] + x[5] - \[Delta][2, 3] \[GreaterEqual] 0, 
        x[3] + x[4] + x[5] - \[Delta][2, 3] \[GreaterEqual] 0, 
        x[1] + x[3] + x[4] + x[5] - \[Delta][2, 3] \[GreaterEqual] 
          0, \[Delta][2, 3] \[GreaterEqual] 0, 
        x[2] - \[Delta][2, 4] \[GreaterEqual] 0, 
        x[1] + x[2] - \[Delta][2, 4] \[GreaterEqual] 0, 
        x[2] + x[3] - \[Delta][2, 4] \[GreaterEqual] 0, 
        x[1] + x[2] + x[3] - \[Delta][2, 4] \[GreaterEqual] 0, 
        x[4] - \[Delta][2, 4] \[GreaterEqual] 0, 
        x[1] + x[4] - \[Delta][2, 4] \[GreaterEqual] 0, 
        x[3] + x[4] - \[Delta][2, 4] \[GreaterEqual] 0, 
        x[1] + x[3] + x[4] - \[Delta][2, 4] \[GreaterEqual] 4, 
        x[2] + x[5] - \[Delta][2, 4] \[GreaterEqual] 0, 
        x[1] + x[2] + x[5] - \[Delta][2, 4] \[GreaterEqual] 4, 
        x[2] + x[3] + x[5] - \[Delta][2, 4] \[GreaterEqual] 4, 
        x[1] + x[2] + x[3] + x[5] - \[Delta][2, 4] \[GreaterEqual] 0, 
        x[4] + x[5] - \[Delta][2, 4] \[GreaterEqual] 4, 
        x[1] + x[4] + x[5] - \[Delta][2, 4] \[GreaterEqual] 0, 
        x[3] + x[4] + x[5] - \[Delta][2, 4] \[GreaterEqual] 0, 
        x[1] + x[3] + x[4] + x[5] - \[Delta][2, 4] \[GreaterEqual] 
          0, \[Delta][2, 4] \[GreaterEqual] 0, 
        x[2] - \[Delta][2, 5] \[GreaterEqual] 0, 
        x[1] + x[2] - \[Delta][2, 5] \[GreaterEqual] 0, 
        x[2] + x[3] - \[Delta][2, 5] \[GreaterEqual] 0, 
        x[1] + x[2] + x[3] - \[Delta][2, 5] \[GreaterEqual] 0, 
        x[2] + x[4] - \[Delta][2, 5] \[GreaterEqual] 0, 
        x[1] + x[2] + x[4] - \[Delta][2, 5] \[GreaterEqual] 4, 
        x[2] + x[3] + x[4] - \[Delta][2, 5] \[GreaterEqual] 4, 
        x[1] + x[2] + x[3] + x[4] - \[Delta][2, 5] \[GreaterEqual] 0, 
        x[5] - \[Delta][2, 5] \[GreaterEqual] 0, 
        x[1] + x[5] - \[Delta][2, 5] \[GreaterEqual] 0, 
        x[3] + x[5] - \[Delta][2, 5] \[GreaterEqual] 0, 
        x[1] + x[3] + x[5] - \[Delta][2, 5] \[GreaterEqual] 4, 
        x[4] + x[5] - \[Delta][2, 5] \[GreaterEqual] 4, 
        x[1] + x[4] + x[5] - \[Delta][2, 5] \[GreaterEqual] 0, 
        x[3] + x[4] + x[5] - \[Delta][2, 5] \[GreaterEqual] 0, 
        x[1] + x[3] + x[4] + x[5] - \[Delta][2, 5] \[GreaterEqual] 
          0, \[Delta][2, 5] \[GreaterEqual] 0, 
        x[3] - \[Delta][3, 4] \[GreaterEqual] 0, 
        x[1] + x[3] - \[Delta][3, 4] \[GreaterEqual] 0, 
        x[2] + x[3] - \[Delta][3, 4] \[GreaterEqual] 0, 
        x[1] + x[2] + x[3] - \[Delta][3, 4] \[GreaterEqual] 0, 
        x[4] - \[Delta][3, 4] \[GreaterEqual] 0, 
        x[1] + x[4] - \[Delta][3, 4] \[GreaterEqual] 0, 
        x[2] + x[4] - \[Delta][3, 4] \[GreaterEqual] 0, 
        x[1] + x[2] + x[4] - \[Delta][3, 4] \[GreaterEqual] 4, 
        x[3] + x[5] - \[Delta][3, 4] \[GreaterEqual] 0, 
        x[1] + x[3] + x[5] - \[Delta][3, 4] \[GreaterEqual] 4, 
        x[2] + x[3] + x[5] - \[Delta][3, 4] \[GreaterEqual] 4, 
        x[1] + x[2] + x[3] + x[5] - \[Delta][3, 4] \[GreaterEqual] 0, 
        x[4] + x[5] - \[Delta][3, 4] \[GreaterEqual] 4, 
        x[1] + x[4] + x[5] - \[Delta][3, 4] \[GreaterEqual] 0, 
        x[2] + x[4] + x[5] - \[Delta][3, 4] \[GreaterEqual] 0, 
        x[1] + x[2] + x[4] + x[5] - \[Delta][3, 4] \[GreaterEqual] 
          0, \[Delta][3, 4] \[GreaterEqual] 0, 
        x[3] - \[Delta][3, 5] \[GreaterEqual] 0, 
        x[1] + x[3] - \[Delta][3, 5] \[GreaterEqual] 0, 
        x[2] + x[3] - \[Delta][3, 5] \[GreaterEqual] 0, 
        x[1] + x[2] + x[3] - \[Delta][3, 5] \[GreaterEqual] 0, 
        x[3] + x[4] - \[Delta][3, 5] \[GreaterEqual] 0, 
        x[1] + x[3] + x[4] - \[Delta][3, 5] \[GreaterEqual] 4, 
        x[2] + x[3] + x[4] - \[Delta][3, 5] \[GreaterEqual] 4, 
        x[1] + x[2] + x[3] + x[4] - \[Delta][3, 5] \[GreaterEqual] 0, 
        x[5] - \[Delta][3, 5] \[GreaterEqual] 0, 
        x[1] + x[5] - \[Delta][3, 5] \[GreaterEqual] 0, 
        x[2] + x[5] - \[Delta][3, 5] \[GreaterEqual] 0, 
        x[1] + x[2] + x[5] - \[Delta][3, 5] \[GreaterEqual] 4, 
        x[4] + x[5] - \[Delta][3, 5] \[GreaterEqual] 4, 
        x[1] + x[4] + x[5] - \[Delta][3, 5] \[GreaterEqual] 0, 
        x[2] + x[4] + x[5] - \[Delta][3, 5] \[GreaterEqual] 0, 
        x[1] + x[2] + x[4] + x[5] - \[Delta][3, 5] \[GreaterEqual] 
          0, \[Delta][3, 5] \[GreaterEqual] 0, 
        x[4] - \[Delta][4, 5] \[GreaterEqual] 0, 
        x[1] + x[4] - \[Delta][4, 5] \[GreaterEqual] 0, 
        x[2] + x[4] - \[Delta][4, 5] \[GreaterEqual] 0, 
        x[1] + x[2] + x[4] - \[Delta][4, 5] \[GreaterEqual] 4, 
        x[3] + x[4] - \[Delta][4, 5] \[GreaterEqual] 0, 
        x[1] + x[3] + x[4] - \[Delta][4, 5] \[GreaterEqual] 4, 
        x[2] + x[3] + x[4] - \[Delta][4, 5] \[GreaterEqual] 4, 
        x[1] + x[2] + x[3] + x[4] - \[Delta][4, 5] \[GreaterEqual] 0, 
        x[5] - \[Delta][4, 5] \[GreaterEqual] 0, 
        x[1] + x[5] - \[Delta][4, 5] \[GreaterEqual] 0, 
        x[2] + x[5] - \[Delta][4, 5] \[GreaterEqual] 0, 
        x[1] + x[2] + x[5] - \[Delta][4, 5] \[GreaterEqual] 4, 
        x[3] + x[5] - \[Delta][4, 5] \[GreaterEqual] 0, 
        x[1] + x[3] + x[5] - \[Delta][4, 5] \[GreaterEqual] 4, 
        x[2] + x[3] + x[5] - \[Delta][4, 5] \[GreaterEqual] 4, 
        x[1] + x[2] + x[3] + x[5] - \[Delta][4, 5] \[GreaterEqual] 
          0, \[Delta][4, 5] \[GreaterEqual] 0}, {x[1], x[2], x[3], x[4], 
        x[5], \[Delta][1, 2], \[Delta][1, 3], \[Delta][1, 4], \[Delta][1, 
          5], \[Delta][2, 3], \[Delta][2, 4], \[Delta][2, 5], \[Delta][3, 
          4], \[Delta][3, 5], \[Delta][4, 5]}, {0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0}}\)], "Output"]
}, Open  ]],

Cell["\<\
The first three return values are the same as above. The last but \
one return value stores all variables of the LP and the last provides \
information about the transfers in each direction such that the endpoints of \
the line segment remain in the strong epsilon-core.\
\>", "Text",
  TextJustification->1],

Cell[CellGroupData[{

Cell[BoxData[
    \(trans3\)], "Input"],

Cell[BoxData[
    \({0, 0, 0, 0, 0, 0, 0, 0, 0, 0}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "The result states that it is not possible to transfer a positive amount in \
each direction without leaving the core. To check this, let us determine, if \
an endpoint of the line segment 1-2  belongs to the core if we transfer a \
half unit from player 1 to player 2 from the derived kernel solution. The \
function ",
  StyleBox["Transfer[]",
    FontWeight->"Bold"],
  " needs five input ",
  "arguments",
  ", the initial imputation, the whole player set, the transfer amount, the \
player from whom we extract the transfer amount and the player who receives \
it."
}], "Text",
  TextJustification->1],

Cell[CellGroupData[{

Cell[BoxData[
    \(tr1 = Transfer[sol3, T3, 1\/2, 1, 2]\)], "Input"],

Cell[BoxData[
    \({1\/2, 3\/2, 1, 2, 2}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(InCoreQ[tr1, ExpGame3]\)], "Input"],

Cell[BoxData[
    \(False\)], "Output"]
}, Open  ]],

Cell["Next let us remain in the initial payoff distribution.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(tr2 = Transfer[sol3, T3, 0, 1, 2]\)], "Input"],

Cell[BoxData[
    \({1, 1, 1, 2, 2}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(InCoreQ[tr2, ExpGame3]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell["\<\
In the last example we take from the initial distribution a half \
unit away from player 2 to give it player 1.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(tr3 = Transfer[sol3, T3, \(-1\)\/2, 1, 2]\)], "Input"],

Cell[BoxData[
    \({3\/2, 1\/2, 1, 2, 2}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(InCoreQ[tr3, ExpGame3]\)], "Input"],

Cell[BoxData[
    \(False\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Recall that all Kernel commands based on the built-in  ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " command ",
  StyleBox["ConstrainedMax[]",
    FontWeight->"Bold"],
  ". Unfortunately, this command offers no control on the solver. That's why, \
we let us also return the whole final LP that computes us a kernel element \
with the intention to export this final LP to a mathematical software that \
offers more control on the solver. In some respect one can overcome this \
shortcoming by computing kernel elements by varying the strong epsilon core. \
This can be done by calculating in a first step some critical values. For \
instance the command ",
  StyleBox["FirstCriticalVal[]",
    FontWeight->"Bold"],
  " calculates the smallest epsilon value such that the epsilon-core  is \
non-empty (cf. ",
  ButtonBox["Maschler, Peleg and Shapley",
    ButtonData:>"M. Maschler",
    ButtonStyle->"Hyperlink"],
  " (1979)). "
}], "Text",
  TextJustification->1],

Cell[CellGroupData[{

Cell[BoxData[
    \(FirstCriticalVal[ExpGame1]\)], "Input"],

Cell[BoxData[
    \({eps1 \[Rule] \(-\(45\/2\)\)}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(FirstCriticalVal[ExpGame2]\)], "Input"],

Cell[BoxData[
    \({eps1 \[Rule] \(-\(45\/2\)\)}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(FirstCriticalVal[ExpGame3]\)], "Input"],

Cell[BoxData[
    \({eps1 \[Rule] 0}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(FirstCriticalVal[ExpGame4]\)], "Input"],

Cell[BoxData[
    \({eps1 \[Rule] \(-\(3\/16\)\)}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(SecondCriticalVal[ExpGame3]\)], "Input"],

Cell[BoxData[
    \({eps2 \[Rule] 4}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ThirdCriticalVal[ExpGame3]\)], "Input"],

Cell[BoxData[
    \({eps3 \[Rule] 21}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(FourthCriticalVal[ExpGame3]\)], "Input"],

Cell[BoxData[
    \({eps4 \[Rule] 4}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(FifthCriticalVal[ExpGame3]\)], "Input"],

Cell[BoxData[
    \({eps5 \[Rule] 16}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(StarCriticalVal[ExpGame3]\)], "Input"],

Cell[BoxData[
    \({stareps \[Rule] 4}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(SecondStarCriticalVal[ExpGame3]\)], "Input"],

Cell[BoxData[
    \({dstareps \[Rule] 4}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ThirdStarCriticalVal[ExpGame3]\)], "Input"],

Cell[BoxData[
    \({thstareps \[Rule] 0}\)], "Output"]
}, Open  ]],

Cell["\<\
Now let us demonstrate that we are able to compute the complete \
kernel of a game.\
\>", "Text"],

Cell[BoxData[
    \(\(ExpGame9 := \((DefineGame[T3, vec3]; v[{2, 5}] = 1; v[{3, 5}] = 1; 
          v[{4, 5}] = 1; v[{1, 2, 3}] = 11\/12; v[{1, 2, 4}] = 1; 
          v[{1, 2, 5}] = 1; v[{1, 3, 4}] = 1; v[{1, 3, 5}] = 1; 
          v[{1, 4, 5}] = 1; v[{2, 3, 4}] = 1; v[{2, 3, 5}] = 1; 
          v[{2, 4, 5}] = 1; v[{3, 4, 5}] = 1; v[{1, 2, 3, 4}] = 1; 
          v[{1, 2, 3, 5}] = 1; v[{1, 2, 4, 5}] = 1; v[{2, 3, 4, 5}] = 1; 
          v[T3] = 2;)\);\)\)], "Input"],

Cell[TextData[{
  "The kernel of this game is given by the union of the following three line \
segments (cf. ",
  ButtonBox["Maschler and Peleg",
    ButtonData:>"References",
    ButtonStyle->"Hyperlink"],
  "  (1966,p.322)):\n",
  Cell[BoxData[
      \(TraditionalForm\`J\_1 = \([\ {0, 1, 1, 1, 1}/2, {1, 11, 11, 12, 13}/
            24]\)\)]],
  "\n",
  Cell[BoxData[
      \(TraditionalForm\`J\_2\  = \ \([{7, 8, 8, 9, 16}/
            24, \ {1, 11, 11, 12, 13}/24]\)\)]],
  "\n",
  Cell[BoxData[
      \(TraditionalForm\`J\_3\  = \([{7, 8, 8, 9, 16}/
            24, {11, 11, 11, 14, 25}/36]\)\)]]
}], "Text",
  TextJustification->1,
  CellTags->"MP66"],

Cell[TextData[{
  "Note first that specifying an epsilon value can speed up the calculation \
time by using the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " function ",
  StyleBox["ConstrainedMax[].",
    FontWeight->"Bold"]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \({time9, ker9} = AbsoluteTiming[Kernel[ExpGame9]]\)], "Input"],

Cell[BoxData[
    \("Game has nonempty core"\)], "Print"],

Cell[BoxData[
    \({2.222048`6.798298429698468\ Second, {7\/24, 1\/3, 1\/3, 3\/8, 
        2\/3}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \({time091, ker9} = 
      AbsoluteTiming[Kernel[ExpGame9, EpsilonValue \[Rule] \ 3]]\)], "Input"],

Cell[BoxData[
    \({0.602216`6.231297283396393\ Second, {7\/24, 1\/3, 1\/3, 3\/8, 
        2\/3}}\)], "Output"]
}, Open  ]],

Cell["\<\
We can also to try to find out some kernel segment by using the \
command:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(KernelVertices[ExpGame9]\)], "Input"],

Cell[BoxData[
    \("Game has nonempty core"\)], "Print"],

Cell[BoxData[
    \({{1\/24, 11\/24, 11\/24, 1\/2, 13\/24}, {7\/24, 1\/3, 1\/3, 3\/8, 
        2\/3}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \({time92, {sol9, pay9}} = 
      AbsoluteTiming[KernelCalculation[ExpGame9]]\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("Game is average-convex? "\[InvisibleSpace]False\),
      SequenceForm[ "Game is average-convex? ", False],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("A Kernel solution is: "\[InvisibleSpace]{x[
              1] \[Rule] 7\/24, x[2] \[Rule] 1\/3, x[3] \[Rule] 1\/3, 
          x[4] \[Rule] 3\/8, x[5] \[Rule] 2\/3}\),
      SequenceForm[ 
      "A Kernel solution is: ", {x[ 1] -> Rational[ 7, 24], x[ 2] -> Rational[
         1, 3], x[ 3] -> Rational[ 1, 3], x[ 4] -> Rational[ 3, 8], x[ 5] -> 
        Rational[ 2, 3]}],
      Editable->False]], "Print"],

Cell[BoxData[
    \({14.511696`7.613263165437368\ Second, {{7\/24, 1\/3, 1\/3, 3\/8, 
          2\/3}, {{0, 11\/24, 11\/24, 13\/24, 13\/24}, {0, 1\/2, 1\/2, 1\/2, 
            1\/2}, {7\/24, 1\/3, 1\/3, 3\/8, 2\/3}, {11\/36, 11\/36, 11\/36, 
            7\/18, 25\/36}, {1\/3, 1\/3, 1\/3, 1\/3, 2\/3}}}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(kerli9 = KernelImputationListQ[ExpGame9, pay9]\)], "Input"],

Cell[BoxData[
    \({False, True, True, True, False}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ps = Position[kerli9, True]\)], "Input"],

Cell[BoxData[
    \({{2}, {3}, {4}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(kerel = Extract[pay9, ps]\)], "Input"],

Cell[BoxData[
    \({{0, 1\/2, 1\/2, 1\/2, 1\/2}, {7\/24, 1\/3, 1\/3, 3\/8, 2\/3}, {11\/36, 
        11\/36, 11\/36, 7\/18, 25\/36}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \({time9, {sol91, pay91}} = 
      AbsoluteTiming[
        KernelCalculation[ExpGame9, EpsilonValue \[Rule] 3]]\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("Game is zero-monotone? "\[InvisibleSpace]False\),
      SequenceForm[ "Game is zero-monotone? ", False],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Core is nonempty? "\[InvisibleSpace]True\),
      SequenceForm[ "Core is nonempty? ", True],
      Editable->False]], "Print"],

Cell[BoxData[
    \("Game is either zero-monotonic or has nonempty core"\)], "Print"],

Cell[BoxData[
    InterpretationBox[\("A Kernel solution is: "\[InvisibleSpace]{x[
              1] \[Rule] 1\/24, x[2] \[Rule] 11\/24, x[3] \[Rule] 11\/24, 
          x[4] \[Rule] 1\/2, x[5] \[Rule] 13\/24}\),
      SequenceForm[ 
      "A Kernel solution is: ", {x[ 1] -> Rational[ 1, 24], x[ 2] -> Rational[
         11, 24], x[ 3] -> Rational[ 11, 24], x[ 4] -> Rational[ 1, 2], x[ 5] -> 
        Rational[ 13, 24]}],
      Editable->False]], "Print"],

Cell[BoxData[
    \({7.989676`7.354074161512693\ Second, {{1\/24, 11\/24, 11\/24, 1\/2, 
          13\/24}, {{0, 0, 1, 1, 0}, {0, 1\/2, 1\/2, 1\/2, 1\/2}, {0, 1, 0, 
            1, 0}, {0, 1, 1, 0, 0}, {7\/24, 1\/3, 1\/3, 3\/8, 2\/3}, {19\/24, 
            1\/12, 1\/12, 7\/8, 1\/6}, {1, 0, 1, 0, 0}, {1, 1, 0, 0, 
            0}}}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(AppendTo[kerel, sol91]\)], "Input"],

Cell[BoxData[
    \({{0, 1\/2, 1\/2, 1\/2, 1\/2}, {7\/24, 1\/3, 1\/3, 3\/8, 2\/3}, {11\/36, 
        11\/36, 11\/36, 7\/18, 25\/36}, {1\/24, 11\/24, 11\/24, 1\/2, 
        13\/24}}\)], "Output"]
}, Open  ]],

Cell["This is exactly the kernel solution.", "Text"],

Cell[TextData[{
  "Instead of computing kernel solutions with an LP approach, we can also \
compute a kernel element by relying on a convergence algorithm. We \
implemented an algorithm that was due to Maschler by iteratively carrying out \
transfers between pairs of players. Details of the algorithm can be found in \
",
  ButtonBox["Faigle, Kern and Kuipers",
    ButtonData:>"References",
    ButtonStyle->"Hyperlink"],
  " (1998). Note that the algorithm is implemented by using recursion. The \
default value is set to 512 and can be changed with the option \
SetRecursionLimit. We invoke the algorithm by calling the function \
FindKernelSolution[game,payoff,options] and the options can be find out by \
calling"
}], "Text",
  TextJustification->1,
  CellTags->"Faigle98"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Options[FindKernelSolution]\)], "Input"],

Cell[BoxData[
    \({DigitPrecision \[Rule] 6, RationalTol \[Rule] 1\/10000000, 
      SetRecursionLimit \[Rule] 512, Silent \[Rule] True}\)], "Output"]
}, Open  ]],

Cell["\<\
To check out how the function works, let us first construct some \
payoff vectors.\
\>", "Text"],

Cell[BoxData[{
    \(\(c1 = {2, 0, 0, 0, 0};\)\), "\[IndentingNewLine]", 
    \(\(c2 = Permutations[c1];\)\)}], "Input"],

Cell["Computing a pre-kernel element can be done by", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \({tc1, c1kern1} = 
      AbsoluteTiming[FindKernelSolution[ExpGame9, c1]]\)], "Input"],

Cell[BoxData[
    \({3.730658`7.023330431354646\ Second, {1\/4, 17\/48, 17\/48, 19\/48, 
        31\/48}}\)], "Output"]
}, Open  ]],

Cell["or", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \({tc2, c1kern2} = 
      AbsoluteTiming[FindKernelSolution[ExpGame9, c2]]\)], "Input"],

Cell[BoxData[
    \({16.604043`7.671758842909665\ Second, {{1\/4, 17\/48, 17\/48, 19\/48, 
          31\/48}, {1\/4, 17\/48, 17\/48, 19\/48, 31\/48}, {1\/4, 17\/48, 
          17\/48, 19\/48, 31\/48}, {1\/24, 11\/24, 11\/24, 1\/2, 
          13\/24}, {13\/48, 11\/32, 11\/32, 37\/96, 21\/32}}}\)], "Output"]
}, Open  ]],

Cell["By using the kernel candidates of pay91 we compute", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \({tc3, c1kern3} = 
      AbsoluteTiming[FindKernelSolution[ExpGame9, pay91]]\)], "Input"],

Cell[BoxData[
    \({18.746741`7.724470772827149\ Second, {{1\/24, 11\/24, 11\/24, 1\/2, 
          13\/24}, {0, 1\/2, 1\/2, 1\/2, 1\/2}, {1\/24, 11\/24, 11\/24, 1\/2, 
          13\/24}, {1\/4, 17\/48, 17\/48, 19\/48, 31\/48}, {7\/24, 1\/3, 
          1\/3, 3\/8, 2\/3}, {9\/32, 65\/192, 65\/192, 73\/192, 
          127\/192}, {1\/4, 17\/48, 17\/48, 19\/48, 31\/48}, {1\/4, 17\/48, 
          17\/48, 19\/48, 31\/48}}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(c2k2 = Union[c1kern2]\)], "Input"],

Cell[BoxData[
    \({{1\/24, 11\/24, 11\/24, 1\/2, 13\/24}, {1\/4, 17\/48, 17\/48, 19\/48, 
        31\/48}, {13\/48, 11\/32, 11\/32, 37\/96, 21\/32}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(c2k3 = Union[c1kern3]\)], "Input"],

Cell[BoxData[
    \({{0, 1\/2, 1\/2, 1\/2, 1\/2}, {1\/24, 11\/24, 11\/24, 1\/2, 
        13\/24}, {1\/4, 17\/48, 17\/48, 19\/48, 31\/48}, {9\/32, 65\/192, 
        65\/192, 73\/192, 127\/192}, {7\/24, 1\/3, 1\/3, 3\/8, 
        2\/3}}\)], "Output"]
}, Open  ]],

Cell["\<\
Verifying that the computed solutions are really kernel elements \
can be done by\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(KernelImputationListQ[ExpGame9, #] &\) /@ {c2k2, c2k3}\)], "Input"],

Cell[BoxData[
    \({{True, True, True}, {True, True, True, True, True}}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "For non-zero-monotonic games we are able to compute pre-kernel elements by \
invoking the function ",
  StyleBox["FindPreKernelSolution[]",
    FontWeight->"Bold"],
  ". The function works in the same vein as ",
  StyleBox["FindKernelSolution[]",
    FontWeight->"Bold"],
  ", since they are based on the same algorithm. Therefore, for \
zero-monotonic games they will compute the same results."
}], "Text",
  TextJustification->1],

Cell[CellGroupData[{

Cell[BoxData[
    \({tc4, c1kern4} = 
      AbsoluteTiming[FindPreKernelSolution[ExpGame9, pay91]]\)], "Input"],

Cell[BoxData[
    \({15.608966`7.6449191281171505\ Second, {{1\/24, 11\/24, 11\/24, 1\/2, 
          13\/24}, {0, 1\/2, 1\/2, 1\/2, 1\/2}, {1\/24, 11\/24, 11\/24, 1\/2, 
          13\/24}, {1\/4, 17\/48, 17\/48, 19\/48, 31\/48}, {7\/24, 1\/3, 
          1\/3, 3\/8, 2\/3}, {9\/32, 65\/192, 65\/192, 73\/192, 
          127\/192}, {1\/4, 17\/48, 17\/48, 19\/48, 31\/48}, {1\/4, 17\/48, 
          17\/48, 19\/48, 31\/48}}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(c1kern3 == c1kern4\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "For non-zero-monotonic games the pre-kernel and the kernel solution are \
different. Recall the following three person example given by ",
  ButtonBox["Maschler, Peleg and Shapley",
    ButtonData:>"M. Maschler",
    ButtonStyle->"Hyperlink"],
  " (1979), p 316. The kernel solution is given by {20,0,15} satisfying \
individual rationality and the pre-kernel is found at {27.5,-5,17.5} where \
individual rationality is violated. Define the three person game by "
}], "Text",
  TextJustification->1],

Cell[BoxData[
    \(ExpJeux91 := \((T = {1, 2, 3}; \[IndentingNewLine]Clear[
          v]; \[IndentingNewLine]v[{}] = 0; v[{1}] = 0; v[{2}] = 0; 
        v[{3}] = 0; \[IndentingNewLine]v[{1, 2}] = 20; v[{1, 3}] = 50; 
        v[{2, 3}] = 10; \[IndentingNewLine]v[T] = 40;)\)\)], "Input"],

Cell["\<\
and indeed we compute the kernel by relying on the LP \
approach\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Kernel[ExpJeux91]\)], "Input"],

Cell[BoxData[
    \("Game has empty core"\)], "Print"],

Cell[BoxData[
    \({25, 0, 15}\)], "Output"]
}, Open  ]],

Cell["\<\
as well as by relying on the convergence algorithm by calling \
\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(kerpay91 = FindKernelSolution[ExpJeux91, {0, 0, 40}]\)], "Input"],

Cell[BoxData[
    \({25, 0, 15}\)], "Output"]
}, Open  ]],

Cell["\<\
Invoking the function to compute the pre-kernel, we get exactly the \
required result.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(prk91 = FindPreKernelSolution[ExpJeux91, {40, 0, 0}]\)], "Input"],

Cell[BoxData[
    \({55\/2, \(-5\), 35\/2}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(N[prk91]\)], "Input"],

Cell[BoxData[
    \({27.5`, \(-5.`\), 17.5`}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Now, we want to demonstrate some limitation of the Kernel computation \
associated with our approach by relying on the largest bi-symmetrical \
transfers. The core consists of a unique point",
  StyleBox[" ",
    FontWeight->"Bold"],
  "(1,1,1,2,2)",
  StyleBox[". ",
    FontWeight->"Bold"],
  " For this purpose, resume the game \"",
  StyleBox["ExpGame3",
    FontSlant->"Italic"],
  "\". ",
  ButtonBox["Maschler, Peleg and Shapley",
    ButtonData:>"M. Maschler",
    ButtonStyle->"Hyperlink"],
  " (1979) found out that the Kernel is a line segment extending from the \
core point (1,1,1,2,2) to a boundary point of the imputation set. The Kernel \
of this game is"
}], "Text",
  TextJustification->1],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`K(\[CapitalGamma])\  := {\((t, t, 
              t, \((7 - 3\ t)\)\/2, \((7 - 3\ t)\)\/2}\)\  : \ 
            0 \[LessEqual] \ t\  \[LessEqual] \ 1}\)]],
  " and the pre-kernel  ",
  Cell[BoxData[
      \(TraditionalForm\`\(K\^*\)(\[CapitalGamma])\  := {\((t, t, 
              t, \((7 - 3\ t)\)\/2, \((7 - 3\ t)\)\/2}\)\  : \ \(-0.2\) \
\[LessEqual] \ t\  \[LessEqual] \ 1}\)]],
  "."
}], "Text",
  TextAlignment->Center],

Cell["\<\
According to the calculation of the first critical value, we see \
that the core of the game coincides with the least core of the game.  Let us \
construct some pre-kernel  elements from the line segment, this can be done \
by\
\>", "Text",
  TextJustification->1],

Cell[CellGroupData[{

Cell[BoxData[
    \(kerline = 
      Table[{t, t, 
          t, \(7 - \ 3\ t\)\/2, \(7 - \(\(3\)\(\ \)\(t\)\(\ \)\)\)\/2}, {t, \
\(-3\)\/10, 11\/10, 1\/10}]\)], "Input"],

Cell[BoxData[
    \({{\(-\(3\/10\)\), \(-\(3\/10\)\), \(-\(3\/10\)\), 79\/20, 
        79\/20}, {\(-\(1\/5\)\), \(-\(1\/5\)\), \(-\(1\/5\)\), 19\/5, 
        19\/5}, {\(-\(1\/10\)\), \(-\(1\/10\)\), \(-\(1\/10\)\), 73\/20, 
        73\/20}, {0, 0, 0, 7\/2, 7\/2}, {1\/10, 1\/10, 1\/10, 67\/20, 
        67\/20}, {1\/5, 1\/5, 1\/5, 16\/5, 16\/5}, {3\/10, 3\/10, 3\/10, 
        61\/20, 61\/20}, {2\/5, 2\/5, 2\/5, 29\/10, 29\/10}, {1\/2, 1\/2, 
        1\/2, 11\/4, 11\/4}, {3\/5, 3\/5, 3\/5, 13\/5, 13\/5}, {7\/10, 7\/10, 
        7\/10, 49\/20, 49\/20}, {4\/5, 4\/5, 4\/5, 23\/10, 23\/10}, {9\/10, 
        9\/10, 9\/10, 43\/20, 43\/20}, {1, 1, 1, 2, 2}, {11\/10, 11\/10, 
        11\/10, 37\/20, 37\/20}}\)], "Output"]
}, Open  ]],

Cell["\<\
Verifying that the constructed elements are really contained in the \
line segment that constitutes the kernel solution we use the function\
\>", \
"Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(PreKernelQ[ExpGame3, kerline]\)], "Input"],

Cell[BoxData[
    \({False, True, True, True, True, True, True, True, True, True, True, 
      True, True, True, False}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(KernelImputationListQ[ExpGame3, kerline]\)], "Input"],

Cell[BoxData[
    \({False, False, False, True, True, True, True, True, True, True, True, 
      True, True, True, False}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Kernel[ExpGame3]\)], "Input"],

Cell[BoxData[
    \("Game has nonempty core"\)], "Print"],

Cell[BoxData[
    \({1, 1, 1, 2, 2}\)], "Output"]
}, Open  ]],

Cell["\<\
This kernel solution is contained in the core and coincides with \
the Nucleolus of the game.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Nucleolus[ExpGame3]\)], "Input"],

Cell[BoxData[
    \({1, 1, 1, 2, 2}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(LexiCenter[ExpGame3]\)], "Input"],

Cell[BoxData[
    \({1, 1, 1, 2, 2}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(kersol = 
      Table[Kernel[ExpGame3, EpsilonValue \[Rule] \ j], {j, 10}]\)], "Input"],

Cell[BoxData[
    \({{1, 1, 1, 2, 2}, {1, 1, 1, 2, 2}, {1, 1, 1, 2, 2}, {1, 1, 1, 2, 
        2}, {1, 1, 1, 2, 2}, {1, 1, 1, 2, 2}, {1, 1, 1, 2, 2}, {1, 1, 1, 2, 
        2}, {1, 1, 1, 2, 2}, {1, 1, 1, 2, 2}}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "By varying the critical value we see that we get in any case the same \
kernel result. This is caused due to the fact that the core consists of just \
a singleton. Enlarging the core by some epsilon values has no effect on the \
largest bi-symmetrical transfer and its associated midpoint. Clearly, the \
largest bi-symmetrical transfer varies if we enlarge the core by some epsilon \
values, but it still remains the largest transfer at the imputation computed. \
At the other kernel imputations the bi-symmetrical transfer is smaller than \
the value we will obtain at {1,1,1,2,2} ",
  ButtonBox["Meinhardt (2004)",
    ButtonData:>"(2002b)",
    ButtonStyle->"Hyperlink"],
  ". The same happens if we rely on the function ",
  StyleBox["KernelCalculation[]",
    FontWeight->"Bold"],
  " that use a different procedure to compute kernel elements.  We obtain"
}], "Text",
  TextJustification->1],

Cell[CellGroupData[{

Cell[BoxData[
    \({sol31, obj31, const31, tra31, pay31} = 
      KernelCalculation[ExpGame3, EpsilonValue \[Rule] \ 4, 
        DisplayAllResults \[Rule] \ True]\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("Game is zero-monotone? "\[InvisibleSpace]False\),
      SequenceForm[ "Game is zero-monotone? ", False],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Core is nonempty? "\[InvisibleSpace]True\),
      SequenceForm[ "Core is nonempty? ", True],
      Editable->False]], "Print"],

Cell[BoxData[
    \("Game is either zero-monotonic or has nonempty core"\)], "Print"],

Cell[BoxData[
    InterpretationBox[\("A Kernel solution is: "\[InvisibleSpace]{x[
              1] \[Rule] 1, x[2] \[Rule] 1, x[3] \[Rule] 1, x[4] \[Rule] 2, 
          x[5] \[Rule] 2}\),
      SequenceForm[ 
      "A Kernel solution is: ", {x[ 1] -> 1, x[ 2] -> 1, x[ 3] -> 1, x[ 4] -> 
        2, x[ 5] -> 2}],
      Editable->False]], "Print"],

Cell[BoxData[
    \({{1, 1, 1, 2, 2}, 
      x[1] + x[2] + x[3] + x[4] + x[5], {x[1] \[GreaterEqual] 0, 
        x[1] \[GreaterEqual] 0, x[2] \[GreaterEqual] 0, 
        x[2] \[GreaterEqual] 0, x[3] \[GreaterEqual] 0, 
        x[3] \[GreaterEqual] 0, x[4] \[GreaterEqual] 0, 
        x[1] + x[4] \[GreaterEqual] 0, x[2] + x[4] \[GreaterEqual] 0, 
        x[1] + x[2] + x[4] \[GreaterEqual] 4, 
        x[1] + x[2] + x[4] \[GreaterEqual] 4, 
        x[1] + x[2] + x[4] \[GreaterEqual] 4, x[3] + x[4] \[GreaterEqual] 0, 
        x[1] + x[3] + x[4] \[GreaterEqual] 4, 
        x[1] + x[3] + x[4] \[GreaterEqual] 4, 
        x[1] + x[3] + x[4] \[GreaterEqual] 4, 
        x[2] + x[3] + x[4] \[GreaterEqual] 4, 
        x[2] + x[3] + x[4] \[GreaterEqual] 4, 
        x[2] + x[3] + x[4] \[GreaterEqual] 4, x[5] \[GreaterEqual] 0, 
        x[1] + x[5] \[GreaterEqual] 0, x[2] + x[5] \[GreaterEqual] 0, 
        x[1] + x[2] + x[5] \[GreaterEqual] 4, 
        x[1] + x[2] + x[5] \[GreaterEqual] 4, 
        x[1] + x[2] + x[5] \[GreaterEqual] 4, x[3] + x[5] \[GreaterEqual] 0, 
        x[1] + x[3] + x[5] \[GreaterEqual] 4, 
        x[1] + x[3] + x[5] \[GreaterEqual] 4, 
        x[1] + x[3] + x[5] \[GreaterEqual] 4, 
        x[2] + x[3] + x[5] \[GreaterEqual] 4, 
        x[2] + x[3] + x[5] \[GreaterEqual] 4, 
        x[2] + x[3] + x[5] \[GreaterEqual] 4, x[4] + x[5] \[GreaterEqual] 4, 
        x[1] + x[4] + x[5] \[GreaterEqual] 0, 
        x[2] + x[4] + x[5] \[GreaterEqual] 0, 
        x[3] + x[4] + x[5] \[GreaterEqual] 0, 
        x[1] + x[2] + x[3] + x[4] + x[5] \[LessEqual] 7}, {3\/2, 3\/2, 1\/6, 
        1\/6, 3\/2, 1\/6, 1\/6, 1\/6, 1\/6, 
        1\/2}, {{1\/6, 4\/3, 4\/3, 3\/2, 8\/3}, {1\/6, 4\/3, 4\/3, 8\/3, 
          3\/2}, {1, 1, 1, 2, 2}, {4\/3, 1\/6, 4\/3, 3\/2, 8\/3}, {4\/3, 
          1\/6, 4\/3, 8\/3, 3\/2}, {4\/3, 4\/3, 1\/6, 3\/2, 8\/3}, {4\/3, 
          4\/3, 1\/6, 8\/3, 3\/2}, {3\/2, 3\/2, 4, 0, 0}, {3\/2, 4, 3\/2, 0, 
          0}, {2, 2, 2, 1\/2, 1\/2}, {4, 3\/2, 3\/2, 0, 0}}}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "In some case the ",
  StyleBox["n(n-1)/2",
    FontSlant->"Italic"],
  " initial LPs provide some additional kernel elements. These kernel \
candidates have been stored for the above example in the symbol ",
  StyleBox["pay31",
    FontSlant->"Italic"],
  " and we can test now with the command ",
  StyleBox["KernelImputationListQ[]",
    FontWeight->"Bold"],
  " if one or some of these candidates is an or are additional kernel \
element(s)."
}], "Text",
  TextJustification->1],

Cell[CellGroupData[{

Cell[BoxData[
    \(KernelImputationListQ[ExpGame3, pay31]\)], "Input"],

Cell[BoxData[
    \({False, False, True, False, False, False, False, False, False, False, 
      False}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \({sol32, pay32} = 
      KernelCalculation[ExpGame3, EpsilonValue \[Rule] \ 21]\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("Game is zero-monotone? "\[InvisibleSpace]False\),
      SequenceForm[ "Game is zero-monotone? ", False],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Core is nonempty? "\[InvisibleSpace]True\),
      SequenceForm[ "Core is nonempty? ", True],
      Editable->False]], "Print"],

Cell[BoxData[
    \("Game is either zero-monotonic or has nonempty core"\)], "Print"],

Cell[BoxData[
    InterpretationBox[\("A Kernel solution is: "\[InvisibleSpace]{x[
              1] \[Rule] 1, x[2] \[Rule] 1, x[3] \[Rule] 1, x[4] \[Rule] 2, 
          x[5] \[Rule] 2}\),
      SequenceForm[ 
      "A Kernel solution is: ", {x[ 1] -> 1, x[ 2] -> 1, x[ 3] -> 1, x[ 4] -> 
        2, x[ 5] -> 2}],
      Editable->False]], "Print"],

Cell[BoxData[
    \({{1, 1, 1, 2, 
        2}, {{1\/6, 4\/3, 4\/3, 3\/2, 8\/3}, {1\/6, 4\/3, 4\/3, 8\/3, 
          3\/2}, {1, 1, 1, 2, 2}, {4\/3, 1\/6, 4\/3, 3\/2, 8\/3}, {4\/3, 
          1\/6, 4\/3, 8\/3, 3\/2}, {4\/3, 4\/3, 1\/6, 3\/2, 8\/3}, {4\/3, 
          4\/3, 1\/6, 8\/3, 3\/2}, {3\/2, 3\/2, 4, 0, 0}, {3\/2, 4, 3\/2, 0, 
          0}, {2, 2, 2, 1\/2, 1\/2}, {4, 3\/2, 3\/2, 0, 0}}}\)], "Output"]
}, Open  ]],

Cell["Let us look again on additional kernel elements.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(KernelImputationListQ[ExpGame3, pay32]\)], "Input"],

Cell[BoxData[
    \({False, False, True, False, False, False, False, False, False, False, 
      False}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "In both cases we get the same kernel candidates by relying on the function \
",
  StyleBox["KernelCalculation[]",
    FontWeight->"Bold"],
  "  which are not contained in the solution set.  Hence, we did not find any \
additional kernel solution, although the kernel is not a singleton.  But now \
we want provide a strategy to compute the complete kernel solution by using \
the dual game. This strategy could be successful in cases that the least core \
of the dual and the primal game are different. For a quick test we are \
looking on the nucleolus of the dual and the primal game. Let us define the \
dual game of ",
  StyleBox["ExpGame3.",
    FontSlant->"Italic"]
}], "Text",
  TextJustification->1],

Cell[CellGroupData[{

Cell[BoxData[
    \(duvec\  = DualGame[ExpGame3]\)], "Input"],

Cell[BoxData[
    \({0, 7, 7, 7, 7, 7, 7, 7, 3, 3, 7, 3, 3, 3, 3, 7, 3, 7, 7, 7, 7, 7, 7, 
      7, 7, 7, 7, 7, 7, 7, 7, 7}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(DualExpGame3 := \((\(DefineGame[T3, duvec];\))\);\)\)], "Input"],

Cell["The nucleolus of the dual is", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Nucleolus[DualExpGame3]\)], "Input"],

Cell[BoxData[
    \({7\/5, 7\/5, 7\/5, 7\/5, 7\/5}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(nuc3\)], "Input"],

Cell[BoxData[
    \({1, 1, 1, 2, 2}\)], "Output"]
}, Open  ]],

Cell["Note first that the dual is not a zero-monotonic game.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ZeroMonotoneQ[DualExpGame3]\)], "Input"],

Cell[BoxData[
    \(False\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \({duker3, dupay3} = 
      KernelCalculation[DualExpGame3, EpsilonValue \[Rule] \ 7, 
        SetGameToNonZeroMonotonic \[Rule] \ True]\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("Game is zero-monotone? "\[InvisibleSpace]False\),
      SequenceForm[ "Game is zero-monotone? ", False],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Core is nonempty? "\[InvisibleSpace]False\),
      SequenceForm[ "Core is nonempty? ", False],
      Editable->False]], "Print"],

Cell[BoxData[
    \("Game is not zero-monotonic and has empty core"\)], "Print"],

Cell[BoxData[
    InterpretationBox[\("A Kernel solution is: "\[InvisibleSpace]{x[
              1] \[Rule] 7\/5, x[2] \[Rule] 7\/5, x[3] \[Rule] 7\/5, 
          x[4] \[Rule] 7\/5, x[5] \[Rule] 7\/5}\),
      SequenceForm[ 
      "A Kernel solution is: ", {x[ 1] -> Rational[ 7, 5], x[ 2] -> Rational[ 
        7, 5], x[ 3] -> Rational[ 7, 5], x[ 4] -> Rational[ 7, 5], x[ 5] -> 
        Rational[ 7, 5]}],
      Editable->False]], "Print"],

Cell[BoxData[
    \({{7\/5, 7\/5, 7\/5, 7\/5, 
        7\/5}, {{0, 0, 0, 7\/2, 7\/2}, {0, 0, 7\/2, 0, 7\/2}, {0, 0, 7\/2, 
          7\/2, 0}, {0, 7\/2, 0, 0, 7\/2}, {0, 7\/2, 0, 7\/2, 0}, {0, 7\/2, 
          7\/2, 0, 0}, {7\/5, 7\/5, 7\/5, 7\/5, 7\/5}, {7\/2, 0, 0, 0, 
          7\/2}, {7\/2, 0, 0, 7\/2, 0}, {7\/2, 0, 7\/2, 0, 0}, {7\/2, 7\/2, 
          0, 0, 0}}}\)], "Output"]
}, Open  ]],

Cell["\<\
But note that you should use the option for non zero-monotonic \
games with care. The algorithm works quite well for zero-monotonic games, \
using the above option can cause an infinite loop for an non zero-monotonic \
game.  \
\>", "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[CellGroupData[{

Cell[BoxData[
    \(KernelImputationListQ[ExpGame3, dupay3]\)], "Input"],

Cell[BoxData[
    \({True, False, False, False, False, False, False, False, False, False, 
      False}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(First[dupay3]\)], "Input"],

Cell[BoxData[
    \({0, 0, 0, 7\/2, 7\/2}\)], "Output"]
}, Open  ]],

Cell["\<\
This is the second extreme point of the Kernel segment given \
by\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(kerline\)], "Input"],

Cell[BoxData[
    \({{\(-\(3\/10\)\), \(-\(3\/10\)\), \(-\(3\/10\)\), 79\/20, 
        79\/20}, {\(-\(1\/5\)\), \(-\(1\/5\)\), \(-\(1\/5\)\), 19\/5, 
        19\/5}, {\(-\(1\/10\)\), \(-\(1\/10\)\), \(-\(1\/10\)\), 73\/20, 
        73\/20}, {0, 0, 0, 7\/2, 7\/2}, {1\/10, 1\/10, 1\/10, 67\/20, 
        67\/20}, {1\/5, 1\/5, 1\/5, 16\/5, 16\/5}, {3\/10, 3\/10, 3\/10, 
        61\/20, 61\/20}, {2\/5, 2\/5, 2\/5, 29\/10, 29\/10}, {1\/2, 1\/2, 
        1\/2, 11\/4, 11\/4}, {3\/5, 3\/5, 3\/5, 13\/5, 13\/5}, {7\/10, 7\/10, 
        7\/10, 49\/20, 49\/20}, {4\/5, 4\/5, 4\/5, 23\/10, 23\/10}, {9\/10, 
        9\/10, 9\/10, 43\/20, 43\/20}, {1, 1, 1, 2, 2}, {11\/10, 11\/10, 
        11\/10, 37\/20, 37\/20}}\)], "Output"]
}, Open  ]],

Cell["By invoking the function FindKernelSolution[] we find", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(kersol30 = FindKernelSolution[ExpGame3, {0, 0, 0, 0, 7}]\)], "Input"],

Cell[BoxData[
    \({0, 0, 0, 7\/2, 7\/2}\)], "Output"]
}, Open  ]],

Cell["\<\
and by computing kernel elements by the list of permutations from \
the vector {7,0,0,0,0} we get\
\>", "Text"],

Cell[BoxData[
    \(\(permut = Permutations[{7, 0, 0, 0, 0}];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(kerper = FindKernelSolution[ExpGame3, permut] // Union\)], "Input"],

Cell[BoxData[
    \({{0, 0, 0, 7\/2, 7\/2}, {7\/8, 7\/8, 7\/8, 35\/16, 35\/16}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(KernelImputationListQ[ExpGame3, kerper]\)], "Input"],

Cell[BoxData[
    \({True, True}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(kersol31 = FindKernelSolution[ExpGame3, pay31] // Union\)], "Input"],

Cell[BoxData[
    \({{3\/4, 3\/4, 3\/4, 19\/8, 19\/8}, {29\/32, 29\/32, 29\/32, 137\/64, 
        137\/64}, {31\/32, 31\/32, 31\/32, 131\/64, 131\/64}, {1, 1, 1, 2, 
        2}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(kersol32 = FindKernelSolution[ExpGame3, pay32] // Union\)], "Input"],

Cell[BoxData[
    \({{3\/4, 3\/4, 3\/4, 19\/8, 19\/8}, {29\/32, 29\/32, 29\/32, 137\/64, 
        137\/64}, {31\/32, 31\/32, 31\/32, 131\/64, 131\/64}, {1, 1, 1, 2, 
        2}}\)], "Output"]
}, Open  ]],

Cell["\<\
Finally,we verify that the computed solutions are kernel elements \
by calling again\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(KernelImputationListQ[ExpGame3, kersol32]\)], "Input"],

Cell[BoxData[
    \({True, True, True, True}\)], "Output"]
}, Open  ]],

Cell["\<\
Now let us check whether the payoffs are balancing the excesses. We \
can check this by invoking the function \
\>", "Text",
  TextJustification->1],

Cell[CellGroupData[{

Cell[BoxData[
    \(AllMaxSurpluses[ExpGame3, kerline, 
      DisplayMatrixForm \[Rule] \ True]\)], "Input"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(sij[{1, 2}]\)},
                    {\(sij[{2, 1}]\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(sij[{1, 3}]\)},
                    {\(sij[{3, 1}]\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(sij[{1, 4}]\)},
                    {\(sij[{4, 1}]\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(sij[{1, 5}]\)},
                    {\(sij[{5, 1}]\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(sij[{2, 3}]\)},
                    {\(sij[{3, 2}]\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(sij[{2, 4}]\)},
                    {\(sij[{4, 2}]\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(sij[{2, 5}]\)},
                    {\(sij[{5, 2}]\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(sij[{3, 4}]\)},
                    {\(sij[{4, 3}]\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(sij[{3, 5}]\)},
                    {\(sij[{5, 3}]\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(sij[{4, 5}]\)},
                    {\(sij[{5, 4}]\)}
                    }], "\[NoBreak]", ")"}]},
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(13\/20\)},
                    {\(13\/20\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(13\/20\)},
                    {\(13\/20\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(9\/10\)},
                    {\(13\/20\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(9\/10\)},
                    {\(13\/20\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(13\/20\)},
                    {\(13\/20\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(9\/10\)},
                    {\(13\/20\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(9\/10\)},
                    {\(13\/20\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(9\/10\)},
                    {\(13\/20\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(9\/10\)},
                    {\(13\/20\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(13\/20\)},
                    {\(13\/20\)}
                    }], "\[NoBreak]", ")"}]},
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(3\/5\)},
                    {\(3\/5\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(3\/5\)},
                    {\(3\/5\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(3\/5\)},
                    {\(3\/5\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(3\/5\)},
                    {\(3\/5\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(3\/5\)},
                    {\(3\/5\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(3\/5\)},
                    {\(3\/5\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(3\/5\)},
                    {\(3\/5\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(3\/5\)},
                    {\(3\/5\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(3\/5\)},
                    {\(3\/5\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(3\/5\)},
                    {\(3\/5\)}
                    }], "\[NoBreak]", ")"}]},
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(11\/20\)},
                    {\(11\/20\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(11\/20\)},
                    {\(11\/20\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(11\/20\)},
                    {\(11\/20\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(11\/20\)},
                    {\(11\/20\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(11\/20\)},
                    {\(11\/20\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(11\/20\)},
                    {\(11\/20\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(11\/20\)},
                    {\(11\/20\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(11\/20\)},
                    {\(11\/20\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(11\/20\)},
                    {\(11\/20\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(11\/20\)},
                    {\(11\/20\)}
                    }], "\[NoBreak]", ")"}]},
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(1\/2\)},
                    {\(1\/2\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(1\/2\)},
                    {\(1\/2\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(1\/2\)},
                    {\(1\/2\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(1\/2\)},
                    {\(1\/2\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(1\/2\)},
                    {\(1\/2\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(1\/2\)},
                    {\(1\/2\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(1\/2\)},
                    {\(1\/2\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(1\/2\)},
                    {\(1\/2\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(1\/2\)},
                    {\(1\/2\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(1\/2\)},
                    {\(1\/2\)}
                    }], "\[NoBreak]", ")"}]},
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(9\/20\)},
                    {\(9\/20\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(9\/20\)},
                    {\(9\/20\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(9\/20\)},
                    {\(9\/20\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(9\/20\)},
                    {\(9\/20\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(9\/20\)},
                    {\(9\/20\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(9\/20\)},
                    {\(9\/20\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(9\/20\)},
                    {\(9\/20\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(9\/20\)},
                    {\(9\/20\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(9\/20\)},
                    {\(9\/20\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(9\/20\)},
                    {\(9\/20\)}
                    }], "\[NoBreak]", ")"}]},
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(2\/5\)},
                    {\(2\/5\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(2\/5\)},
                    {\(2\/5\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(2\/5\)},
                    {\(2\/5\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(2\/5\)},
                    {\(2\/5\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(2\/5\)},
                    {\(2\/5\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(2\/5\)},
                    {\(2\/5\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(2\/5\)},
                    {\(2\/5\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(2\/5\)},
                    {\(2\/5\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(2\/5\)},
                    {\(2\/5\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(2\/5\)},
                    {\(2\/5\)}
                    }], "\[NoBreak]", ")"}]},
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(7\/20\)},
                    {\(7\/20\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(7\/20\)},
                    {\(7\/20\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(7\/20\)},
                    {\(7\/20\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(7\/20\)},
                    {\(7\/20\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(7\/20\)},
                    {\(7\/20\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(7\/20\)},
                    {\(7\/20\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(7\/20\)},
                    {\(7\/20\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(7\/20\)},
                    {\(7\/20\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(7\/20\)},
                    {\(7\/20\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(7\/20\)},
                    {\(7\/20\)}
                    }], "\[NoBreak]", ")"}]},
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(3\/10\)},
                    {\(3\/10\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(3\/10\)},
                    {\(3\/10\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(3\/10\)},
                    {\(3\/10\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(3\/10\)},
                    {\(3\/10\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(3\/10\)},
                    {\(3\/10\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(3\/10\)},
                    {\(3\/10\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(3\/10\)},
                    {\(3\/10\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(3\/10\)},
                    {\(3\/10\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(3\/10\)},
                    {\(3\/10\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(3\/10\)},
                    {\(3\/10\)}
                    }], "\[NoBreak]", ")"}]},
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(1\/4\)},
                    {\(1\/4\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(1\/4\)},
                    {\(1\/4\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(1\/4\)},
                    {\(1\/4\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(1\/4\)},
                    {\(1\/4\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(1\/4\)},
                    {\(1\/4\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(1\/4\)},
                    {\(1\/4\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(1\/4\)},
                    {\(1\/4\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(1\/4\)},
                    {\(1\/4\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(1\/4\)},
                    {\(1\/4\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(1\/4\)},
                    {\(1\/4\)}
                    }], "\[NoBreak]", ")"}]},
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(1\/5\)},
                    {\(1\/5\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(1\/5\)},
                    {\(1\/5\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(1\/5\)},
                    {\(1\/5\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(1\/5\)},
                    {\(1\/5\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(1\/5\)},
                    {\(1\/5\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(1\/5\)},
                    {\(1\/5\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(1\/5\)},
                    {\(1\/5\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(1\/5\)},
                    {\(1\/5\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(1\/5\)},
                    {\(1\/5\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(1\/5\)},
                    {\(1\/5\)}
                    }], "\[NoBreak]", ")"}]},
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(3\/20\)},
                    {\(3\/20\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(3\/20\)},
                    {\(3\/20\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(3\/20\)},
                    {\(3\/20\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(3\/20\)},
                    {\(3\/20\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(3\/20\)},
                    {\(3\/20\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(3\/20\)},
                    {\(3\/20\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(3\/20\)},
                    {\(3\/20\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(3\/20\)},
                    {\(3\/20\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(3\/20\)},
                    {\(3\/20\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(3\/20\)},
                    {\(3\/20\)}
                    }], "\[NoBreak]", ")"}]},
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(1\/10\)},
                    {\(1\/10\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(1\/10\)},
                    {\(1\/10\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(1\/10\)},
                    {\(1\/10\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(1\/10\)},
                    {\(1\/10\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(1\/10\)},
                    {\(1\/10\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(1\/10\)},
                    {\(1\/10\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(1\/10\)},
                    {\(1\/10\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(1\/10\)},
                    {\(1\/10\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(1\/10\)},
                    {\(1\/10\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(1\/10\)},
                    {\(1\/10\)}
                    }], "\[NoBreak]", ")"}]},
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(1\/20\)},
                    {\(1\/20\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(1\/20\)},
                    {\(1\/20\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(1\/20\)},
                    {\(1\/20\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(1\/20\)},
                    {\(1\/20\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(1\/20\)},
                    {\(1\/20\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(1\/20\)},
                    {\(1\/20\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(1\/20\)},
                    {\(1\/20\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(1\/20\)},
                    {\(1\/20\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(1\/20\)},
                    {\(1\/20\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(1\/20\)},
                    {\(1\/20\)}
                    }], "\[NoBreak]", ")"}]},
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}]},
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(-\(1\/20\)\)},
                    {\(-\(1\/20\)\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(-\(1\/20\)\)},
                    {\(-\(1\/20\)\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(-\(1\/20\)\)},
                    {\(3\/10\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(-\(1\/20\)\)},
                    {\(3\/10\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(-\(1\/20\)\)},
                    {\(-\(1\/20\)\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(-\(1\/20\)\)},
                    {\(3\/10\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(-\(1\/20\)\)},
                    {\(3\/10\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(-\(1\/20\)\)},
                    {\(3\/10\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(-\(1\/20\)\)},
                    {\(3\/10\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(-\(1\/20\)\)},
                    {\(-\(1\/20\)\)}
                    }], "\[NoBreak]", ")"}]}
            }], "\[NoBreak]", ")"}],
      MatrixForm[ {{{
        sij[ {1, 2}], 
        sij[ {2, 1}]}, {
        sij[ {1, 3}], 
        sij[ {3, 1}]}, {
        sij[ {1, 4}], 
        sij[ {4, 1}]}, {
        sij[ {1, 5}], 
        sij[ {5, 1}]}, {
        sij[ {2, 3}], 
        sij[ {3, 2}]}, {
        sij[ {2, 4}], 
        sij[ {4, 2}]}, {
        sij[ {2, 5}], 
        sij[ {5, 2}]}, {
        sij[ {3, 4}], 
        sij[ {4, 3}]}, {
        sij[ {3, 5}], 
        sij[ {5, 3}]}, {
        sij[ {4, 5}], 
        sij[ {5, 4}]}}, {{
        Rational[ 13, 20], 
        Rational[ 13, 20]}, {
        Rational[ 13, 20], 
        Rational[ 13, 20]}, {
        Rational[ 9, 10], 
        Rational[ 13, 20]}, {
        Rational[ 9, 10], 
        Rational[ 13, 20]}, {
        Rational[ 13, 20], 
        Rational[ 13, 20]}, {
        Rational[ 9, 10], 
        Rational[ 13, 20]}, {
        Rational[ 9, 10], 
        Rational[ 13, 20]}, {
        Rational[ 9, 10], 
        Rational[ 13, 20]}, {
        Rational[ 9, 10], 
        Rational[ 13, 20]}, {
        Rational[ 13, 20], 
        Rational[ 13, 20]}}, {{
        Rational[ 3, 5], 
        Rational[ 3, 5]}, {
        Rational[ 3, 5], 
        Rational[ 3, 5]}, {
        Rational[ 3, 5], 
        Rational[ 3, 5]}, {
        Rational[ 3, 5], 
        Rational[ 3, 5]}, {
        Rational[ 3, 5], 
        Rational[ 3, 5]}, {
        Rational[ 3, 5], 
        Rational[ 3, 5]}, {
        Rational[ 3, 5], 
        Rational[ 3, 5]}, {
        Rational[ 3, 5], 
        Rational[ 3, 5]}, {
        Rational[ 3, 5], 
        Rational[ 3, 5]}, {
        Rational[ 3, 5], 
        Rational[ 3, 5]}}, {{
        Rational[ 11, 20], 
        Rational[ 11, 20]}, {
        Rational[ 11, 20], 
        Rational[ 11, 20]}, {
        Rational[ 11, 20], 
        Rational[ 11, 20]}, {
        Rational[ 11, 20], 
        Rational[ 11, 20]}, {
        Rational[ 11, 20], 
        Rational[ 11, 20]}, {
        Rational[ 11, 20], 
        Rational[ 11, 20]}, {
        Rational[ 11, 20], 
        Rational[ 11, 20]}, {
        Rational[ 11, 20], 
        Rational[ 11, 20]}, {
        Rational[ 11, 20], 
        Rational[ 11, 20]}, {
        Rational[ 11, 20], 
        Rational[ 11, 20]}}, {{
        Rational[ 1, 2], 
        Rational[ 1, 2]}, {
        Rational[ 1, 2], 
        Rational[ 1, 2]}, {
        Rational[ 1, 2], 
        Rational[ 1, 2]}, {
        Rational[ 1, 2], 
        Rational[ 1, 2]}, {
        Rational[ 1, 2], 
        Rational[ 1, 2]}, {
        Rational[ 1, 2], 
        Rational[ 1, 2]}, {
        Rational[ 1, 2], 
        Rational[ 1, 2]}, {
        Rational[ 1, 2], 
        Rational[ 1, 2]}, {
        Rational[ 1, 2], 
        Rational[ 1, 2]}, {
        Rational[ 1, 2], 
        Rational[ 1, 2]}}, {{
        Rational[ 9, 20], 
        Rational[ 9, 20]}, {
        Rational[ 9, 20], 
        Rational[ 9, 20]}, {
        Rational[ 9, 20], 
        Rational[ 9, 20]}, {
        Rational[ 9, 20], 
        Rational[ 9, 20]}, {
        Rational[ 9, 20], 
        Rational[ 9, 20]}, {
        Rational[ 9, 20], 
        Rational[ 9, 20]}, {
        Rational[ 9, 20], 
        Rational[ 9, 20]}, {
        Rational[ 9, 20], 
        Rational[ 9, 20]}, {
        Rational[ 9, 20], 
        Rational[ 9, 20]}, {
        Rational[ 9, 20], 
        Rational[ 9, 20]}}, {{
        Rational[ 2, 5], 
        Rational[ 2, 5]}, {
        Rational[ 2, 5], 
        Rational[ 2, 5]}, {
        Rational[ 2, 5], 
        Rational[ 2, 5]}, {
        Rational[ 2, 5], 
        Rational[ 2, 5]}, {
        Rational[ 2, 5], 
        Rational[ 2, 5]}, {
        Rational[ 2, 5], 
        Rational[ 2, 5]}, {
        Rational[ 2, 5], 
        Rational[ 2, 5]}, {
        Rational[ 2, 5], 
        Rational[ 2, 5]}, {
        Rational[ 2, 5], 
        Rational[ 2, 5]}, {
        Rational[ 2, 5], 
        Rational[ 2, 5]}}, {{
        Rational[ 7, 20], 
        Rational[ 7, 20]}, {
        Rational[ 7, 20], 
        Rational[ 7, 20]}, {
        Rational[ 7, 20], 
        Rational[ 7, 20]}, {
        Rational[ 7, 20], 
        Rational[ 7, 20]}, {
        Rational[ 7, 20], 
        Rational[ 7, 20]}, {
        Rational[ 7, 20], 
        Rational[ 7, 20]}, {
        Rational[ 7, 20], 
        Rational[ 7, 20]}, {
        Rational[ 7, 20], 
        Rational[ 7, 20]}, {
        Rational[ 7, 20], 
        Rational[ 7, 20]}, {
        Rational[ 7, 20], 
        Rational[ 7, 20]}}, {{
        Rational[ 3, 10], 
        Rational[ 3, 10]}, {
        Rational[ 3, 10], 
        Rational[ 3, 10]}, {
        Rational[ 3, 10], 
        Rational[ 3, 10]}, {
        Rational[ 3, 10], 
        Rational[ 3, 10]}, {
        Rational[ 3, 10], 
        Rational[ 3, 10]}, {
        Rational[ 3, 10], 
        Rational[ 3, 10]}, {
        Rational[ 3, 10], 
        Rational[ 3, 10]}, {
        Rational[ 3, 10], 
        Rational[ 3, 10]}, {
        Rational[ 3, 10], 
        Rational[ 3, 10]}, {
        Rational[ 3, 10], 
        Rational[ 3, 10]}}, {{
        Rational[ 1, 4], 
        Rational[ 1, 4]}, {
        Rational[ 1, 4], 
        Rational[ 1, 4]}, {
        Rational[ 1, 4], 
        Rational[ 1, 4]}, {
        Rational[ 1, 4], 
        Rational[ 1, 4]}, {
        Rational[ 1, 4], 
        Rational[ 1, 4]}, {
        Rational[ 1, 4], 
        Rational[ 1, 4]}, {
        Rational[ 1, 4], 
        Rational[ 1, 4]}, {
        Rational[ 1, 4], 
        Rational[ 1, 4]}, {
        Rational[ 1, 4], 
        Rational[ 1, 4]}, {
        Rational[ 1, 4], 
        Rational[ 1, 4]}}, {{
        Rational[ 1, 5], 
        Rational[ 1, 5]}, {
        Rational[ 1, 5], 
        Rational[ 1, 5]}, {
        Rational[ 1, 5], 
        Rational[ 1, 5]}, {
        Rational[ 1, 5], 
        Rational[ 1, 5]}, {
        Rational[ 1, 5], 
        Rational[ 1, 5]}, {
        Rational[ 1, 5], 
        Rational[ 1, 5]}, {
        Rational[ 1, 5], 
        Rational[ 1, 5]}, {
        Rational[ 1, 5], 
        Rational[ 1, 5]}, {
        Rational[ 1, 5], 
        Rational[ 1, 5]}, {
        Rational[ 1, 5], 
        Rational[ 1, 5]}}, {{
        Rational[ 3, 20], 
        Rational[ 3, 20]}, {
        Rational[ 3, 20], 
        Rational[ 3, 20]}, {
        Rational[ 3, 20], 
        Rational[ 3, 20]}, {
        Rational[ 3, 20], 
        Rational[ 3, 20]}, {
        Rational[ 3, 20], 
        Rational[ 3, 20]}, {
        Rational[ 3, 20], 
        Rational[ 3, 20]}, {
        Rational[ 3, 20], 
        Rational[ 3, 20]}, {
        Rational[ 3, 20], 
        Rational[ 3, 20]}, {
        Rational[ 3, 20], 
        Rational[ 3, 20]}, {
        Rational[ 3, 20], 
        Rational[ 3, 20]}}, {{
        Rational[ 1, 10], 
        Rational[ 1, 10]}, {
        Rational[ 1, 10], 
        Rational[ 1, 10]}, {
        Rational[ 1, 10], 
        Rational[ 1, 10]}, {
        Rational[ 1, 10], 
        Rational[ 1, 10]}, {
        Rational[ 1, 10], 
        Rational[ 1, 10]}, {
        Rational[ 1, 10], 
        Rational[ 1, 10]}, {
        Rational[ 1, 10], 
        Rational[ 1, 10]}, {
        Rational[ 1, 10], 
        Rational[ 1, 10]}, {
        Rational[ 1, 10], 
        Rational[ 1, 10]}, {
        Rational[ 1, 10], 
        Rational[ 1, 10]}}, {{
        Rational[ 1, 20], 
        Rational[ 1, 20]}, {
        Rational[ 1, 20], 
        Rational[ 1, 20]}, {
        Rational[ 1, 20], 
        Rational[ 1, 20]}, {
        Rational[ 1, 20], 
        Rational[ 1, 20]}, {
        Rational[ 1, 20], 
        Rational[ 1, 20]}, {
        Rational[ 1, 20], 
        Rational[ 1, 20]}, {
        Rational[ 1, 20], 
        Rational[ 1, 20]}, {
        Rational[ 1, 20], 
        Rational[ 1, 20]}, {
        Rational[ 1, 20], 
        Rational[ 1, 20]}, {
        Rational[ 1, 20], 
        Rational[ 1, 20]}}, {{0, 0}, {0, 0}, {0, 0}, {0, 0}, {0, 0}, {0, 0}, {
        0, 0}, {0, 0}, {0, 0}, {0, 0}}, {{
        Rational[ -1, 20], 
        Rational[ -1, 20]}, {
        Rational[ -1, 20], 
        Rational[ -1, 20]}, {
        Rational[ -1, 20], 
        Rational[ 3, 10]}, {
        Rational[ -1, 20], 
        Rational[ 3, 10]}, {
        Rational[ -1, 20], 
        Rational[ -1, 20]}, {
        Rational[ -1, 20], 
        Rational[ 3, 10]}, {
        Rational[ -1, 20], 
        Rational[ 3, 10]}, {
        Rational[ -1, 20], 
        Rational[ 3, 10]}, {
        Rational[ -1, 20], 
        Rational[ 3, 10]}, {
        Rational[ -1, 20], 
        Rational[ -1, 20]}}}]]], "Output"]
}, Open  ]],

Cell["\<\
If one is just interested in a special pair of players, in our \
example for the pair {3,4}, then one should call\
\>", "Text",
  TextJustification->1],

Cell[CellGroupData[{

Cell[BoxData[
    \(MaxSurplus[ExpGame3, 3, 4, kerline]\)], "Input"],

Cell[BoxData[
    \({9\/10, 3\/5, 11\/20, 1\/2, 9\/20, 2\/5, 7\/20, 3\/10, 1\/4, 1\/5, 
      3\/20, 1\/10, 1\/20, 0, \(-\(1\/20\)\)}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(MaxSurplus[ExpGame3, 4, 3, kerline]\)], "Input"],

Cell[BoxData[
    \({13\/20, 3\/5, 11\/20, 1\/2, 9\/20, 2\/5, 7\/20, 3\/10, 1\/4, 1\/5, 
      3\/20, 1\/10, 1\/20, 0, 3\/10}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["4.4. Unanimity Coordinates",
  ButtonData:>"4.4.",
  ButtonStyle->"Hyperlink"]], "Subsubsection",
  CellTags->"Unanimity Coordinates"],

Cell[TextData[{
  "The package ",
  StyleBox["TuGames",
    FontSlant->"Italic"],
  " provides also a small set of functions related to unanimity coordinates. \
We want to demonstrate the use of these functions for an example given by ",
  ButtonBox["Rafels and Ybern",
    ButtonData:>"C. Rafels",
    ButtonStyle->"Hyperlink"],
  " (1995) on page 120. The example is a 5-player  game with the following \
values:"
}], "Text",
  TextJustification->1],

Cell[BoxData[
    \(\(worth = {0, 0, 0, 0, 0, 0, 50.2, 49.7, 47.1, 55.8, 53.3, 101.3, 
          137.6, 130.8, 131.2, 188.4, 149.7, 229.5, 259.6, 239.3, 278, 428.2, 
          289.1, 308.8, 428.2, 432.8, 471.9, 555.7, 756.5, 772.5, 712.8, 
          1209.2};\)\)], "Input"],

Cell["The game is defined by ", "Text"],

Cell[BoxData[
    \(\(ExpGame9 := \((DefineGame[T3, worth, 
            RationalApproximate \[Rule] \ False])\);\)\)], "Input"],

Cell[TextData[{
  "Among other things, we can evaluate all unanimity coordinates of the game \
\"",
  StyleBox["ExpGame9",
    FontSlant->"Italic"],
  "\" with the command"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(UnanimityCoordinates[ExpGame9]\)], "Input"],

Cell[BoxData[
    \({0, 0, 0, 0, 0, 0, 50.2`, 49.7`, 47.1`, 55.8`, 53.3`, 101.3`, 137.6`, 
      130.8`, 131.2`, 188.4`, \(-3.5`\), 30.899999999999977`, 
      16.00000000000003`, 11.699999999999989`, 41.30000000000001`, 
      136.89999999999998`, 3.7000000000000455`, \(-13.299999999999955`\), 
      0.9000000000000341`, \(-17.599999999999966`\), \
\(-3.3000000000000114`\), 
      37.40000000000009`, \(-8.600000000000023`\), \(-2.7999999999999545`\), \
\(-3.5`\), 37.600000000000136`}\)], "Output"]
}, Open  ]],

Cell["\<\
Furthermore, we can extract the minimum unanimity coordinates of \
each coalition size by\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MinUnanimityCoordinates[ExpGame9]\)], "Input"],

Cell[BoxData[
    \({0, 47.1`, \(-17.599999999999966`\), \(-8.600000000000023`\), 
      37.600000000000136`}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "In addition to these functions we can also verify  the convexity property \
by relying on unanimity coordinates. The following sufficient condition of \
convexity worked out in ",
  ButtonBox["Rafels and Ybern",
    ButtonData:>"C. Rafels",
    ButtonStyle->"Hyperlink"],
  " (1995) in Corollary 2.1 is implemented in the function ",
  StyleBox["EvalSumMinCoord[]. ",
    FontWeight->"Bold"],
  "First recall that the unanimity coordinates are defined by"
}], "Text",
  TextJustification->1,
  CellTags->"(1995)"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[Lambda]\_R := \ \[Sum]\_\(S\  \[Subset] R\)\ \
\((\(-1\))\)\^\(r - s\)\ \(v(S)\)\)\(,\)\)\)]],
  " for all ",
  StyleBox["R \[SubsetEqual] N,S,R\[NotEqual]",
    FontSlant->"Italic"],
  "0."
}], "Text",
  TextAlignment->Center,
  CellTags->"(1995)"],

Cell[TextData[{
  "A sufficient condition of convexity of a game ",
  StyleBox["v ",
    FontSlant->"Italic"],
  "in terms of unanimity coordinates is given by"
}], "Text",
  CellTags->"(1995)"],

Cell[TextData[{
  "if for all ",
  StyleBox["k",
    FontSlant->"Italic"],
  "=",
  StyleBox["0,...,n-2",
    FontSlant->"Italic"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sum]\+\(j = 0\)\%k\( k!\)\/\(\(j!\)\ \(\((k - \
j)\)!\)\)\ \[Alpha]\_j\  \[GreaterEqual] \ 0\)]],
  ", then the game is convex, where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\_k := \ 
        min\_\(\(\(|\)\(S\)\(|\)\)\  = \ k + 2\)\ \[Lambda]\_S\)]],
  "."
}], "Text",
  TextAlignment->Center,
  CellTags->"(1995)"],

Cell[CellGroupData[{

Cell[BoxData[
    \(EvalSumMinCoord[ExpGame9]\)], "Input"],

Cell[BoxData[
    \({47.1`, 29.500000000000036`, 3.300000000000047`, 
      6.100000000000172`}\)], "Output"]
}, Open  ]],

Cell["\<\
All evaluated sums are strictly positive, hence we conclude that \
the game is convex. A fortiori, due its strictly positive values the game is \
even strictly convex. The functions presented next verify just whether the \
sufficient condition of convexity in terms of unanimity coordinates is \
satisfied. \
\>", "Text",
  TextJustification->1],

Cell[CellGroupData[{

Cell[BoxData[
    \(ConvexUnanConditionQ[ExpGame9]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(StrictlyConvexUnanConditionQ[ExpGame9]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ConvexQ[ExpGame9]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "In cases that all unanimity coordinates are nonnegative (i.e. the game is \
convex) or that the minimum size of coalition with negative unanimity \
coordinates is greater than ",
  StyleBox["N-2",
    FontSlant->"Italic"],
  " the return value of the function ",
  StyleBox["EvalSumMinCoord[]",
    FontWeight->"Bold"],
  " is the vector of minimum values of unanimity coordinates of each \
coalition size. In the former case we obtain, for instance,"
}], "Text",
  TextJustification->1],

Cell[CellGroupData[{

Cell[BoxData[
    \(MinUnanimityCoordinates[ExpGame1]\)], "Input"],

Cell[BoxData[
    \({0, 0, 0, 10}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(EvalSumMinCoord[ExpGame1]\)], "Input"],

Cell[BoxData[
    \("No negative unanimity coordinates found."\)], "Print"],

Cell[BoxData[
    \("Game is convex."\)], "Print"],

Cell[BoxData[
    \("The minimum unanimity coordinates are:"\)], "Print"],

Cell[BoxData[
    \({0, 0, 0, 10}\)], "Output"]
}, Open  ]],

Cell["and for the latter", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MinUnanimityCoordinates[ExpGame8]\)], "Input"],

Cell[BoxData[
    \({267\/10, 3199\/15, \(-\(5597\/30\)\), 2398\/15}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(EvalSumMinCoord[ExpGame8]\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("Minimum coalition size with negative unanimity \
coordinate is equal to "\[InvisibleSpace]3\),
      SequenceForm[ 
      "Minimum coalition size with negative unanimity coordinate is equal to \
", 3],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Coalition size of T-2 is "\[InvisibleSpace]2\),
      SequenceForm[ "Coalition size of T-2 is ", 2],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(3\[InvisibleSpace]" greater than \
"\[InvisibleSpace]2\),
      SequenceForm[ 3, " greater than ", 2],
      Editable->False]], "Print"],

Cell[BoxData[
    \("No sum of minimum unanimity coordinates can be evaluated."\)], "Print"],

Cell[BoxData[
    \("The minimum unanimity coordinates are:"\)], "Print"],

Cell[BoxData[
    \({267\/10, 3199\/15, \(-\(5597\/30\)\), 2398\/15}\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["5. Computing the Vertices of the Core",
  ButtonData:>"Vertices",
  ButtonStyle->"Hyperlink"]], "Section",
  CellTags->"5"],

Cell[TextData[{
  "The next functions describe some interfaces that call the ",
  StyleBox["cddmathlink",
    FontSlant->"Italic"],
  " library via ",
  StyleBox["MathLink",
    FontSlant->"Italic"],
  " to speed up calculation. One can also use the command ",
  StyleBox["CoreVertices[]",
    FontWeight->"Bold"],
  " to obtain the same result as with the command ",
  StyleBox["CddVerticesCore[]",
    FontWeight->"Bold"],
  ". But this command is based on ",
  StyleBox["Mathematica-",
    FontSlant->"Italic"],
  "Code and it is very slow. That means that on old computers like a Pentium \
II system your game should not be greater than 6 player if you are interest \
to get the result in finite time.  The examples were performed on a Pentium \
II with 266 MHz under LINUX x86 and ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Version 4.2. On a Xeon Processor with 1.8 GHZ  the same example was \
computed in 5 seconds."
}], "Text",
  TextJustification->1],

Cell["\<\
If the package VertexEnum is properly installed on your OS, you can \
calculate the vertices of the core by using the command\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \({time, {vert1, nonvert1}} = 
      AbsoluteTiming[VerticesCore[ExpGame1]]\)], "Input"],

Cell[BoxData[
    \({82.593479`8.368490753333155\ Second, {{{0, 50, 40, 0}, {40, 50, 0, 
            0}, {0, 0, 90, 0}, {90, 0, 0, 0}, {0, 0, 40, 50}, {40, 0, 0, 
            50}, {0, 40, 0, 50}, {0, 50, 0, 40}}, {{17, 8, 11, 19, 5, 1, 
            4}, {17, 14, 8, 19, 7, 3, 4}, {16, 11, 13, 19, 5, 6, 8, 9, 2, 1, 
            4}, {18, 14, 13, 19, 6, 7, 8, 12, 3, 2, 4}, {15, 6, 9, 19, 5, 2, 
            1}, {15, 12, 7, 19, 6, 3, 2}, {15, 10, 7, 19, 5, 3, 1}, {17, 10, 
            7, 19, 5, 3, 1}}}}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Note, that the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Version 3.0 is even faster under the command ",
  StyleBox["CoreVertices[]",
    FontWeight->"Bold"],
  ", you get all vertices on the same platform in 52 seconds instead of 107 \
seconds."
}], "Text"],

Cell[TextData[{
  "By calling the ",
  StyleBox["cddmathlink",
    FontSlant->"Italic"],
  " library, we obtain the same result in 0.02 seconds."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \({time, vert2} = AbsoluteTiming[CddVerticesCore[ExpGame1]]\)], "Input"],

Cell[BoxData[
    \({0.167171`5.674705933869714\ Second, {{0, 0, 40, 50}, {0, 0, 90, 
          0}, {0, 40, 0, 50}, {0, 50, 0, 40}, {0, 50, 40, 0}, {40, 0, 0, 
          50}, {40, 50, 0, 0}, {90, 0, 0, 0}}}\)], "Output"]
}, Open  ]],

Cell["\<\
If you are interested in rational results under Windows, then \
call\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \({time, vert3} = AbsoluteTiming[CddGmpVerticesCore[ExpGame1]]\)], "Input"],

Cell[BoxData[
    \({0.13666`5.58718640988264\ Second, {{0, 0, 40, 50}, {0, 0, 90, 0}, {0, 
          40, 0, 50}, {0, 50, 0, 40}, {0, 50, 40, 0}, {40, 0, 0, 50}, {40, 
          50, 0, 0}, {90, 0, 0, 0}}}\)], "Output"]
}, Open  ]],

Cell["\<\
Now let us check the result on core elements. This can be done by \
calling\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(CoreElementsQ[ExpGame1, vert1]\)], "Input"],

Cell[BoxData[
    \({True, True, True, True, True, True, True, True}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BelongToCoreQ[ExpGame1, vert1]\)], "Input"],

Cell[BoxData[
    \({True, True, True, True, True, True, True, True}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(CoreElementsQ[ExpGame1, vert2]\)], "Input"],

Cell[BoxData[
    \({True, True, True, True, True, True, True, True}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "This is the expected result since the game \"",
  StyleBox["ExpGame1\"",
    FontSlant->"Italic"],
  " is convex."
}], "Text"],

Cell["\<\
Since we have less than 24 vertices let us verify whether the game \
is strictly convex.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ConvexStrQ[ExpGame1]\)], "Input"],

Cell[BoxData[
    \(False\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "The game \"",
  StyleBox["ExpGame1\"",
    FontSlant->"Italic"],
  " is convex let us also compute the marginal values.  "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(marv = MargValue[ExpGame1]\)], "Input"],

Cell[BoxData[
    \({{0, 0, 40, 50}, {0, 0, 90, 0}, {0, 40, 0, 50}, {0, 50, 0, 40}, {0, 0, 
        90, 0}, {0, 50, 40, 0}, {0, 0, 40, 50}, {0, 0, 90, 0}, {40, 0, 0, 
        50}, {90, 0, 0, 0}, {0, 0, 90, 0}, {90, 0, 0, 0}, {0, 40, 0, 50}, {0, 
        50, 0, 40}, {40, 0, 0, 50}, {90, 0, 0, 0}, {40, 50, 0, 0}, {90, 0, 0, 
        0}, {0, 0, 90, 0}, {0, 50, 40, 0}, {0, 0, 90, 0}, {90, 0, 0, 0}, {40, 
        50, 0, 0}, {90, 0, 0, 0}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Length[marv]\)], "Input"],

Cell[BoxData[
    \(24\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "This is the expected result for convex games that the number of marginal \
worth vectors is equal to ",
  StyleBox["n",
    FontSlant->"Italic"],
  "!. To demonstrate that the marginal worth vectors coincide with the \
vertices of the core, we remove all duplicated vectors by"
}], "Text",
  TextJustification->1],

Cell[CellGroupData[{

Cell[BoxData[
    \(unmarv = Union[marv]\)], "Input"],

Cell[BoxData[
    \({{0, 0, 40, 50}, {0, 0, 90, 0}, {0, 40, 0, 50}, {0, 50, 0, 40}, {0, 50, 
        40, 0}, {40, 0, 0, 50}, {40, 50, 0, 0}, {90, 0, 0, 0}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Length[Union[marv]]\)], "Input"],

Cell[BoxData[
    \(8\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(CoreElementsQ[ExpGame1, unmarv]\)], "Input"],

Cell[BoxData[
    \({True, True, True, True, True, True, True, True}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BelongToCoreQ[ExpGame1, unmarv]\)], "Input"],

Cell[BoxData[
    \({True, True, True, True, True, True, True, True}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(to1 = Union[marv, vert1]\)], "Input"],

Cell[BoxData[
    \({{0, 0, 40, 50}, {0, 0, 90, 0}, {0, 40, 0, 50}, {0, 50, 0, 40}, {0, 50, 
        40, 0}, {40, 0, 0, 50}, {40, 50, 0, 0}, {90, 0, 0, 0}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Length[to1]\)], "Input"],

Cell[BoxData[
    \(8\)], "Output"]
}, Open  ]],

Cell["\<\
Hence, we get the expected result, that the marginal worth vectors \
coincide with core vertices.  \
\>", "Text"],

Cell["\<\
 In particular, you should handle very carefully floating point \
results by checking on core elements. We make this point more clear by the \
following example\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ecken2 = CddVerticesCore[ExpGame2] // Rationalize\)], "Input"],

Cell[BoxData[
    \({{0, 0, 40, 50}, {0, 0, 90, 0}, {0, 40, 0, 50}, {0, 50, 0, 40}, {0, 50, 
        40, 0}, {40, 0, 0, 50}, {40, 50, 0, 0}, {90, 0, 0, 0}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BelongToCoreQ[ExpGame2, ecken2]\)], "Input"],

Cell[BoxData[
    \({True, True, True, True, True, True, True, True}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ecken3 = CddVerticesCore[ExpGame3] // Rationalize\)], "Input"],

Cell[BoxData[
    \({{0, 0, 0, 4, 4}, {0, 2, 2, 2, 2}, {0, 4, 4, 0, 4}, {0, 4, 4, 4, 
        0}, {1, 1, 1, 2, 2}, {2, 0, 2, 2, 2}, {2, 2, 0, 2, 2}, {2, 2, 2, 0, 
        4}, {2, 2, 2, 4, 0}, {4, 0, 4, 0, 4}, {4, 0, 4, 4, 0}, {4, 4, 0, 0, 
        4}, {4, 4, 0, 4, 0}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BelongToCoreQ[ExpGame3, ecken3]\)], "Input"],

Cell[BoxData[
    \({False, False, False, False, True, False, False, False, False, False, 
      False, False, False}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ecken8fl = CddGmpVerticesCore[ExpGame8]\)], "Input"],

Cell[BoxData[
    \({{267\/10, 7199\/30, 800\/3, 800\/3}, {267\/10, 800\/3, 7199\/30, 
        800\/3}, {267\/10, 800\/3, 800\/3, 7199\/30}, {7199\/30, 267\/10, 
        800\/3, 800\/3}, {7199\/30, 800\/3, 267\/10, 800\/3}, {7199\/30, 
        800\/3, 800\/3, 267\/10}, {800\/3, 267\/10, 7199\/30, 
        800\/3}, {800\/3, 267\/10, 800\/3, 7199\/30}, {800\/3, 7199\/30, 
        267\/10, 800\/3}, {800\/3, 7199\/30, 800\/3, 267\/10}, {800\/3, 
        800\/3, 267\/10, 7199\/30}, {800\/3, 800\/3, 7199\/30, 
        267\/10}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ecken8 = CddVerticesCore[ExpGame8] // Rationalize\)], "Input"],

Cell[BoxData[
    \({{267\/10, 7199\/30, 800\/3, 800\/3}, {267\/10, 800\/3, 7199\/30, 
        800\/3}, {267\/10, 800\/3, 800\/3, 7199\/30}, {7199\/30, 267\/10, 
        800\/3, 800\/3}, {7199\/30, 800\/3, 267\/10, 800\/3}, {7199\/30, 
        800\/3, 800\/3, 267\/10}, {800\/3, 267\/10, 7199\/30, 
        800\/3}, {800\/3, 267\/10, 800\/3, 7199\/30}, {800\/3, 7199\/30, 
        267\/10, 800\/3}, {800\/3, 7199\/30, 800\/3, 267\/10}, {800\/3, 
        800\/3, 267\/10, 7199\/30}, {800\/3, 800\/3, 7199\/30, 
        267\/10}}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "These are exactly the core vertices we have already computed in the ",
  ButtonBox["Section 4.2",
    ButtonData:>"k-convexity",
    ButtonStyle->"Hyperlink"],
  " . But if we check this result with the usual function ",
  StyleBox["CoreElementsQ[]",
    FontWeight->"Bold",
    FontVariations->{"CompatibilityType"->0}],
  StyleBox[" we obtain a wrong result by using floating point numbers. ",
    FontVariations->{"CompatibilityType"->0}]
}], "Text",
  TextJustification->1],

Cell[CellGroupData[{

Cell[BoxData[
    \(CoreElementsQ[ExpGame8, ecken8]\)], "Input"],

Cell[BoxData[
    \({True, True, True, True, True, True, True, True, True, True, True, 
      True}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(CoreElementsQ[ExpGame8, ecken8fl]\)], "Input"],

Cell[BoxData[
    \({True, True, True, True, True, True, True, True, True, True, True, 
      True}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "The correct result is delivered by the function ",
  StyleBox["BelongToCoreQ[]",
    FontWeight->"Bold"]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(BelongToCoreQ[ExpGame8, ecken8]\)], "Input"],

Cell[BoxData[
    \({True, True, True, True, True, True, True, True, True, True, True, 
      True}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(CoreElementsQ[ExpGame8, ecken8fl]\)], "Input"],

Cell[BoxData[
    \({True, True, True, True, True, True, True, True, True, True, True, 
      True}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "To overcome problems associated with floating points result you should \
convert these results to rational numbers by using the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " built-in function ",
  StyleBox["Rationalize[]",
    FontWeight->"Bold"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ravert8 = Rationalize[ecken8]\)], "Input"],

Cell[BoxData[
    \({{267\/10, 7199\/30, 800\/3, 800\/3}, {267\/10, 800\/3, 7199\/30, 
        800\/3}, {267\/10, 800\/3, 800\/3, 7199\/30}, {7199\/30, 267\/10, 
        800\/3, 800\/3}, {7199\/30, 800\/3, 267\/10, 800\/3}, {7199\/30, 
        800\/3, 800\/3, 267\/10}, {800\/3, 267\/10, 7199\/30, 
        800\/3}, {800\/3, 267\/10, 800\/3, 7199\/30}, {800\/3, 7199\/30, 
        267\/10, 800\/3}, {800\/3, 7199\/30, 800\/3, 267\/10}, {800\/3, 
        800\/3, 267\/10, 7199\/30}, {800\/3, 800\/3, 7199\/30, 
        267\/10}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Length[ravert8]\)], "Input"],

Cell[BoxData[
    \(12\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(CoreElementsQ[ExpGame8, ravert8]\)], "Input"],

Cell[BoxData[
    \({True, True, True, True, True, True, True, True, True, True, True, 
      True}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BelongToCoreQ[ExpGame8, ravert8]\)], "Input"],

Cell[BoxData[
    \({True, True, True, True, True, True, True, True, True, True, True, 
      True}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "This is exactly the result we have already obtained in the ",
  ButtonBox["Section 4.2",
    ButtonData:>"k-convexity",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell["\<\
You can also calculate the vertices of the imputation set and of \
the reasonable set by using\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Rationalize[CddVerticesImputationSet[ExpGame1]]\)], "Input"],

Cell[BoxData[
    \({{0, 0, 0, 90}, {0, 0, 90, 0}, {0, 90, 0, 0}, {90, 0, 0, 
        0}}\)], "Output"]
}, Open  ]],

Cell["and", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Rationalize[CddVerticesReasonableSet[ExpGame1]]\)], "Input"],

Cell[BoxData[
    \({{\(-100\), 50, 90, 50}, {90, \(-140\), 90, 50}, {90, 50, \(-100\), 
        50}, {90, 50, 90, \(-140\)}}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \( (*\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["6. Concluding Remarks and Limitations",
  ButtonData:>"6.",
  ButtonStyle->"Hyperlink"]], "Section",
  CellTags->"Concluding Remarks and Limitations"],

Cell[TextData[{
  "In this section we want to discuss some limitations that appear in the \
context of the package ",
  StyleBox["TuGames",
    FontSlant->"Italic"],
  ".  Note first that it is not possible to assign arbitrary names to the \
players. The players must be named with natural numbers. Naming players in \
the fashion as we did it in the example below does not work or produces wrong \
results in bad cases. "
}], "Text",
  TextJustification->1],

Cell[CellGroupData[{

Cell[BoxData[
    \(T10 = {p1, p2, p3}\)], "Input"],

Cell[BoxData[
    \({p1, p2, p3}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(T11 = {1, 2, 3}\)], "Input"],

Cell[BoxData[
    \({1, 2, 3}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(vec10 = Table[0, {k, 2^Length[T10]}];\)\)], "Input"],

Cell[BoxData[
    \(\(ExpGame10 := \((DefineGame[T10, vec10]; v[{p2}] = \(v[{p3}] = 45\); \ 
          v[{p1, p2}] = 40; v[{p1, p3}] = 40; v[T] = 90;)\);\)\)], "Input"],

Cell["\<\
If we want to evaluate the Shapley value of the game with the \
chosen representation of the player set this will produce an error. \
\>", \
"Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(NewShapley[ExpGame10]\)], "Input"],

Cell[BoxData[
    \(Part::"partw" \(\(:\)\(\ \)\) 
      "Part \!\(1\) of \!\({}\) does not exist."\)], "Message"],

Cell[BoxData[
    \(Take::"seqs" \(\(:\)\(\ \)\) 
      "Sequence specification (+n, -n, {+n}, {-n}, {m, n}, or {m, n, s}) \
expected at position \!\(2\) in \!\(Take[\(\(\(\({p1, p2, p3}\)\), \(\(\(\(-1\
\)\) + \(\(\(\({}\)\) \[LeftDoubleBracket] 1 \
\[RightDoubleBracket]\)\)\)\)\)\)]\)."\)], "Message"],

Cell[BoxData[
    \(Part::"partw" \(\(:\)\(\ \)\) 
      "Part \!\(2\) of \!\({}\) does not exist."\)], "Message"],

Cell[BoxData[
    \(Take::"seqs" \(\(:\)\(\ \)\) 
      "Sequence specification (+n, -n, {+n}, {-n}, {m, n}, or {m, n, s}) \
expected at position \!\(2\) in \!\(Take[\(\(\(\({p1, p2, p3}\)\), \(\(\(\(-1\
\)\) + \(\(\(\({}\)\) \[LeftDoubleBracket] 2 \
\[RightDoubleBracket]\)\)\)\)\)\)]\)."\)], "Message"],

Cell[BoxData[
    \(Part::"partw" \(\(:\)\(\ \)\) 
      "Part \!\(3\) of \!\({}\) does not exist."\)], "Message"],

Cell[BoxData[
    \(General::"stop" \(\(:\)\(\ \)\) 
      "Further output of \!\(Part :: \"partw\"\) will be suppressed during \
this calculation."\)], "Message"],

Cell[BoxData[
    \(Take::"seqs" \(\(:\)\(\ \)\) 
      "Sequence specification (+n, -n, {+n}, {-n}, {m, n}, or {m, n, s}) \
expected at position \!\(2\) in \!\(Take[\(\(\(\({p1, p2, p3}\)\), \(\(\(\(-1\
\)\) + \(\(\(\({}\)\) \[LeftDoubleBracket] 3 \
\[RightDoubleBracket]\)\)\)\)\)\)]\)."\)], "Message"],

Cell[BoxData[
    \(General::"stop" \(\(:\)\(\ \)\) 
      "Further output of \!\(Take :: \"seqs\"\) will be suppressed during \
this calculation."\)], "Message"],

Cell[BoxData[
    \({1\/6\ \((v[{p1, {p1, p2, 
                  p3}, \(-1\) + \
{}\[LeftDoubleBracket]1\[RightDoubleBracket]}] + 
            v[{p1, {p1, p3, 
                  p2}, \(-1\) + \
{}\[LeftDoubleBracket]1\[RightDoubleBracket]}] + 
            v[{p1, {p2, p1, 
                  p3}, \(-1\) + \
{}\[LeftDoubleBracket]1\[RightDoubleBracket]}] + 
            v[{p1, {p2, p3, 
                  p1}, \(-1\) + \
{}\[LeftDoubleBracket]1\[RightDoubleBracket]}] + 
            v[{p1, {p3, p1, 
                  p2}, \(-1\) + \
{}\[LeftDoubleBracket]1\[RightDoubleBracket]}] + 
            v[{p1, {p3, p2, 
                  p1}, \(-1\) + \
{}\[LeftDoubleBracket]1\[RightDoubleBracket]}] - 
            v[Take[{p1, p2, 
                  p3}, \(-1\) + \
{}\[LeftDoubleBracket]1\[RightDoubleBracket]]] - 
            v[Take[{p1, p3, 
                  p2}, \(-1\) + \
{}\[LeftDoubleBracket]1\[RightDoubleBracket]]] - 
            v[Take[{p2, p1, 
                  p3}, \(-1\) + \
{}\[LeftDoubleBracket]1\[RightDoubleBracket]]] - 
            v[Take[{p2, p3, 
                  p1}, \(-1\) + \
{}\[LeftDoubleBracket]1\[RightDoubleBracket]]] - 
            v[Take[{p3, p1, 
                  p2}, \(-1\) + \
{}\[LeftDoubleBracket]1\[RightDoubleBracket]]] - 
            v[Take[{p3, p2, 
                  p1}, \(-1\) + \
{}\[LeftDoubleBracket]1\[RightDoubleBracket]]])\), 
      1\/6\ \((v[{p2, {p1, p2, 
                  p3}, \(-1\) + \
{}\[LeftDoubleBracket]2\[RightDoubleBracket]}] + 
            v[{p2, {p1, p3, 
                  p2}, \(-1\) + \
{}\[LeftDoubleBracket]2\[RightDoubleBracket]}] + 
            v[{p2, {p2, p1, 
                  p3}, \(-1\) + \
{}\[LeftDoubleBracket]2\[RightDoubleBracket]}] + 
            v[{p2, {p2, p3, 
                  p1}, \(-1\) + \
{}\[LeftDoubleBracket]2\[RightDoubleBracket]}] + 
            v[{p2, {p3, p1, 
                  p2}, \(-1\) + \
{}\[LeftDoubleBracket]2\[RightDoubleBracket]}] + 
            v[{p2, {p3, p2, 
                  p1}, \(-1\) + \
{}\[LeftDoubleBracket]2\[RightDoubleBracket]}] - 
            v[Take[{p1, p2, 
                  p3}, \(-1\) + \
{}\[LeftDoubleBracket]2\[RightDoubleBracket]]] - 
            v[Take[{p1, p3, 
                  p2}, \(-1\) + \
{}\[LeftDoubleBracket]2\[RightDoubleBracket]]] - 
            v[Take[{p2, p1, 
                  p3}, \(-1\) + \
{}\[LeftDoubleBracket]2\[RightDoubleBracket]]] - 
            v[Take[{p2, p3, 
                  p1}, \(-1\) + \
{}\[LeftDoubleBracket]2\[RightDoubleBracket]]] - 
            v[Take[{p3, p1, 
                  p2}, \(-1\) + \
{}\[LeftDoubleBracket]2\[RightDoubleBracket]]] - 
            v[Take[{p3, p2, 
                  
                  p1}, \(-1\) + \
{}\[LeftDoubleBracket]2\[RightDoubleBracket]]])\), 
      1\/6\ \((v[{p3, {p1, p2, 
                  p3}, \(-1\) + \
{}\[LeftDoubleBracket]3\[RightDoubleBracket]}] + 
            v[{p3, {p1, p3, 
                  p2}, \(-1\) + \
{}\[LeftDoubleBracket]3\[RightDoubleBracket]}] + 
            v[{p3, {p2, p1, 
                  p3}, \(-1\) + \
{}\[LeftDoubleBracket]3\[RightDoubleBracket]}] + 
            v[{p3, {p2, p3, 
                  p1}, \(-1\) + \
{}\[LeftDoubleBracket]3\[RightDoubleBracket]}] + 
            v[{p3, {p3, p1, 
                  p2}, \(-1\) + \
{}\[LeftDoubleBracket]3\[RightDoubleBracket]}] + 
            v[{p3, {p3, p2, 
                  p1}, \(-1\) + \
{}\[LeftDoubleBracket]3\[RightDoubleBracket]}] - 
            v[Take[{p1, p2, 
                  p3}, \(-1\) + \
{}\[LeftDoubleBracket]3\[RightDoubleBracket]]] - 
            v[Take[{p1, p3, 
                  p2}, \(-1\) + \
{}\[LeftDoubleBracket]3\[RightDoubleBracket]]] - 
            v[Take[{p2, p1, 
                  p3}, \(-1\) + \
{}\[LeftDoubleBracket]3\[RightDoubleBracket]]] - 
            v[Take[{p2, p3, 
                  p1}, \(-1\) + \
{}\[LeftDoubleBracket]3\[RightDoubleBracket]]] - 
            v[Take[{p3, p1, 
                  p2}, \(-1\) + \
{}\[LeftDoubleBracket]3\[RightDoubleBracket]]] - 
            v[Take[{p3, p2, 
                  p1}, \(-1\) + \
{}\[LeftDoubleBracket]3\[RightDoubleBracket]]])\)}\)], "Output"]
}, Open  ]],

Cell["\<\
Renaming the players with natural numbers helps to produce the \
correct results. \
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(T11 = MapThread[Set, {T10, {1, 2, 3}}]\)], "Input"],

Cell[BoxData[
    \({1, 2, 3}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(sh1 = NewShapley[ExpGame10]\)], "Input"],

Cell[BoxData[
    \({85\/3, 185\/6, 185\/6}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(sh2 = ShapleyValue[ExpGame10]\)], "Input"],

Cell[BoxData[
    \({85\/3, 185\/6, 185\/6}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Now, let us briefly discuss limitations that appear in relation to the \
operator \":=\" or ",
  StyleBox["SetDelayed[]",
    FontWeight->"Bold"],
  " command. To find out what will happen if the game in which we are \
interested in is not evaluated, we define for this purpose a new game with \
similar coalitional values like the game \"",
  StyleBox["ExpGame10",
    FontSlant->"Italic"],
  "\". Recall from the discussion of ",
  ButtonBox["Section 3.1",
    ButtonData:>"How to define Games?",
    ButtonStyle->"Hyperlink"],
  " that the values of the characteristic function are evaluated at the \
moment when the ",
  StyleBox["game_name",
    FontSlant->"Italic"],
  " appears in the command. Just defining the game and invoking the return \
key is not enough to change the values of the characteristic function. "
}], "Text",
  TextJustification->1],

Cell[BoxData[
    \(\(ExpGame11 := \((DefineGame[{1, 2, 3}, vec10]; 
          v[{2}] = \(v[{3}] = 30\); \ v[{1, 2}] = 40; v[{1, 3}] = 40; 
          v[T] = 90;)\);\)\)], "Input"],

Cell["\<\
To check out which coalitional values are currently assigned can be \
done by \
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(?? v\)], "Input"],

Cell[BoxData[
    \("v[S] describes the worth of coalition S"\)], "Print",
  CellTags->"Info3267505555-1237298"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {GridBox[{
                {\(v[{}] = 0\)},
                {" "},
                {\(v[{1}] = 0\)},
                {" "},
                {\(v[{2}] = 45\)},
                {" "},
                {\(v[{3}] = 45\)},
                {" "},
                {\(v[{1, 2}] = 40\)},
                {" "},
                {\(v[{1, 3}] = 40\)},
                {" "},
                {\(v[{2, 3}] = 0\)},
                {" "},
                {\(v[{1, 2, 3}] = 90\)}
                },
              GridBaseline->{Baseline, {1, 1}},
              ColumnWidths->0.999,
              ColumnAlignments->{Left}]}
          },
        GridBaseline->{Baseline, {1, 1}},
        ColumnAlignments->{Left}],
      Definition[ "v"],
      Editable->False]], "Print",
  CellTags->"Info3267505555-1237298"]
}, Open  ]],

Cell[TextData[{
  "We notice that still the coalitional values for the game \"",
  StyleBox["ExpGame10",
    FontSlant->"Italic"],
  "\" are present. If you want to evaluate, for example, the Shapley value \
for the game \"",
  StyleBox["ExpGame11",
    FontSlant->"Italic"],
  "\" but you make a typesetting error by forgetting the number 11 in our \
example, you will obtain the result of the Shapley value for the game \"",
  StyleBox["ExpGame10",
    FontSlant->"Italic"],
  "\", since there is no change in the characteristic function. "
}], "Text",
  TextJustification->1],

Cell[CellGroupData[{

Cell[BoxData[
    \(NewShapley[ExpGame]\)], "Input"],

Cell[BoxData[
    \({85\/3, 185\/6, 185\/6}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "There is at that moment a change in the values of the characteristic \
function when a new ",
  StyleBox["game_name",
    FontSlant->"Italic"],
  " appears in a command that requires as an input ",
  "argument",
  " a ",
  StyleBox["game_name",
    FontSlant->"Italic"],
  ". For our example, we get new values for the characteristic function when \
we call the command ",
  StyleBox["NewShapley[]",
    FontWeight->"Bold"],
  " with a ",
  StyleBox["game_name",
    FontSlant->"Italic"],
  " that has been previously defined elsewhere in the notebook.  "
}], "Text",
  TextJustification->1],

Cell[CellGroupData[{

Cell[BoxData[
    \(sh3 = NewShapley[ExpGame11]\)], "Input"],

Cell[BoxData[
    \({100\/3, 85\/3, 85\/3}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(sh4 = ShapleyValue[ExpGame11]\)], "Input"],

Cell[BoxData[
    \({100\/3, 85\/3, 85\/3}\)], "Output"]
}, Open  ]],

Cell["\<\
Now let us again check out the values of the characteristic \
function by\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(?? v\)], "Input"],

Cell[BoxData[
    \("v[S] describes the worth of coalition S"\)], "Print",
  CellTags->"Info3267505563-5322123"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {GridBox[{
                {\(v[{}] = 0\)},
                {" "},
                {\(v[{1}] = 0\)},
                {" "},
                {\(v[{2}] = 30\)},
                {" "},
                {\(v[{3}] = 30\)},
                {" "},
                {\(v[{1, 2}] = 40\)},
                {" "},
                {\(v[{1, 3}] = 40\)},
                {" "},
                {\(v[{2, 3}] = 0\)},
                {" "},
                {\(v[{1, 2, 3}] = 90\)}
                },
              GridBaseline->{Baseline, {1, 1}},
              ColumnWidths->0.999,
              ColumnAlignments->{Left}]}
          },
        GridBaseline->{Baseline, {1, 1}},
        ColumnAlignments->{Left}],
      Definition[ "v"],
      Editable->False]], "Print",
  CellTags->"Info3267505563-5322123"]
}, Open  ]],

Cell["\<\
In cases that some unexpected or strange results have occurred \
after the calculation task has finished, you should check out by the above \
command which values are currently assigned to the characteristic function. \
\
\>", "Text",
  TextJustification->1],

Cell[TextData[{
  "We did also some effort to examine the data format of some functions to \
prevent that ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " is performing lengthy unnecessary computations. By avoiding such \
computations you can immediately correct the wrong input ",
  "argument",
  " instead of waiting some time till ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " has finished its evaluation. Here we present an small and simple example. \
First let us construct some payoffs."
}], "Text",
  TextJustification->1],

Cell[CellGroupData[{

Cell[BoxData[
    \(sol11 = KernelCalculation[ExpGame11]\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("Game is average-convex? "\[InvisibleSpace]False\),
      SequenceForm[ "Game is average-convex? ", False],
      Editable->False]], "Print"],

Cell[BoxData[
    \({{10, 40, 40}, 
      x[1] + x[2] + x[3], {\(-10\) - x[1] \[LessEqual] \(-20\), 
        20 - x[2] \[LessEqual] \(-20\), 
        30 - x[1] - x[2] \[LessEqual] \(-20\), 
        20 - x[3] \[LessEqual] \(-20\), 
        30 - x[1] - x[3] \[LessEqual] \(-20\), 
        x[1] + x[2] + x[3] \[LessEqual] 90}, {{10, 40, 40}, {30, 40, 
          20}}}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "The list ",
  StyleBox["sol11 ",
    FontSlant->"Italic"],
  "captures all output informations. If we do not care about the data format \
of ",
  StyleBox["sol11 ",
    FontSlant->"Italic"],
  "and try to hand over the payoff informations contained in it to the \
function ",
  StyleBox["BelongToCoreQ[]",
    FontWeight->"Bold"],
  ", this produces"
}], "Text",
  TextJustification->1],

Cell[CellGroupData[{

Cell[BoxData[
    \(BelongToCoreQ[ExpGame11, sol11]\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("Depth is equal to "\[InvisibleSpace]7\),
      SequenceForm[ "Depth is equal to ", 7],
      Editable->False]], "Print"],

Cell[BoxData[
    \("Usage: BelongToCoreQ[game,payoffs] and \
CoreElementsQ[game,payoffs]"\)], "Print"],

Cell[BoxData[
    \("Input format of the variable 'payoffs' is not correct."\)], "Print"],

Cell[BoxData[
    \("The variable 'payoffs' must be a list of payoff vectors or a single \
payoff vector."\)], "Print"]
}, Open  ]],

Cell[TextData[{
  "The payoff informations in the list ",
  StyleBox["sol11",
    FontSlant->"Italic"],
  " are contained at the first and fourth position. To have access on these \
information one must extract these informations from the list. To extract \
informations located at the first or fourth position can be done by"
}], "Text",
  TextJustification->1],

Cell[CellGroupData[{

Cell[BoxData[
    \(sol11[\([1]\)]\)], "Input"],

Cell[BoxData[
    \({10, 40, 40}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(sol11[\([4]\)]\)], "Input"],

Cell[BoxData[
    \({{10, 40, 40}, {30, 40, 20}}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "These are the correct input formats to hand over to the function ",
  StyleBox["BelongToCoreQ[]",
    FontWeight->"Bold"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(BelongToCoreQ[ExpGame11, sol11[\([4]\)]]\)], "Input"],

Cell[BoxData[
    \({True, False}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "At the end let us mention that ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " offers you the possibility to enhance your typesetting productivity. As \
you have already realized some commands have rather lengthy names that makes \
it very inconvenient to type in every letter in the notebook. To overcome \
these inconveniences ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " offers you a command and symbol-name completion. This can be achieved by \
invoking together the control key  (abbreviated by ",
  StyleBox["C^",
    FontWeight->"Bold"],
  ") and the key of the letter ",
  StyleBox["k",
    FontWeight->"Bold"],
  ". For instance to complete the command ",
  StyleBox["MinUnanimityCoordinates[]",
    FontWeight->"Bold"],
  " type the first four letters of the command and use the key combination ",
  StyleBox["C^k",
    FontWeight->"Bold"],
  " to complete the command. Hence"
}], "Text",
  TextJustification->1],

Cell[BoxData[
    \(\(\(MinU\)\(\ \)\)\)], "Input"],

Cell[TextData[{
  "Invoking ",
  StyleBox["C^k",
    FontWeight->"Bold"],
  " completes the command."
}], "Text"],

Cell[BoxData[
    \(\(\(MinUnanimityCoordinates\)\(\ \)\)\)], "Input"],

Cell[TextData[{
  "Now introducing the ",
  StyleBox["game_name",
    FontSlant->"Italic"],
  " in the command can also be performed by the",
  StyleBox[" C^k",
    FontWeight->"Bold"],
  " key combination. In this case you must again type in the first four \
letters of the ",
  StyleBox["game_name",
    FontSlant->"Italic"],
  " "
}], "Text",
  TextJustification->1],

Cell[BoxData[
    \(\(\(MinUnanimityCoordinates\)\([\)\(ExpG\)\(\ \)\)\)], "Input"],

Cell[TextData[{
  "then invoke ",
  StyleBox["C^k",
    FontWeight->"Bold"],
  " and you obtain"
}], "Text"],

Cell[BoxData[
    \(\(\(\ \)\(\(MinUnanimityCoordinates\)\([\)\(ExpGame1\)\(\ \)\)\)\)], \
"Input"],

Cell["\<\
Finally, type the last number and the missing bracket to finish the \
typesetting.\
\>", "Text"],

Cell[BoxData[
    \(\(\(MinUnanimityCoordinates[ExpGame11]\)\(\ \)\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["7. References",
  ButtonData:>"7.",
  ButtonStyle->"Hyperlink"]], "Section",
  CellTags->"References"],

Cell[TextData[{
  "\n",
  ButtonBox["M. Carter",
    ButtonData:>"1993C",
    ButtonStyle->"Hyperlink"],
  ", ",
  StyleBox["Cooperative Games",
    FontSlant->"Italic"],
  " , in Economic and Financial Modeling with ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ", editor Hal R. Varian, Springer Publisher, 167-191, 1993.\n",
  ButtonBox["Theo Driessen",
    ButtonData:>"(1988)",
    ButtonStyle->"Hyperlink"],
  ", ",
  StyleBox["Cooperative Games,Solutions and Applications",
    FontSlant->"Italic"],
  ", Kluwer Academic Publishers, Dordrecht, 1988.\n",
  ButtonBox["U. Faigle, W. Kern and J. Kuipers",
    ButtonData:>"Faigle98",
    ButtonStyle->"Hyperlink"],
  ", An efficient algorithm for nucleolus and prekernel computation in some \
classes of Tu Games, Memorandum No. 1464, Faculty of Mathematical Sciences, \
University of Twente, 1998.\n",
  ButtonBox["E. Inarra and J. Usategui",
    ButtonData:>"(1993)",
    ButtonStyle->"Hyperlink"],
  ",  ",
  StyleBox["The Shapley value and average convex games",
    FontSlant->"Italic"],
  ",  IJGT, 22, 13-29, 1993.\n",
  ButtonBox["Maschler, M. and Peleg",
    ButtonData:>"MP66",
    ButtonStyle->"Hyperlink"],
  ", B.,A Characterization, Existence Proof and Dimension Bounds for the \
Kernel of a Game , Pacific Journal of Mathematics 18(2), 289 328, 1966.\n",
  ButtonBox["M. Maschler,B. Peleg and L.S. Shapley",
    ButtonData:>"(1979)",
    ButtonStyle->"Hyperlink"],
  ", ",
  StyleBox["Geometric Properties of Kernel, Nucleolus and related Concepts",
    FontSlant->"Italic"],
  ", in Mathematics of Operations Research, Vol.4, Nov. 1979, p.303-338.\n",
  ButtonBox["H. Meinhardt",
    ButtonData:>"(2002a)",
    ButtonStyle->"Hyperlink"],
  ", ",
  StyleBox["Decision Making in Cooperative Common Pool Situations",
    FontSlant->"Italic"],
  ", Lecture Notes in Economics and ",
  StyleBox["Mathematical",
    FontVariations->{"CompatibilityType"->0}],
  " Systems, Vol. 517, 2002a, Springer, Heidelberg. \n",
  ButtonBox["H. Meinhardt",
    ButtonData:>"(2002b)",
    ButtonStyle->"Hyperlink"],
  ", ",
  StyleBox["An LP approach to compute the pre-kernel for cooperative games,",
    FontSlant->"Italic"],
  " forthcoming in Computers and Operation Research, 2004. \n",
  ButtonBox["C. Rafels and N. Ybern",
    ButtonData:>"(1995)",
    ButtonStyle->"Hyperlink"],
  ",  ",
  StyleBox["Even and Odd Marginal Worth Vectors, Owen's Multilinear Extension \
and Convex Games",
    FontSlant->"Italic"],
  ", IJGT, 113-126, 1995.\n",
  ButtonBox["Hal R. Varian",
    ButtonData:>"1993",
    ButtonStyle->"Hyperlink"],
  " (Ed.), ",
  StyleBox["Economics and Financial Modeling with Mathematica",
    FontSlant->"Italic"],
  ", Springer,1993"
}], "Text",
  CellTags->{
  "M. Carter", "Theo Driessen", "E. Inarra", "M. Maschler", "H. Meinhardt", 
    "C. Rafels", "Hal R. Varian"}],

Cell[BoxData[
    \(*) \)], "Input"]
}, Open  ]]
},
FrontEndVersion->"5.0 for X",
ScreenRectangle->{{0, 1600}, {0, 1200}},
ScreenStyleEnvironment->"Presentation",
WindowSize->{1268, 907},
WindowMargins->{{132, Automatic}, {Automatic, 10}},
PrintingPageRange->{Automatic, Automatic},
PrintingOptions->{"PaperSize"->{597.562, 842.375},
"PaperOrientation"->"Portrait",
"PostScriptOutputFile":>FrontEnd`FileName[{"home", "holger", "mathe", \
"EntwPackages", "Documentation", "Englisch"}, "ManualTuGames.nb.ps", \
CharacterEncoding -> "iso8859-1"],
"Magnification"->1},
ShowSelection->True,
CellLabelAutoDelete->True,
LineSpacing->{3, 1},
Magnification->1,
StyleDefinitions -> "Demo.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "1."->{
    Cell[2257, 71, 1760, 64, 477, "Text",
      CellTags->{
      "1.", "2.", "2.1.", "2.2.", "2.3.", "3.", "4.", "4.1.", "4.2.", "4.3.", 
        "4.4.", "5.", "6.", "7.", "3.1.", "Vertices"}]},
  "2."->{
    Cell[2257, 71, 1760, 64, 477, "Text",
      CellTags->{
      "1.", "2.", "2.1.", "2.2.", "2.3.", "3.", "4.", "4.1.", "4.2.", "4.3.", 
        "4.4.", "5.", "6.", "7.", "3.1.", "Vertices"}]},
  "2.1."->{
    Cell[2257, 71, 1760, 64, 477, "Text",
      CellTags->{
      "1.", "2.", "2.1.", "2.2.", "2.3.", "3.", "4.", "4.1.", "4.2.", "4.3.", 
        "4.4.", "5.", "6.", "7.", "3.1.", "Vertices"}]},
  "2.2."->{
    Cell[2257, 71, 1760, 64, 477, "Text",
      CellTags->{
      "1.", "2.", "2.1.", "2.2.", "2.3.", "3.", "4.", "4.1.", "4.2.", "4.3.", 
        "4.4.", "5.", "6.", "7.", "3.1.", "Vertices"}]},
  "2.3."->{
    Cell[2257, 71, 1760, 64, 477, "Text",
      CellTags->{
      "1.", "2.", "2.1.", "2.2.", "2.3.", "3.", "4.", "4.1.", "4.2.", "4.3.", 
        "4.4.", "5.", "6.", "7.", "3.1.", "Vertices"}]},
  "3."->{
    Cell[2257, 71, 1760, 64, 477, "Text",
      CellTags->{
      "1.", "2.", "2.1.", "2.2.", "2.3.", "3.", "4.", "4.1.", "4.2.", "4.3.", 
        "4.4.", "5.", "6.", "7.", "3.1.", "Vertices"}]},
  "4."->{
    Cell[2257, 71, 1760, 64, 477, "Text",
      CellTags->{
      "1.", "2.", "2.1.", "2.2.", "2.3.", "3.", "4.", "4.1.", "4.2.", "4.3.", 
        "4.4.", "5.", "6.", "7.", "3.1.", "Vertices"}]},
  "4.1."->{
    Cell[2257, 71, 1760, 64, 477, "Text",
      CellTags->{
      "1.", "2.", "2.1.", "2.2.", "2.3.", "3.", "4.", "4.1.", "4.2.", "4.3.", 
        "4.4.", "5.", "6.", "7.", "3.1.", "Vertices"}]},
  "4.2."->{
    Cell[2257, 71, 1760, 64, 477, "Text",
      CellTags->{
      "1.", "2.", "2.1.", "2.2.", "2.3.", "3.", "4.", "4.1.", "4.2.", "4.3.", 
        "4.4.", "5.", "6.", "7.", "3.1.", "Vertices"}]},
  "4.3."->{
    Cell[2257, 71, 1760, 64, 477, "Text",
      CellTags->{
      "1.", "2.", "2.1.", "2.2.", "2.3.", "3.", "4.", "4.1.", "4.2.", "4.3.", 
        "4.4.", "5.", "6.", "7.", "3.1.", "Vertices"}]},
  "4.4."->{
    Cell[2257, 71, 1760, 64, 477, "Text",
      CellTags->{
      "1.", "2.", "2.1.", "2.2.", "2.3.", "3.", "4.", "4.1.", "4.2.", "4.3.", 
        "4.4.", "5.", "6.", "7.", "3.1.", "Vertices"}]},
  "5."->{
    Cell[2257, 71, 1760, 64, 477, "Text",
      CellTags->{
      "1.", "2.", "2.1.", "2.2.", "2.3.", "3.", "4.", "4.1.", "4.2.", "4.3.", 
        "4.4.", "5.", "6.", "7.", "3.1.", "Vertices"}]},
  "6."->{
    Cell[2257, 71, 1760, 64, 477, "Text",
      CellTags->{
      "1.", "2.", "2.1.", "2.2.", "2.3.", "3.", "4.", "4.1.", "4.2.", "4.3.", 
        "4.4.", "5.", "6.", "7.", "3.1.", "Vertices"}]},
  "7."->{
    Cell[2257, 71, 1760, 64, 477, "Text",
      CellTags->{
      "1.", "2.", "2.1.", "2.2.", "2.3.", "3.", "4.", "4.1.", "4.2.", "4.3.", 
        "4.4.", "5.", "6.", "7.", "3.1.", "Vertices"}]},
  "3.1."->{
    Cell[2257, 71, 1760, 64, 477, "Text",
      CellTags->{
      "1.", "2.", "2.1.", "2.2.", "2.3.", "3.", "4.", "4.1.", "4.2.", "4.3.", 
        "4.4.", "5.", "6.", "7.", "3.1.", "Vertices"}]},
  "Vertices"->{
    Cell[2257, 71, 1760, 64, 477, "Text",
      CellTags->{
      "1.", "2.", "2.1.", "2.2.", "2.3.", "3.", "4.", "4.1.", "4.2.", "4.3.", 
        "4.4.", "5.", "6.", "7.", "3.1.", "Vertices"}]},
  "Introduction"->{
    Cell[4054, 140, 130, 3, 102, "Section",
      CellTags->"Introduction"]},
  "http://www.ifor.math.ethz.ch/staff/fukuda/fukuda.html"->{
    Cell[4187, 145, 3860, 88, 374, "Text",
      CellTags->{
      "http://www.ifor.math.ethz.ch/staff/fukuda/fukuda.html", "1993", 
        "1993C"}]},
  "1993"->{
    Cell[4187, 145, 3860, 88, 374, "Text",
      CellTags->{
      "http://www.ifor.math.ethz.ch/staff/fukuda/fukuda.html", "1993", 
        "1993C"}]},
  "1993C"->{
    Cell[4187, 145, 3860, 88, 374, "Text",
      CellTags->{
      "http://www.ifor.math.ethz.ch/staff/fukuda/fukuda.html", "1993", 
        "1993C"}]},
  "Installation"->{
    Cell[8084, 238, 131, 3, 102, "Section",
      CellTags->"Installation"]},
  "Unix"->{
    Cell[8240, 245, 125, 3, 56, "Subsubsection",
      CellTags->"Unix"]},
  "Windows"->{
    Cell[10481, 328, 131, 3, 56, "Subsubsection",
      CellTags->"Windows"]},
  "Mac OS"->{
    Cell[12699, 395, 130, 3, 56, "Subsubsection",
      CellTags->"Mac OS"]},
  "Getting Started"->{
    Cell[12985, 409, 137, 3, 102, "Section",
      CellTags->"Getting Started"]},
  "Info3264939207-8254035"->{
    Cell[89374, 2186, 164, 3, 55, "Print",
      CellTags->"Info3264939207-8254035"]},
  "Info3331391299-1787670"->{
    Cell[89712, 2201, 161, 3, 32, "Print",
      CellTags->"Info3331391299-1787670"]},
  "How to define Games?"->{
    Cell[90056, 2216, 157, 3, 56, "Subsubsection",
      CellTags->"How to define Games?"]},
  "DefineGame"->{
    Cell[90216, 2221, 1575, 47, 169, "Text",
      CellTags->"DefineGame"]},
  "(1979)"->{
    Cell[93940, 2326, 253, 7, 43, "Text",
      CellTags->"(1979)"]},
  "Info3331391315-5722292"->{
    Cell[95715, 2376, 112, 2, 32, "Print",
      CellTags->"Info3331391315-5722292"]},
  "Some Functions"->{
    Cell[96268, 2396, 135, 3, 102, "Section",
      CellTags->"Some Functions"]},
  "Basic Functions"->{
    Cell[98522, 2442, 163, 4, 56, "Subsubsection",
      CellTags->"Basic Functions"]},
  "(1993)"->{
    Cell[100035, 2506, 740, 16, 100, "Text",
      CellTags->"(1993)"]},
  "k-convexity"->{
    Cell[107465, 2900, 154, 4, 56, "Subsubsection",
      CellTags->"k-convexity"]},
  "(1988)"->{
    Cell[107622, 2906, 2056, 50, 157, "Text",
      CellTags->{"(1988)", "(2002a)"}]},
  "(2002a)"->{
    Cell[107622, 2906, 2056, 50, 157, "Text",
      CellTags->{"(1988)", "(2002a)"}]},
  "1988"->{
    Cell[112187, 3051, 617, 24, 43, "Text",
      CellTags->"1988"],
    Cell[112807, 3077, 498, 15, 43, "Text",
      CellTags->"1988"],
    Cell[113308, 3094, 531, 18, 57, "Text",
      CellTags->"1988"],
    Cell[113842, 3114, 630, 23, 57, "Text",
      CellTags->"1988"],
    Cell[114475, 3139, 1379, 43, 81, "Text",
      CellTags->"1988"]},
  "Kernel"->{
    Cell[142062, 4168, 144, 4, 56, "Subsubsection",
      CellTags->"Kernel"]},
  "(2002b)"->{
    Cell[142209, 4174, 1930, 42, 195, "Text",
      CellTags->"(2002b)"]},
  "MP66"->{
    Cell[176839, 5207, 658, 20, 155, "Text",
      CellTags->"MP66"]},
  "Faigle98"->{
    Cell[182124, 5388, 780, 16, 119, "Text",
      CellTags->"Faigle98"]},
  "Unanimity Coordinates"->{
    Cell[241155, 7143, 159, 3, 56, "Subsubsection",
      CellTags->"Unanimity Coordinates"]},
  "(1995)"->{
    Cell[243357, 7213, 532, 13, 81, "Text",
      CellTags->"(1995)"],
    Cell[243892, 7228, 312, 10, 44, "Text",
      CellTags->"(1995)"],
    Cell[244207, 7240, 194, 6, 43, "Text",
      CellTags->"(1995)"],
    Cell[244404, 7248, 510, 18, 61, "Text",
      CellTags->"(1995)"]},
  "5"->{
    Cell[248166, 7404, 148, 3, 102, "Section",
      CellTags->"5"]},
  "Concluding Remarks and Limitations"->{
    Cell[261365, 7892, 175, 3, 102, "Section",
      CellTags->"Concluding Remarks and Limitations"]},
  "Info3267505555-1237298"->{
    Cell[270315, 8170, 112, 2, 32, "Print",
      CellTags->"Info3267505555-1237298"],
    Cell[270430, 8174, 846, 27, 368, "Print",
      CellTags->"Info3267505555-1237298"]},
  "Info3267505563-5322123"->{
    Cell[273110, 8278, 112, 2, 32, "Print",
      CellTags->"Info3267505563-5322123"],
    Cell[273225, 8282, 846, 27, 368, "Print",
      CellTags->"Info3267505563-5322123"]},
  "References"->{
    Cell[279651, 8519, 127, 3, 102, "Section",
      CellTags->"References"]},
  "M. Carter"->{
    Cell[279781, 8524, 2856, 79, 409, "Text",
      CellTags->{
      "M. Carter", "Theo Driessen", "E. Inarra", "M. Maschler", 
        "H. Meinhardt", "C. Rafels", "Hal R. Varian"}]},
  "Theo Driessen"->{
    Cell[279781, 8524, 2856, 79, 409, "Text",
      CellTags->{
      "M. Carter", "Theo Driessen", "E. Inarra", "M. Maschler", 
        "H. Meinhardt", "C. Rafels", "Hal R. Varian"}]},
  "E. Inarra"->{
    Cell[279781, 8524, 2856, 79, 409, "Text",
      CellTags->{
      "M. Carter", "Theo Driessen", "E. Inarra", "M. Maschler", 
        "H. Meinhardt", "C. Rafels", "Hal R. Varian"}]},
  "M. Maschler"->{
    Cell[279781, 8524, 2856, 79, 409, "Text",
      CellTags->{
      "M. Carter", "Theo Driessen", "E. Inarra", "M. Maschler", 
        "H. Meinhardt", "C. Rafels", "Hal R. Varian"}]},
  "H. Meinhardt"->{
    Cell[279781, 8524, 2856, 79, 409, "Text",
      CellTags->{
      "M. Carter", "Theo Driessen", "E. Inarra", "M. Maschler", 
        "H. Meinhardt", "C. Rafels", "Hal R. Varian"}]},
  "C. Rafels"->{
    Cell[279781, 8524, 2856, 79, 409, "Text",
      CellTags->{
      "M. Carter", "Theo Driessen", "E. Inarra", "M. Maschler", 
        "H. Meinhardt", "C. Rafels", "Hal R. Varian"}]},
  "Hal R. Varian"->{
    Cell[279781, 8524, 2856, 79, 409, "Text",
      CellTags->{
      "M. Carter", "Theo Driessen", "E. Inarra", "M. Maschler", 
        "H. Meinhardt", "C. Rafels", "Hal R. Varian"}]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"1.", 283750, 8637},
  {"2.", 283956, 8642},
  {"2.1.", 284164, 8647},
  {"2.2.", 284372, 8652},
  {"2.3.", 284580, 8657},
  {"3.", 284786, 8662},
  {"4.", 284992, 8667},
  {"4.1.", 285200, 8672},
  {"4.2.", 285408, 8677},
  {"4.3.", 285616, 8682},
  {"4.4.", 285824, 8687},
  {"5.", 286030, 8692},
  {"6.", 286236, 8697},
  {"7.", 286442, 8702},
  {"3.1.", 286650, 8707},
  {"Vertices", 286862, 8712},
  {"Introduction", 287078, 8717},
  {"http://www.ifor.math.ethz.ch/staff/fukuda/fukuda.html", 287217, 8720},
  {"1993", 287382, 8725},
  {"1993C", 287548, 8730},
  {"Installation", 287721, 8735},
  {"Unix", 287811, 8738},
  {"Windows", 287901, 8741},
  {"Mac OS", 287994, 8744},
  {"Getting Started", 288095, 8747},
  {"Info3264939207-8254035", 288207, 8750},
  {"Info3331391299-1787670", 288324, 8753},
  {"How to define Games?", 288439, 8756},
  {"DefineGame", 288550, 8759},
  {"(1979)", 288641, 8762},
  {"Info3331391315-5722292", 288741, 8765},
  {"Some Functions", 288850, 8768},
  {"Basic Functions", 288955, 8771},
  {"(1993)", 289057, 8774},
  {"k-convexity", 289149, 8777},
  {"(1988)", 289248, 8780},
  {"(2002a)", 289350, 8783},
  {"1988", 289449, 8786},
  {"Kernel", 289810, 8797},
  {"(2002b)", 289905, 8800},
  {"MP66", 289992, 8803},
  {"Faigle98", 290079, 8806},
  {"Unanimity Coordinates", 290183, 8809},
  {"(1995)", 290292, 8812},
  {"5", 290585, 8821},
  {"Concluding Remarks and Limitations", 290697, 8824},
  {"Info3267505555-1237298", 290830, 8827},
  {"Info3267505563-5322123", 291037, 8832},
  {"References", 291232, 8837},
  {"M. Carter", 291328, 8840},
  {"Theo Driessen", 291535, 8845},
  {"E. Inarra", 291738, 8850},
  {"M. Maschler", 291943, 8855},
  {"H. Meinhardt", 292149, 8860},
  {"C. Rafels", 292352, 8865},
  {"Hal R. Varian", 292559, 8870}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 73, 1, 81, "Title"],
Cell[1830, 54, 18, 0, 122, "Author"],
Cell[1851, 56, 351, 9, 229, "Text"],

Cell[CellGroupData[{
Cell[2227, 69, 27, 0, 115, "Section"],
Cell[2257, 71, 1760, 64, 477, "Text",
  CellTags->{
  "1.", "2.", "2.1.", "2.2.", "2.3.", "3.", "4.", "4.1.", "4.2.", "4.3.", 
    "4.4.", "5.", "6.", "7.", "3.1.", "Vertices"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[4054, 140, 130, 3, 102, "Section",
  CellTags->"Introduction"],
Cell[4187, 145, 3860, 88, 374, "Text",
  CellTags->{
  "http://www.ifor.math.ethz.ch/staff/fukuda/fukuda.html", "1993", "1993C"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[8084, 238, 131, 3, 102, "Section",
  CellTags->"Installation"],

Cell[CellGroupData[{
Cell[8240, 245, 125, 3, 56, "Subsubsection",
  CellTags->"Unix"],
Cell[8368, 250, 1923, 68, 236, "Text"],
Cell[10294, 320, 150, 3, 43, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10481, 328, 131, 3, 56, "Subsubsection",
  CellTags->"Windows"],
Cell[10615, 333, 2047, 57, 446, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[12699, 395, 130, 3, 56, "Subsubsection",
  CellTags->"Mac OS"],
Cell[12832, 400, 104, 3, 43, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[12985, 409, 137, 3, 102, "Section",
  CellTags->"Getting Started"],
Cell[13125, 414, 246, 5, 62, "Text"],

Cell[CellGroupData[{
Cell[13396, 423, 183, 3, 92, "Input"],
Cell[13582, 428, 86, 1, 32, "Print"],
Cell[13671, 431, 195, 4, 32, "Print"],
Cell[13869, 437, 86, 1, 32, "Print"],
Cell[13958, 440, 67, 1, 32, "Print"],
Cell[14028, 443, 59, 1, 32, "Print"],
Cell[14090, 446, 86, 1, 32, "Print"],
Cell[14179, 449, 86, 1, 32, "Print"],
Cell[14268, 452, 86, 1, 32, "Print"],
Cell[14357, 455, 59, 1, 32, "Print"],
Cell[14419, 458, 86, 1, 32, "Print"]
}, Open  ]],
Cell[14520, 462, 71, 0, 43, "Text"],

Cell[CellGroupData[{
Cell[14616, 466, 66, 1, 46, "Input"],
Cell[14685, 469, 2680, 39, 588, "Output"]
}, Open  ]],
Cell[17380, 511, 161, 5, 43, "Text"],

Cell[CellGroupData[{
Cell[17566, 520, 49, 1, 46, "Input"],
Cell[17618, 523, 71612, 1655, 597, "Print"]
}, Open  ]],
Cell[89245, 2181, 126, 3, 43, "Text"],
Cell[89374, 2186, 164, 3, 55, "Print",
  CellTags->"Info3264939207-8254035"],
Cell[89541, 2191, 90, 3, 43, "Text"],

Cell[CellGroupData[{
Cell[89656, 2198, 53, 1, 46, "Input"],
Cell[89712, 2201, 161, 3, 32, "Print",
  CellTags->"Info3331391299-1787670"]
}, Open  ]],
Cell[89888, 2207, 143, 5, 43, "Text"],

Cell[CellGroupData[{
Cell[90056, 2216, 157, 3, 56, "Subsubsection",
  CellTags->"How to define Games?"],
Cell[90216, 2221, 1575, 47, 169, "Text",
  CellTags->"DefineGame"],
Cell[91794, 2270, 705, 11, 391, "Input"],
Cell[92502, 2283, 255, 9, 43, "Text"],
Cell[92760, 2294, 120, 2, 69, "Input"],
Cell[92883, 2298, 914, 22, 119, "Text"],
Cell[93800, 2322, 137, 2, 46, "Input"],
Cell[93940, 2326, 253, 7, 43, "Text",
  CellTags->"(1979)"],
Cell[94196, 2335, 123, 2, 69, "Input"],
Cell[94322, 2339, 243, 4, 69, "Input"],
Cell[94568, 2345, 45, 0, 43, "Text"],
Cell[94616, 2347, 276, 4, 128, "Input"],
Cell[94895, 2353, 755, 16, 100, "Text"],

Cell[CellGroupData[{
Cell[95675, 2373, 37, 1, 46, "Input"],
Cell[95715, 2376, 112, 2, 32, "Print",
  CellTags->"Info3331391315-5722292"]
}, Open  ]],
Cell[95842, 2381, 377, 9, 62, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[96268, 2396, 135, 3, 102, "Section",
  CellTags->"Some Functions"],
Cell[96406, 2401, 2091, 37, 252, "Text"],

Cell[CellGroupData[{
Cell[98522, 2442, 163, 4, 56, "Subsubsection",
  CellTags->"Basic Functions"],
Cell[98688, 2448, 830, 20, 119, "Text"],

Cell[CellGroupData[{
Cell[99543, 2472, 50, 1, 46, "Input"],
Cell[99596, 2475, 38, 1, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[99671, 2481, 50, 1, 46, "Input"],
Cell[99724, 2484, 38, 1, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[99799, 2490, 50, 1, 46, "Input"],
Cell[99852, 2493, 39, 1, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[99928, 2499, 50, 1, 46, "Input"],
Cell[99981, 2502, 39, 1, 59, "Output"]
}, Open  ]],
Cell[100035, 2506, 740, 16, 100, "Text",
  CellTags->"(1993)"],
Cell[100778, 2524, 496, 12, 44, "Text"],
Cell[101277, 2538, 395, 15, 62, "Text"],

Cell[CellGroupData[{
Cell[101697, 2557, 52, 1, 46, "Input"],
Cell[101752, 2560, 38, 1, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[101827, 2566, 52, 1, 46, "Input"],
Cell[101882, 2569, 38, 1, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[101957, 2575, 52, 1, 46, "Input"],
Cell[102012, 2578, 39, 1, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[102088, 2584, 52, 1, 46, "Input"],
Cell[102143, 2587, 38, 1, 59, "Output"]
}, Open  ]],
Cell[102196, 2591, 50, 0, 43, "Text"],

Cell[CellGroupData[{
Cell[102271, 2595, 57, 1, 46, "Input"],
Cell[102331, 2598, 38, 1, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[102406, 2604, 57, 1, 46, "Input"],
Cell[102466, 2607, 38, 1, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[102541, 2613, 57, 1, 46, "Input"],
Cell[102601, 2616, 39, 1, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[102677, 2622, 57, 1, 46, "Input"],
Cell[102737, 2625, 38, 1, 59, "Output"]
}, Open  ]],
Cell[102790, 2629, 386, 14, 43, "Text"],
Cell[103179, 2645, 147, 3, 48, "Text"],
Cell[103329, 2650, 151, 4, 43, "Text"],

Cell[CellGroupData[{
Cell[103505, 2658, 63, 1, 46, "Input"],
Cell[103571, 2661, 38, 1, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[103646, 2667, 63, 1, 46, "Input"],
Cell[103712, 2670, 38, 1, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[103787, 2676, 63, 1, 46, "Input"],
Cell[103853, 2679, 38, 1, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[103928, 2685, 63, 1, 46, "Input"],
Cell[103994, 2688, 38, 1, 59, "Output"]
}, Open  ]],
Cell[104047, 2692, 344, 13, 62, "Text"],

Cell[CellGroupData[{
Cell[104416, 2709, 56, 1, 46, "Input"],
Cell[104475, 2712, 38, 1, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[104550, 2718, 52, 1, 46, "Input"],
Cell[104605, 2721, 38, 1, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[104680, 2727, 56, 1, 46, "Input"],
Cell[104739, 2730, 38, 1, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[104814, 2736, 56, 1, 46, "Input"],
Cell[104873, 2739, 38, 1, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[104948, 2745, 52, 1, 46, "Input"],
Cell[105003, 2748, 38, 1, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[105078, 2754, 56, 1, 46, "Input"],
Cell[105137, 2757, 38, 1, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[105212, 2763, 56, 1, 46, "Input"],
Cell[105271, 2766, 39, 1, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[105347, 2772, 52, 1, 46, "Input"],
Cell[105402, 2775, 39, 1, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[105478, 2781, 56, 1, 46, "Input"],
Cell[105537, 2784, 39, 1, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[105613, 2790, 56, 1, 46, "Input"],
Cell[105672, 2793, 38, 1, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[105747, 2799, 52, 1, 46, "Input"],
Cell[105802, 2802, 38, 1, 59, "Output"]
}, Open  ]],
Cell[105855, 2806, 394, 15, 43, "Text"],

Cell[CellGroupData[{
Cell[106274, 2825, 48, 1, 46, "Input"],
Cell[106325, 2828, 38, 1, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[106400, 2834, 48, 1, 46, "Input"],
Cell[106451, 2837, 38, 1, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[106526, 2843, 48, 1, 46, "Input"],
Cell[106577, 2846, 38, 1, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[106652, 2852, 48, 1, 46, "Input"],
Cell[106703, 2855, 38, 1, 59, "Output"]
}, Open  ]],
Cell[106756, 2859, 53, 0, 43, "Text"],

Cell[CellGroupData[{
Cell[106834, 2863, 48, 1, 46, "Input"],
Cell[106885, 2866, 80, 1, 78, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[107002, 2872, 48, 1, 46, "Input"],
Cell[107053, 2875, 80, 1, 78, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[107170, 2881, 48, 1, 46, "Input"],
Cell[107221, 2884, 49, 1, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[107307, 2890, 48, 1, 46, "Input"],
Cell[107358, 2893, 58, 1, 78, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[107465, 2900, 154, 4, 56, "Subsubsection",
  CellTags->"k-convexity"],
Cell[107622, 2906, 2056, 50, 157, "Text",
  CellTags->{"(1988)", "(2002a)"}],
Cell[109681, 2958, 333, 5, 92, "Input"],
Cell[110017, 2965, 232, 4, 69, "Input"],
Cell[110252, 2971, 127, 2, 69, "Input"],
Cell[110382, 2975, 205, 3, 69, "Input"],
Cell[110590, 2980, 222, 6, 43, "Text"],
Cell[110815, 2988, 186, 3, 128, "Input"],
Cell[111004, 2993, 72, 0, 43, "Text"],

Cell[CellGroupData[{
Cell[111101, 2997, 44, 1, 46, "Input"],
Cell[111148, 3000, 182, 3, 82, "Output"]
}, Open  ]],
Cell[111345, 3006, 243, 8, 43, "Text"],

Cell[CellGroupData[{
Cell[111613, 3018, 52, 1, 46, "Input"],
Cell[111668, 3021, 68, 1, 59, "Output"]
}, Open  ]],
Cell[111751, 3025, 79, 1, 46, "Input"],
Cell[111833, 3028, 99, 3, 43, "Text"],

Cell[CellGroupData[{
Cell[111957, 3035, 48, 1, 46, "Input"],
Cell[112008, 3038, 38, 1, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[112083, 3044, 48, 1, 46, "Input"],
Cell[112134, 3047, 38, 1, 59, "Output"]
}, Open  ]],
Cell[112187, 3051, 617, 24, 43, "Text",
  CellTags->"1988"],
Cell[112807, 3077, 498, 15, 43, "Text",
  CellTags->"1988"],
Cell[113308, 3094, 531, 18, 57, "Text",
  CellTags->"1988"],
Cell[113842, 3114, 630, 23, 57, "Text",
  CellTags->"1988"],
Cell[114475, 3139, 1379, 43, 81, "Text",
  CellTags->"1988"],

Cell[CellGroupData[{
Cell[115879, 3186, 46, 1, 46, "Input"],
Cell[115928, 3189, 101, 2, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[116066, 3196, 46, 1, 46, "Input"],
Cell[116115, 3199, 82, 1, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[116234, 3205, 46, 1, 46, "Input"],
Cell[116283, 3208, 58, 1, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[116378, 3214, 46, 1, 46, "Input"],
Cell[116427, 3217, 179, 3, 78, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[116643, 3225, 51, 1, 46, "Input"],
Cell[116697, 3228, 371, 5, 82, "Output"]
}, Open  ]],
Cell[117083, 3236, 967, 28, 81, "Text"],

Cell[CellGroupData[{
Cell[118075, 3268, 60, 1, 46, "Input"],
Cell[118138, 3271, 86, 1, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[118261, 3277, 60, 1, 46, "Input"],
Cell[118324, 3280, 82, 1, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[118443, 3286, 60, 1, 46, "Input"],
Cell[118506, 3289, 60, 1, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[118603, 3295, 60, 1, 46, "Input"],
Cell[118666, 3298, 169, 2, 78, "Output"]
}, Open  ]],
Cell[118850, 3303, 588, 19, 62, "Text"],
Cell[119441, 3324, 76, 1, 46, "Input"],
Cell[119520, 3327, 76, 1, 46, "Input"],
Cell[119599, 3330, 76, 1, 46, "Input"],
Cell[119678, 3333, 76, 1, 46, "Input"],
Cell[119757, 3336, 407, 10, 62, "Text"],

Cell[CellGroupData[{
Cell[120189, 3350, 49, 1, 46, "Input"],
Cell[120241, 3353, 38, 1, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[120316, 3359, 50, 1, 46, "Input"],
Cell[120369, 3362, 39, 1, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[120445, 3368, 49, 1, 46, "Input"],
Cell[120497, 3371, 38, 1, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[120572, 3377, 50, 1, 46, "Input"],
Cell[120625, 3380, 39, 1, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[120701, 3386, 49, 1, 46, "Input"],
Cell[120753, 3389, 38, 1, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[120828, 3395, 50, 1, 46, "Input"],
Cell[120881, 3398, 38, 1, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[120956, 3404, 49, 1, 46, "Input"],
Cell[121008, 3407, 38, 1, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[121083, 3413, 50, 1, 46, "Input"],
Cell[121136, 3416, 38, 1, 59, "Output"]
}, Open  ]],
Cell[121189, 3420, 334, 10, 62, "Text"],

Cell[CellGroupData[{
Cell[121548, 3434, 60, 1, 46, "Input"],
Cell[121611, 3437, 108, 2, 59, "Output"]
}, Open  ]],
Cell[121734, 3442, 76, 1, 46, "Input"],

Cell[CellGroupData[{
Cell[121835, 3447, 50, 1, 46, "Input"],
Cell[121888, 3450, 39, 1, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[121964, 3456, 49, 1, 46, "Input"],
Cell[122016, 3459, 38, 1, 59, "Output"]
}, Open  ]],
Cell[122069, 3463, 252, 8, 43, "Text"],

Cell[CellGroupData[{
Cell[122346, 3475, 46, 1, 46, "Input"],
Cell[122395, 3478, 101, 2, 59, "Output"]
}, Open  ]],
Cell[122511, 3483, 172, 5, 43, "Text"],
Cell[122686, 3490, 129, 3, 43, "Text"],

Cell[CellGroupData[{
Cell[122840, 3497, 55, 1, 46, "Input"],
Cell[122898, 3500, 47, 1, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[122982, 3506, 55, 1, 46, "Input"],
Cell[123040, 3509, 46, 1, 59, "Output"]
}, Open  ]],
Cell[123101, 3513, 124, 3, 43, "Text"],

Cell[CellGroupData[{
Cell[123250, 3520, 55, 1, 46, "Input"],
Cell[123308, 3523, 46, 1, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[123391, 3529, 55, 1, 46, "Input"],
Cell[123449, 3532, 46, 1, 59, "Output"]
}, Open  ]],
Cell[123510, 3536, 307, 7, 62, "Text"],

Cell[CellGroupData[{
Cell[123842, 3547, 58, 1, 46, "Input"],
Cell[123903, 3550, 70, 1, 78, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[124010, 3556, 58, 1, 46, "Input"],
Cell[124071, 3559, 58, 1, 78, "Output"]
}, Open  ]],
Cell[124144, 3563, 607, 18, 81, "Text"],

Cell[CellGroupData[{
Cell[124776, 3585, 56, 1, 46, "Input"],
Cell[124835, 3588, 38, 1, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[124910, 3594, 56, 1, 46, "Input"],
Cell[124969, 3597, 38, 1, 59, "Output"]
}, Open  ]],
Cell[125022, 3601, 1272, 35, 122, "Text"],

Cell[CellGroupData[{
Cell[126319, 3640, 71, 1, 46, "Input"],
Cell[126393, 3643, 427, 6, 128, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[126857, 3654, 49, 1, 46, "Input"],
Cell[126909, 3657, 198, 3, 82, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[127144, 3665, 43, 1, 46, "Input"],
Cell[127190, 3668, 36, 1, 59, "Output"]
}, Open  ]],
Cell[127241, 3672, 407, 9, 65, "Text"],

Cell[CellGroupData[{
Cell[127673, 3685, 60, 1, 46, "Input"],
Cell[127736, 3688, 101, 2, 59, "Output"]
}, Open  ]],
Cell[127852, 3693, 1434, 31, 176, "Text"],

Cell[CellGroupData[{
Cell[129311, 3728, 76, 1, 46, "Input"],
Cell[129390, 3731, 777, 10, 197, "Output"]
}, Open  ]],
Cell[130182, 3744, 1360, 37, 81, "Text"],
Cell[131545, 3783, 298, 11, 44, "Text"],
Cell[131846, 3796, 494, 15, 62, "Text"],

Cell[CellGroupData[{
Cell[132365, 3815, 71, 1, 46, "Input"],
Cell[132439, 3818, 157, 2, 82, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[132633, 3825, 73, 1, 46, "Input"],
Cell[132709, 3828, 157, 2, 82, "Output"]
}, Open  ]],
Cell[132881, 3833, 134, 3, 43, "Text"],

Cell[CellGroupData[{
Cell[133040, 3840, 60, 1, 46, "Input"],
Cell[133103, 3843, 91, 1, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[133231, 3849, 62, 1, 46, "Input"],
Cell[133296, 3852, 91, 1, 59, "Output"]
}, Open  ]],
Cell[133402, 3856, 226, 6, 43, "Text"],

Cell[CellGroupData[{
Cell[133653, 3866, 61, 1, 46, "Input"],
Cell[133717, 3869, 198, 3, 82, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[133952, 3877, 63, 1, 46, "Input"],
Cell[134018, 3880, 198, 3, 82, "Output"]
}, Open  ]],
Cell[134231, 3886, 127, 3, 43, "Text"],

Cell[CellGroupData[{
Cell[134383, 3893, 62, 1, 46, "Input"],
Cell[134448, 3896, 101, 2, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[134586, 3903, 64, 1, 46, "Input"],
Cell[134653, 3906, 101, 2, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[134791, 3913, 45, 1, 46, "Input"],
Cell[134839, 3916, 36, 1, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[134912, 3922, 54, 1, 46, "Input"],
Cell[134969, 3925, 198, 3, 82, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[135204, 3933, 44, 1, 46, "Input"],
Cell[135251, 3936, 36, 1, 59, "Output"]
}, Open  ]],
Cell[135302, 3940, 252, 8, 43, "Text"],

Cell[CellGroupData[{
Cell[135579, 3952, 71, 1, 46, "Input"],
Cell[135653, 3955, 1048, 15, 393, "Output"]
}, Open  ]],
Cell[136716, 3973, 57, 0, 43, "Text"],

Cell[CellGroupData[{
Cell[136798, 3977, 49, 1, 46, "Input"],
Cell[136850, 3980, 541, 8, 213, "Output"]
}, Open  ]],
Cell[137406, 3991, 97, 3, 43, "Text"],

Cell[CellGroupData[{
Cell[137528, 3998, 43, 1, 46, "Input"],
Cell[137574, 4001, 36, 1, 59, "Output"]
}, Open  ]],
Cell[137625, 4005, 132, 3, 43, "Text"],

Cell[CellGroupData[{
Cell[137782, 4012, 65, 1, 46, "Input"],
Cell[137850, 4015, 101, 2, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[137988, 4022, 76, 1, 46, "Input"],
Cell[138067, 4025, 853, 12, 289, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[138957, 4042, 47, 1, 46, "Input"],
Cell[139007, 4045, 36, 1, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[139080, 4051, 64, 1, 46, "Input"],
Cell[139147, 4054, 113, 2, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[139297, 4061, 77, 1, 46, "Input"],
Cell[139377, 4064, 113, 2, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[139527, 4071, 64, 1, 46, "Input"],
Cell[139594, 4074, 113, 2, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[139744, 4081, 56, 1, 46, "Input"],
Cell[139803, 4084, 541, 8, 213, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[140381, 4097, 44, 1, 46, "Input"],
Cell[140428, 4100, 36, 1, 59, "Output"]
}, Open  ]],
Cell[140479, 4104, 575, 16, 43, "Text"],

Cell[CellGroupData[{
Cell[141079, 4124, 66, 1, 46, "Input"],
Cell[141148, 4127, 159, 2, 78, "Output"]
}, Open  ]],
Cell[141322, 4132, 173, 4, 43, "Text"],

Cell[CellGroupData[{
Cell[141520, 4140, 66, 1, 46, "Input"],
Cell[141589, 4143, 67, 1, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[141693, 4149, 75, 1, 46, "Input"],
Cell[141771, 4152, 67, 1, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[141875, 4158, 68, 1, 46, "Input"],
Cell[141946, 4161, 67, 1, 59, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[142062, 4168, 144, 4, 56, "Subsubsection",
  CellTags->"Kernel"],
Cell[142209, 4174, 1930, 42, 195, "Text",
  CellTags->"(2002b)"],

Cell[CellGroupData[{
Cell[144164, 4220, 56, 1, 46, "Input"],
Cell[144223, 4223, 57, 1, 32, "Print"],
Cell[144283, 4226, 62, 1, 78, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[144382, 4232, 56, 1, 46, "Input"],
Cell[144441, 4235, 57, 1, 32, "Print"],
Cell[144501, 4238, 62, 1, 78, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[144600, 4244, 57, 1, 46, "Input"],
Cell[144660, 4247, 62, 1, 78, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[144759, 4253, 56, 1, 46, "Input"],
Cell[144818, 4256, 57, 1, 32, "Print"],
Cell[144878, 4259, 49, 1, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[144964, 4265, 57, 1, 46, "Input"],
Cell[145024, 4268, 49, 1, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[145110, 4274, 56, 1, 46, "Input"],
Cell[145169, 4277, 57, 1, 32, "Print"],
Cell[145229, 4280, 62, 1, 78, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[145328, 4286, 57, 1, 46, "Input"],
Cell[145388, 4289, 62, 1, 78, "Output"]
}, Open  ]],
Cell[145465, 4293, 106, 3, 43, "Text"],

Cell[CellGroupData[{
Cell[145596, 4300, 66, 1, 46, "Input"],
Cell[145665, 4303, 38, 1, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[145740, 4309, 66, 1, 46, "Input"],
Cell[145809, 4312, 38, 1, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[145884, 4318, 66, 1, 46, "Input"],
Cell[145953, 4321, 38, 1, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[146028, 4327, 66, 1, 46, "Input"],
Cell[146097, 4330, 38, 1, 59, "Output"]
}, Open  ]],
Cell[146150, 4334, 35, 0, 43, "Text"],
Cell[146188, 4336, 90, 1, 46, "Input"],
Cell[146281, 4339, 98, 3, 43, "Text"],

Cell[CellGroupData[{
Cell[146404, 4346, 69, 1, 46, "Input"],
Cell[146476, 4349, 60, 1, 59, "Output"]
}, Open  ]],
Cell[146551, 4353, 147, 5, 43, "Text"],

Cell[CellGroupData[{
Cell[146723, 4362, 54, 1, 46, "Input"],
Cell[146780, 4365, 182, 3, 82, "Output"]
}, Open  ]],
Cell[146977, 4371, 337, 10, 62, "Text"],

Cell[CellGroupData[{
Cell[147339, 4385, 101, 2, 46, "Input"],
Cell[147443, 4389, 1299, 24, 184, "Output"]
}, Open  ]],
Cell[148757, 4416, 243, 8, 43, "Text"],

Cell[CellGroupData[{
Cell[149025, 4428, 52, 1, 46, "Input"],
Cell[149080, 4431, 62, 1, 78, "Output"]
}, Open  ]],
Cell[149157, 4435, 284, 7, 43, "Text"],

Cell[CellGroupData[{
Cell[149466, 4446, 60, 1, 46, "Input"],
Cell[149529, 4449, 62, 1, 78, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[149628, 4455, 53, 1, 46, "Input"],
Cell[149684, 4458, 62, 1, 78, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[149783, 4464, 55, 1, 46, "Input"],
Cell[149841, 4467, 62, 1, 78, "Output"]
}, Open  ]],
Cell[149918, 4471, 69, 0, 43, "Text"],

Cell[CellGroupData[{
Cell[150012, 4475, 59, 1, 46, "Input"],
Cell[150074, 4478, 120, 2, 59, "Output"]
}, Open  ]],
Cell[150209, 4483, 645, 16, 105, "Text"],
Cell[150857, 4501, 193, 6, 43, "Text"],

Cell[CellGroupData[{
Cell[151075, 4511, 50, 1, 46, "Input"],
Cell[151128, 4514, 38, 1, 59, "Output"]
}, Open  ]],
Cell[151181, 4518, 122, 5, 43, "Text"],

Cell[CellGroupData[{
Cell[151328, 4527, 37, 1, 46, "Input"],
Cell[151368, 4530, 49, 1, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[151454, 4536, 59, 1, 46, "Input"],
Cell[151516, 4539, 49, 1, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[151602, 4545, 60, 1, 46, "Input"],
Cell[151665, 4548, 49, 1, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[151751, 4554, 90, 1, 46, "Input"],
Cell[151844, 4557, 49, 1, 59, "Output"]
}, Open  ]],
Cell[151908, 4561, 1018, 28, 119, "Text"],

Cell[CellGroupData[{
Cell[152951, 4593, 108, 2, 46, "Input"],
Cell[153062, 4597, 177, 3, 32, "Print"],
Cell[153242, 4602, 165, 3, 32, "Print"],
Cell[153410, 4607, 85, 1, 32, "Print"],
Cell[153498, 4610, 347, 7, 32, "Print"],
Cell[153848, 4619, 392, 6, 168, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[154277, 4630, 70, 1, 46, "Input"],
Cell[154350, 4633, 117, 2, 59, "Output"]
}, Open  ]],
Cell[154482, 4638, 151, 4, 43, "Text"],

Cell[CellGroupData[{
Cell[154658, 4646, 171, 3, 69, "Input"],
Cell[154832, 4651, 177, 3, 32, "Print"],
Cell[155012, 4656, 165, 3, 32, "Print"],
Cell[155180, 4661, 85, 1, 32, "Print"],
Cell[155268, 4664, 347, 7, 32, "Print"],
Cell[155618, 4673, 1594, 29, 335, "Output"]
}, Open  ]],
Cell[157227, 4705, 1125, 24, 138, "Text"],
Cell[158355, 4731, 58, 0, 43, "Text"],

Cell[CellGroupData[{
Cell[158438, 4735, 59, 1, 46, "Input"],
Cell[158500, 4738, 207, 3, 82, "Output"]
}, Open  ]],
Cell[158722, 4744, 54, 0, 43, "Text"],

Cell[CellGroupData[{
Cell[158801, 4748, 48, 1, 46, "Input"],
Cell[158852, 4751, 126, 2, 59, "Output"]
}, Open  ]],
Cell[158993, 4756, 226, 6, 43, "Text"],

Cell[CellGroupData[{
Cell[159244, 4766, 128, 2, 46, "Input"],
Cell[159375, 4770, 57, 1, 32, "Print"],
Cell[159435, 4773, 11918, 199, 1439, "Output"]
}, Open  ]],
Cell[171368, 4975, 318, 6, 62, "Text"],

Cell[CellGroupData[{
Cell[171711, 4985, 39, 1, 46, "Input"],
Cell[171753, 4988, 64, 1, 59, "Output"]
}, Open  ]],
Cell[171832, 4992, 624, 14, 100, "Text"],

Cell[CellGroupData[{
Cell[172481, 5010, 69, 1, 73, "Input"],
Cell[172553, 5013, 55, 1, 78, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[172645, 5019, 55, 1, 46, "Input"],
Cell[172703, 5022, 39, 1, 59, "Output"]
}, Open  ]],
Cell[172757, 5026, 70, 0, 43, "Text"],

Cell[CellGroupData[{
Cell[172852, 5030, 66, 1, 46, "Input"],
Cell[172921, 5033, 49, 1, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[173007, 5039, 55, 1, 46, "Input"],
Cell[173065, 5042, 38, 1, 59, "Output"]
}, Open  ]],
Cell[173118, 5046, 135, 3, 43, "Text"],

Cell[CellGroupData[{
Cell[173278, 5053, 74, 1, 73, "Input"],
Cell[173355, 5056, 55, 1, 78, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[173447, 5062, 55, 1, 46, "Input"],
Cell[173505, 5065, 39, 1, 59, "Output"]
}, Open  ]],
Cell[173559, 5069, 994, 23, 119, "Text"],

Cell[CellGroupData[{
Cell[174578, 5096, 59, 1, 46, "Input"],
Cell[174640, 5099, 63, 1, 78, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[174740, 5105, 59, 1, 46, "Input"],
Cell[174802, 5108, 63, 1, 78, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[174902, 5114, 59, 1, 46, "Input"],
Cell[174964, 5117, 50, 1, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[175051, 5123, 59, 1, 46, "Input"],
Cell[175113, 5126, 63, 1, 78, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[175213, 5132, 60, 1, 46, "Input"],
Cell[175276, 5135, 50, 1, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[175363, 5141, 59, 1, 46, "Input"],
Cell[175425, 5144, 51, 1, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[175513, 5150, 60, 1, 46, "Input"],
Cell[175576, 5153, 50, 1, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[175663, 5159, 59, 1, 46, "Input"],
Cell[175725, 5162, 51, 1, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[175813, 5168, 58, 1, 46, "Input"],
Cell[175874, 5171, 53, 1, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[175964, 5177, 64, 1, 46, "Input"],
Cell[176031, 5180, 54, 1, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[176122, 5186, 63, 1, 46, "Input"],
Cell[176188, 5189, 55, 1, 59, "Output"]
}, Open  ]],
Cell[176258, 5193, 107, 3, 43, "Text"],
Cell[176368, 5198, 468, 7, 169, "Input"],
Cell[176839, 5207, 658, 20, 155, "Text",
  CellTags->"MP66"],
Cell[177500, 5229, 250, 8, 43, "Text"],

Cell[CellGroupData[{
Cell[177775, 5241, 81, 1, 46, "Input"],
Cell[177859, 5244, 57, 1, 32, "Print"],
Cell[177919, 5247, 112, 2, 78, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[178068, 5254, 116, 2, 46, "Input"],
Cell[178187, 5258, 112, 2, 78, "Output"]
}, Open  ]],
Cell[178314, 5263, 98, 3, 43, "Text"],

Cell[CellGroupData[{
Cell[178437, 5270, 57, 1, 46, "Input"],
Cell[178497, 5273, 57, 1, 32, "Print"],
Cell[178557, 5276, 115, 2, 78, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[178709, 5283, 108, 2, 46, "Input"],
Cell[178820, 5287, 179, 3, 32, "Print"],
Cell[179002, 5292, 443, 8, 51, "Print"],
Cell[179448, 5302, 317, 4, 123, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[179802, 5311, 79, 1, 46, "Input"],
Cell[179884, 5314, 66, 1, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[179987, 5320, 60, 1, 46, "Input"],
Cell[180050, 5323, 49, 1, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[180136, 5329, 58, 1, 46, "Input"],
Cell[180197, 5332, 146, 2, 78, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[180380, 5339, 142, 3, 46, "Input"],
Cell[180525, 5344, 177, 3, 32, "Print"],
Cell[180705, 5349, 165, 3, 32, "Print"],
Cell[180873, 5354, 85, 1, 32, "Print"],
Cell[180961, 5357, 455, 8, 51, "Print"],
Cell[181419, 5367, 346, 5, 153, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[181802, 5377, 55, 1, 46, "Input"],
Cell[181860, 5380, 194, 3, 78, "Output"]
}, Open  ]],
Cell[182069, 5386, 52, 0, 43, "Text"],
Cell[182124, 5388, 780, 16, 119, "Text",
  CellTags->"Faigle98"],

Cell[CellGroupData[{
Cell[182929, 5408, 60, 1, 46, "Input"],
Cell[182992, 5411, 152, 2, 78, "Output"]
}, Open  ]],
Cell[183159, 5416, 106, 3, 43, "Text"],
Cell[183268, 5421, 120, 2, 69, "Input"],
Cell[183391, 5425, 61, 0, 43, "Text"],

Cell[CellGroupData[{
Cell[183477, 5429, 105, 2, 46, "Input"],
Cell[183585, 5433, 119, 2, 78, "Output"]
}, Open  ]],
Cell[183719, 5438, 18, 0, 43, "Text"],

Cell[CellGroupData[{
Cell[183762, 5442, 105, 2, 46, "Input"],
Cell[183870, 5446, 307, 4, 123, "Output"]
}, Open  ]],
Cell[184192, 5453, 66, 0, 43, "Text"],

Cell[CellGroupData[{
Cell[184283, 5457, 108, 2, 46, "Input"],
Cell[184394, 5461, 434, 6, 168, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[184865, 5472, 54, 1, 46, "Input"],
Cell[184922, 5475, 164, 2, 78, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[185123, 5482, 54, 1, 46, "Input"],
Cell[185180, 5485, 248, 4, 123, "Output"]
}, Open  ]],
Cell[185443, 5492, 105, 3, 43, "Text"],

Cell[CellGroupData[{
Cell[185573, 5499, 89, 1, 46, "Input"],
Cell[185665, 5502, 86, 1, 59, "Output"]
}, Open  ]],
Cell[185766, 5506, 450, 11, 81, "Text"],

Cell[CellGroupData[{
Cell[186241, 5521, 111, 2, 46, "Input"],
Cell[186355, 5525, 435, 6, 168, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[186827, 5536, 51, 1, 46, "Input"],
Cell[186881, 5539, 38, 1, 59, "Output"]
}, Open  ]],
Cell[186934, 5543, 519, 10, 81, "Text"],
Cell[187456, 5555, 287, 4, 138, "Input"],
Cell[187746, 5561, 88, 3, 43, "Text"],

Cell[CellGroupData[{
Cell[187859, 5568, 50, 1, 46, "Input"],
Cell[187912, 5571, 54, 1, 32, "Print"],
Cell[187969, 5574, 45, 1, 59, "Output"]
}, Open  ]],
Cell[188029, 5578, 88, 3, 43, "Text"],

Cell[CellGroupData[{
Cell[188142, 5585, 85, 1, 46, "Input"],
Cell[188230, 5588, 45, 1, 59, "Output"]
}, Open  ]],
Cell[188290, 5592, 110, 3, 43, "Text"],

Cell[CellGroupData[{
Cell[188425, 5599, 85, 1, 46, "Input"],
Cell[188513, 5602, 56, 1, 78, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[188606, 5608, 41, 1, 46, "Input"],
Cell[188650, 5611, 58, 1, 59, "Output"]
}, Open  ]],
Cell[188723, 5615, 726, 20, 81, "Text"],
Cell[189452, 5637, 480, 12, 50, "Text"],
Cell[189935, 5651, 274, 6, 62, "Text"],

Cell[CellGroupData[{
Cell[190234, 5661, 169, 4, 73, "Input"],
Cell[190406, 5667, 720, 10, 213, "Output"]
}, Open  ]],
Cell[191141, 5680, 165, 4, 43, "Text"],

Cell[CellGroupData[{
Cell[191331, 5688, 62, 1, 46, "Input"],
Cell[191396, 5691, 133, 2, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[191566, 5698, 73, 1, 46, "Input"],
Cell[191642, 5701, 135, 2, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[191814, 5708, 49, 1, 46, "Input"],
Cell[191866, 5711, 57, 1, 32, "Print"],
Cell[191926, 5714, 49, 1, 59, "Output"]
}, Open  ]],
Cell[191990, 5718, 117, 3, 43, "Text"],

Cell[CellGroupData[{
Cell[192132, 5725, 52, 1, 46, "Input"],
Cell[192187, 5728, 49, 1, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[192273, 5734, 53, 1, 46, "Input"],
Cell[192329, 5737, 49, 1, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[192415, 5743, 107, 2, 46, "Input"],
Cell[192525, 5747, 222, 3, 82, "Output"]
}, Open  ]],
Cell[192762, 5753, 916, 17, 119, "Text"],

Cell[CellGroupData[{
Cell[193703, 5774, 176, 3, 69, "Input"],
Cell[193882, 5779, 177, 3, 32, "Print"],
Cell[194062, 5784, 165, 3, 32, "Print"],
Cell[194230, 5789, 85, 1, 32, "Print"],
Cell[194318, 5792, 347, 7, 32, "Print"],
Cell[194668, 5801, 2020, 35, 358, "Output"]
}, Open  ]],
Cell[196703, 5839, 500, 14, 81, "Text"],

Cell[CellGroupData[{
Cell[197228, 5857, 71, 1, 46, "Input"],
Cell[197302, 5860, 117, 2, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[197456, 5867, 111, 2, 46, "Input"],
Cell[197570, 5871, 177, 3, 32, "Print"],
Cell[197750, 5876, 165, 3, 32, "Print"],
Cell[197918, 5881, 85, 1, 32, "Print"],
Cell[198006, 5884, 347, 7, 32, "Print"],
Cell[198356, 5893, 407, 6, 168, "Output"]
}, Open  ]],
Cell[198778, 5902, 64, 0, 43, "Text"],

Cell[CellGroupData[{
Cell[198867, 5906, 71, 1, 46, "Input"],
Cell[198941, 5909, 117, 2, 59, "Output"]
}, Open  ]],
Cell[199073, 5914, 726, 15, 100, "Text"],

Cell[CellGroupData[{
Cell[199824, 5933, 61, 1, 46, "Input"],
Cell[199888, 5936, 137, 2, 59, "Output"]
}, Open  ]],
Cell[200040, 5941, 86, 1, 46, "Input"],
Cell[200129, 5944, 44, 0, 43, "Text"],

Cell[CellGroupData[{
Cell[200198, 5948, 56, 1, 46, "Input"],
Cell[200257, 5951, 64, 1, 78, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[200358, 5957, 37, 1, 46, "Input"],
Cell[200398, 5960, 49, 1, 59, "Output"]
}, Open  ]],
Cell[200462, 5964, 70, 0, 43, "Text"],

Cell[CellGroupData[{
Cell[200557, 5968, 60, 1, 46, "Input"],
Cell[200620, 5971, 39, 1, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[200696, 5977, 167, 3, 69, "Input"],
Cell[200866, 5982, 177, 3, 32, "Print"],
Cell[201046, 5987, 167, 3, 32, "Print"],
Cell[201216, 5992, 80, 1, 32, "Print"],
Cell[201299, 5995, 441, 8, 51, "Print"],
Cell[201743, 6005, 383, 6, 168, "Output"]
}, Open  ]],
Cell[202141, 6014, 297, 7, 62, "Text"],

Cell[CellGroupData[{
Cell[202463, 6025, 72, 1, 46, "Input"],
Cell[202538, 6028, 117, 2, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[202692, 6035, 46, 1, 46, "Input"],
Cell[202741, 6038, 55, 1, 78, "Output"]
}, Open  ]],
Cell[202811, 6042, 89, 3, 43, "Text"],

Cell[CellGroupData[{
Cell[202925, 6049, 40, 1, 46, "Input"],
Cell[202968, 6052, 720, 10, 213, "Output"]
}, Open  ]],
Cell[203703, 6065, 69, 0, 43, "Text"],

Cell[CellGroupData[{
Cell[203797, 6069, 89, 1, 46, "Input"],
Cell[203889, 6072, 55, 1, 78, "Output"]
}, Open  ]],
Cell[203959, 6076, 121, 3, 43, "Text"],
Cell[204083, 6081, 76, 1, 46, "Input"],

Cell[CellGroupData[{
Cell[204184, 6086, 87, 1, 46, "Input"],
Cell[204274, 6089, 93, 1, 78, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[204404, 6095, 72, 1, 46, "Input"],
Cell[204479, 6098, 46, 1, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[204562, 6104, 88, 1, 46, "Input"],
Cell[204653, 6107, 191, 3, 78, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[204881, 6115, 88, 1, 46, "Input"],
Cell[204972, 6118, 191, 3, 78, "Output"]
}, Open  ]],
Cell[205178, 6124, 108, 3, 43, "Text"],

Cell[CellGroupData[{
Cell[205311, 6131, 74, 1, 46, "Input"],
Cell[205388, 6134, 58, 1, 59, "Output"]
}, Open  ]],
Cell[205461, 6138, 158, 4, 43, "Text"],

Cell[CellGroupData[{
Cell[205644, 6146, 108, 2, 46, "Input"],
Cell[205755, 6150, 34685, 961, 1002, "Output"]
}, Open  ]],
Cell[240455, 7114, 161, 4, 43, "Text"],

Cell[CellGroupData[{
Cell[240641, 7122, 68, 1, 46, "Input"],
Cell[240712, 7125, 147, 2, 78, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[240896, 7132, 68, 1, 46, "Input"],
Cell[240967, 7135, 139, 2, 78, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[241155, 7143, 159, 3, 56, "Subsubsection",
  CellTags->"Unanimity Coordinates"],
Cell[241317, 7148, 451, 12, 62, "Text"],
Cell[241771, 7162, 273, 4, 92, "Input"],
Cell[242047, 7168, 39, 0, 43, "Text"],
Cell[242089, 7170, 127, 2, 46, "Input"],
Cell[242219, 7174, 184, 6, 43, "Text"],

Cell[CellGroupData[{
Cell[242428, 7184, 63, 1, 46, "Input"],
Cell[242494, 7187, 503, 8, 82, "Output"]
}, Open  ]],
Cell[243012, 7198, 113, 3, 43, "Text"],

Cell[CellGroupData[{
Cell[243150, 7205, 66, 1, 46, "Input"],
Cell[243219, 7208, 123, 2, 59, "Output"]
}, Open  ]],
Cell[243357, 7213, 532, 13, 81, "Text",
  CellTags->"(1995)"],
Cell[243892, 7228, 312, 10, 44, "Text",
  CellTags->"(1995)"],
Cell[244207, 7240, 194, 6, 43, "Text",
  CellTags->"(1995)"],
Cell[244404, 7248, 510, 18, 61, "Text",
  CellTags->"(1995)"],

Cell[CellGroupData[{
Cell[244939, 7270, 58, 1, 46, "Input"],
Cell[245000, 7273, 109, 2, 59, "Output"]
}, Open  ]],
Cell[245124, 7278, 355, 7, 62, "Text"],

Cell[CellGroupData[{
Cell[245504, 7289, 63, 1, 46, "Input"],
Cell[245570, 7292, 38, 1, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[245645, 7298, 71, 1, 46, "Input"],
Cell[245719, 7301, 38, 1, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[245794, 7307, 50, 1, 46, "Input"],
Cell[245847, 7310, 38, 1, 59, "Output"]
}, Open  ]],
Cell[245900, 7314, 506, 12, 81, "Text"],

Cell[CellGroupData[{
Cell[246431, 7330, 66, 1, 46, "Input"],
Cell[246500, 7333, 47, 1, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[246584, 7339, 58, 1, 46, "Input"],
Cell[246645, 7342, 75, 1, 32, "Print"],
Cell[246723, 7345, 50, 1, 32, "Print"],
Cell[246776, 7348, 73, 1, 32, "Print"],
Cell[246852, 7351, 47, 1, 59, "Output"]
}, Open  ]],
Cell[246914, 7355, 34, 0, 43, "Text"],

Cell[CellGroupData[{
Cell[246973, 7359, 66, 1, 46, "Input"],
Cell[247042, 7362, 82, 1, 78, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[247161, 7368, 58, 1, 46, "Input"],
Cell[247222, 7371, 274, 6, 32, "Print"],
Cell[247499, 7379, 173, 3, 32, "Print"],
Cell[247675, 7384, 174, 4, 32, "Print"],
Cell[247852, 7390, 92, 1, 32, "Print"],
Cell[247947, 7393, 73, 1, 32, "Print"],
Cell[248023, 7396, 82, 1, 78, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[248166, 7404, 148, 3, 102, "Section",
  CellTags->"5"],
Cell[248317, 7409, 974, 25, 119, "Text"],
Cell[249294, 7436, 149, 3, 43, "Text"],

Cell[CellGroupData[{
Cell[249468, 7443, 106, 2, 46, "Input"],
Cell[249577, 7447, 515, 7, 151, "Output"]
}, Open  ]],
Cell[250107, 7457, 294, 9, 62, "Text"],
Cell[250404, 7468, 157, 5, 43, "Text"],

Cell[CellGroupData[{
Cell[250586, 7477, 90, 1, 46, "Input"],
Cell[250679, 7480, 220, 3, 82, "Output"]
}, Open  ]],
Cell[250914, 7486, 92, 3, 43, "Text"],

Cell[CellGroupData[{
Cell[251031, 7493, 93, 1, 46, "Input"],
Cell[251127, 7496, 218, 3, 82, "Output"]
}, Open  ]],
Cell[251360, 7502, 99, 3, 43, "Text"],

Cell[CellGroupData[{
Cell[251484, 7509, 63, 1, 46, "Input"],
Cell[251550, 7512, 82, 1, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[251669, 7518, 63, 1, 46, "Input"],
Cell[251735, 7521, 82, 1, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[251854, 7527, 63, 1, 46, "Input"],
Cell[251920, 7530, 82, 1, 59, "Output"]
}, Open  ]],
Cell[252017, 7534, 145, 5, 43, "Text"],
Cell[252165, 7541, 112, 3, 43, "Text"],

Cell[CellGroupData[{
Cell[252302, 7548, 53, 1, 46, "Input"],
Cell[252358, 7551, 39, 1, 59, "Output"]
}, Open  ]],
Cell[252412, 7555, 153, 5, 43, "Text"],

Cell[CellGroupData[{
Cell[252590, 7564, 59, 1, 46, "Input"],
Cell[252652, 7567, 451, 6, 128, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[253140, 7578, 45, 1, 46, "Input"],
Cell[253188, 7581, 36, 1, 59, "Output"]
}, Open  ]],
Cell[253239, 7585, 332, 8, 62, "Text"],

Cell[CellGroupData[{
Cell[253596, 7597, 53, 1, 46, "Input"],
Cell[253652, 7600, 169, 2, 82, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[253858, 7607, 52, 1, 46, "Input"],
Cell[253913, 7610, 35, 1, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[253985, 7616, 64, 1, 46, "Input"],
Cell[254052, 7619, 82, 1, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[254171, 7625, 64, 1, 46, "Input"],
Cell[254238, 7628, 82, 1, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[254357, 7634, 57, 1, 46, "Input"],
Cell[254417, 7637, 169, 2, 82, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[254623, 7644, 44, 1, 46, "Input"],
Cell[254670, 7647, 35, 1, 59, "Output"]
}, Open  ]],
Cell[254720, 7651, 123, 3, 43, "Text"],
Cell[254846, 7656, 184, 4, 43, "Text"],

Cell[CellGroupData[{
Cell[255055, 7664, 82, 1, 46, "Input"],
Cell[255140, 7667, 169, 2, 82, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[255346, 7674, 64, 1, 46, "Input"],
Cell[255413, 7677, 82, 1, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[255532, 7683, 82, 1, 46, "Input"],
Cell[255617, 7686, 282, 4, 105, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[255936, 7695, 64, 1, 46, "Input"],
Cell[256003, 7698, 131, 2, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[256171, 7705, 72, 1, 46, "Input"],
Cell[256246, 7708, 541, 8, 213, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[256824, 7721, 82, 1, 46, "Input"],
Cell[256909, 7724, 541, 8, 213, "Output"]
}, Open  ]],
Cell[257465, 7735, 496, 12, 62, "Text"],

Cell[CellGroupData[{
Cell[257986, 7751, 64, 1, 46, "Input"],
Cell[258053, 7754, 113, 2, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[258203, 7761, 66, 1, 46, "Input"],
Cell[258272, 7764, 113, 2, 59, "Output"]
}, Open  ]],
Cell[258400, 7769, 135, 4, 43, "Text"],

Cell[CellGroupData[{
Cell[258560, 7777, 64, 1, 46, "Input"],
Cell[258627, 7780, 113, 2, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[258777, 7787, 66, 1, 46, "Input"],
Cell[258846, 7790, 113, 2, 59, "Output"]
}, Open  ]],
Cell[258974, 7795, 297, 9, 62, "Text"],

Cell[CellGroupData[{
Cell[259296, 7808, 62, 1, 46, "Input"],
Cell[259361, 7811, 541, 8, 213, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[259939, 7824, 48, 1, 46, "Input"],
Cell[259990, 7827, 36, 1, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[260063, 7833, 65, 1, 46, "Input"],
Cell[260131, 7836, 113, 2, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[260281, 7843, 65, 1, 46, "Input"],
Cell[260349, 7846, 113, 2, 59, "Output"]
}, Open  ]],
Cell[260477, 7851, 187, 6, 43, "Text"],
Cell[260667, 7859, 118, 3, 43, "Text"],

Cell[CellGroupData[{
Cell[260810, 7866, 80, 1, 46, "Input"],
Cell[260893, 7869, 103, 2, 59, "Output"]
}, Open  ]],
Cell[261011, 7874, 19, 0, 43, "Text"],

Cell[CellGroupData[{
Cell[261055, 7878, 80, 1, 46, "Input"],
Cell[261138, 7881, 139, 2, 59, "Output"]
}, Open  ]],
Cell[261292, 7886, 36, 1, 46, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[261365, 7892, 175, 3, 102, "Section",
  CellTags->"Concluding Remarks and Limitations"],
Cell[261543, 7897, 458, 10, 81, "Text"],

Cell[CellGroupData[{
Cell[262026, 7911, 51, 1, 46, "Input"],
Cell[262080, 7914, 46, 1, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[262163, 7920, 48, 1, 46, "Input"],
Cell[262214, 7923, 43, 1, 59, "Output"]
}, Open  ]],
Cell[262272, 7927, 74, 1, 46, "Input"],
Cell[262349, 7930, 168, 2, 69, "Input"],
Cell[262520, 7934, 158, 4, 43, "Text"],

Cell[CellGroupData[{
Cell[262703, 7942, 54, 1, 46, "Input"],
Cell[262760, 7945, 114, 2, 30, "Message"],
Cell[262877, 7949, 304, 5, 53, "Message"],
Cell[263184, 7956, 114, 2, 30, "Message"],
Cell[263301, 7960, 304, 5, 53, "Message"],
Cell[263608, 7967, 114, 2, 30, "Message"],
Cell[263725, 7971, 163, 3, 30, "Message"],
Cell[263891, 7976, 304, 5, 53, "Message"],
Cell[264198, 7983, 162, 3, 30, "Message"],
Cell[264363, 7988, 4129, 109, 520, "Output"]
}, Open  ]],
Cell[268507, 8100, 106, 3, 43, "Text"],

Cell[CellGroupData[{
Cell[268638, 8107, 71, 1, 46, "Input"],
Cell[268712, 8110, 43, 1, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[268792, 8116, 60, 1, 46, "Input"],
Cell[268855, 8119, 57, 1, 78, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[268949, 8125, 62, 1, 46, "Input"],
Cell[269014, 8128, 57, 1, 78, "Output"]
}, Open  ]],
Cell[269086, 8132, 877, 21, 100, "Text"],
Cell[269966, 8155, 179, 3, 69, "Input"],
Cell[270148, 8160, 102, 3, 43, "Text"],

Cell[CellGroupData[{
Cell[270275, 8167, 37, 1, 46, "Input"],
Cell[270315, 8170, 112, 2, 32, "Print",
  CellTags->"Info3267505555-1237298"],
Cell[270430, 8174, 846, 27, 368, "Print",
  CellTags->"Info3267505555-1237298"]
}, Open  ]],
Cell[271291, 8204, 578, 14, 81, "Text"],

Cell[CellGroupData[{
Cell[271894, 8222, 52, 1, 46, "Input"],
Cell[271949, 8225, 57, 1, 78, "Output"]
}, Open  ]],
Cell[272021, 8229, 610, 19, 81, "Text"],

Cell[CellGroupData[{
Cell[272656, 8252, 60, 1, 46, "Input"],
Cell[272719, 8255, 56, 1, 78, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[272812, 8261, 62, 1, 46, "Input"],
Cell[272877, 8264, 56, 1, 78, "Output"]
}, Open  ]],
Cell[272948, 8268, 97, 3, 43, "Text"],

Cell[CellGroupData[{
Cell[273070, 8275, 37, 1, 46, "Input"],
Cell[273110, 8278, 112, 2, 32, "Print",
  CellTags->"Info3267505563-5322123"],
Cell[273225, 8282, 846, 27, 368, "Print",
  CellTags->"Info3267505563-5322123"]
}, Open  ]],
Cell[274086, 8312, 268, 6, 62, "Text"],
Cell[274357, 8320, 552, 14, 81, "Text"],

Cell[CellGroupData[{
Cell[274934, 8338, 69, 1, 46, "Input"],
Cell[275006, 8341, 179, 3, 32, "Print"],
Cell[275188, 8346, 378, 8, 82, "Output"]
}, Open  ]],
Cell[275581, 8357, 405, 14, 62, "Text"],

Cell[CellGroupData[{
Cell[276011, 8375, 64, 1, 46, "Input"],
Cell[276078, 8378, 159, 3, 32, "Print"],
Cell[276240, 8383, 103, 2, 32, "Print"],
Cell[276346, 8387, 89, 1, 32, "Print"],
Cell[276438, 8390, 119, 2, 32, "Print"]
}, Open  ]],
Cell[276572, 8395, 362, 8, 62, "Text"],

Cell[CellGroupData[{
Cell[276959, 8407, 47, 1, 46, "Input"],
Cell[277009, 8410, 46, 1, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[277092, 8416, 47, 1, 46, "Input"],
Cell[277142, 8419, 62, 1, 59, "Output"]
}, Open  ]],
Cell[277219, 8423, 159, 5, 43, "Text"],

Cell[CellGroupData[{
Cell[277403, 8432, 73, 1, 46, "Input"],
Cell[277479, 8435, 47, 1, 59, "Output"]
}, Open  ]],
Cell[277541, 8439, 966, 25, 119, "Text"],
Cell[278510, 8466, 51, 1, 46, "Input"],
Cell[278564, 8469, 113, 5, 43, "Text"],
Cell[278680, 8476, 70, 1, 46, "Input"],
Cell[278753, 8479, 369, 13, 62, "Text"],
Cell[279125, 8494, 83, 1, 46, "Input"],
Cell[279211, 8497, 108, 5, 43, "Text"],
Cell[279322, 8504, 99, 2, 46, "Input"],
Cell[279424, 8508, 106, 3, 43, "Text"],
Cell[279533, 8513, 81, 1, 46, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[279651, 8519, 127, 3, 102, "Section",
  CellTags->"References"],
Cell[279781, 8524, 2856, 79, 409, "Text",
  CellTags->{
  "M. Carter", "Theo Driessen", "E. Inarra", "M. Maschler", "H. Meinhardt", 
    "C. Rafels", "Hal R. Varian"}],
Cell[282640, 8605, 36, 1, 46, "Input"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

